@@ -1,5 +1,5 @@
 <?php
-/* $Id: croatian-iso-8859-2.inc.php,v 2.6.2.1 2004/06/07 10:09:54 rabus Exp $ */
+/* $Id: croatian-iso-8859-2.inc.php,v 2.66 2005/03/30 19:21:00 lem9 Exp $ */
 
 /**
  * Translation made by: Sime Essert <sime@nofrx.org>
@@ -25,8 +25,6 @@ $strAction = 'Akcija';
 $strAddDeleteColumn = 'Dodaj/izbrii stupac';
 $strAddDeleteRow = 'Dodaj/izbrii polje za kriterij';
 $strAddNewField = 'Dodaj novi stupac';
-$strAddPriv = 'Dodaj novu privilegiju';
-$strAddPrivMessage = 'Privilegija je dodana';
 $strAddSearchConditions = 'Dodaj uvjete pretraivanja (dio "where" upita):';
 $strAddToIndex = 'Dodaj klju';
 $strAddUser = 'Dodaj novog korisnika';
@@ -41,10 +39,7 @@ $strAnalyzeTable = 'Analiziraj tablicu';
 $strAnd = 'i';
 $strAnIndex = 'Klju je upravo dodan %s';
 $strAny = 'Bilo koji';
-$strAnyColumn = 'Bilo koji stupac';
-$strAnyDatabase = 'Bilo koja baza podataka';
 $strAnyHost = 'Bilo koji server';
-$strAnyTable = 'Bilo koja tablica';
 $strAnyUser = 'Bilo koji korisnik';
 $strAPrimaryKey = 'Primarni klju je upravo dodan %s';
 $strAscending = 'Rastui';
@@ -63,19 +58,15 @@ $strBookmarkView = 'Vidi samo';
 $strBrowse = 'Pregled';
 $strBzip = '"bzip-ano"';
 
-$strCantLoadMySQL = 'Ne mogu uitati MySql ekstenziju,<br /> molim provjerite PHP konfiguraciju.';
 $strCantRenameIdxToPrimary = 'Ne mogu promijeniti klju u PRIMARY (primarni) !';
 $strCardinality = 'Kardinalnost';
 $strCarriage = 'Novi red (carriage return): \\r';
 $strChange = 'Promijeni';
 $strChangePassword = 'Promijeni ifru';
 $strCheckAll = 'Oznai sve';
-$strCheckDbPriv = 'Provjeri privilegije baze podataka';
 $strCheckTable = 'Provjeri tablicu';
-$strColumn = 'Stupac';
 $strColumnNames = 'Imena stupaca';
 $strCompleteInserts = 'Kompletan INSERT (sa imenima polja)';
-$strConfirm = 'Da li stvarno to elite uiniti?';
 $strCookiesRequired = '<i>Cookies</i> moraju biti omogueni.';
 $strCopyTable = 'Kopiram tablicu u (baza<b>.</b>tablica):';
 $strCopyTableOK = 'Tablica %s je upravo kopirana u %s.';
@@ -87,27 +78,21 @@ $strCreateNewTable = 'Napravi novu tablicu u bazi ';
 $strCriteria = 'Kriterij';
 
 $strData = 'Podaci';
-$strDatabase = 'Baza podataka ';
+$strDatabase = 'Baza podataka';
 $strDatabaseHasBeenDropped = 'Baza %s je izbrisana.';
 $strDatabases = 'baze';
 $strDatabasesStats = 'Statistika baze';
-$strDatabaseWildcard = 'Baza (<i>wildcard</i> znakovi dozvoljeni):';
 $strDataOnly = 'Samo podaci';
 $strDefault = 'Default';
 $strDelete = 'Izbrii';
 $strDeleted = 'Red je izbrisan';
 $strDeletedRows = 'Izbrisani redovi:';
-$strDeleteFailed = 'Brisanje nije uspjelo!';
-$strDeleteUserMessage = 'Upravo ste izbrisali korisnika: %s.';
 $strDescending = 'Opadajui';
-$strDisplay = 'Prikai';
 $strDisplayOrder = 'Redoslijed prikaza:';
 $strDoAQuery = 'Napravi "upit po primjeru" (<i>wildcard</i>: "%")';
 $strDocu = 'Dokumentacija';
 $strDoYouReally = 'Da li stvarno elite ';
 $strDrop = 'Izbrii';
-$strDropDB = 'Izbrii bazu %s';
-$strDropTable = 'Izbrii tablicu';
 $strDumpingData = 'Izvoz <i>(dump)</i> podataka tablice';
 $strDynamic = 'dinamino';
 
@@ -138,14 +123,12 @@ $strFunction = 'Funkcija';
 
 $strGenTime = 'Vrijeme podizanja';
 $strGo = 'Kreni';
-$strGrants = 'Omogui';
 $strGzip = '"gzip-ano"';
 
 $strHasBeenAltered = 'je promijenjen.';
 $strHasBeenCreated = 'je kreiran/a.';
 $strHome = 'Poetna stranica';
 $strHomepageOfficial = 'phpMyAdmin WEB site';
-$strHomepageSourceforge = 'Sourceforge phpMyAdmin Download Stranica';
 $strHost = 'Host (domena)';
 $strHostEmpty = 'Ime domene je prazno!';
 
@@ -164,17 +147,14 @@ $strInsertNewRow = 'Unesi novi redak';
 $strInsertTextfiles = 'Ubaci podatke iz tekstualne datoteke';
 $strInstructions = 'Uputstva';
 $strInUse = 'se koristi';
-$strInvalidName = '"%s" je rezervirana rije, \nne moe se koristiti kao ime polja, tablice ili baze.';
 
 $strKeepPass = 'Ne mijenjaj lozinku';
 $strKeyname = 'Ime Kljua';
 $strKill = 'Zaustavi';
 
-$strLength = 'Duina';
 $strLengthSet = 'Duina/Vrijednost*';
 $strLimitNumRows = 'Broj redaka po stranici';
 $strLineFeed = '<i>Linefeed</i>: \\n';
-$strLines = 'Linije';
 $strLinesTerminatedBy = 'Linije zavravaju na';
 $strLinksTo = 'Links to';
 $strLocationTextfile = 'Lokacija tekstualne datoteke';
@@ -232,13 +212,11 @@ $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> dio mora biti namjeten u ko
 $strPos1 = 'Poetak';
 $strPrevious = 'Prethodna';
 $strPrimary = 'Primarni';
-$strPrimaryKey = 'Primarni klju';
 $strPrimaryKeyHasBeenDropped = 'Primarni klju je izbrisan';
 $strPrimaryKeyName = 'Ime primarnog kljua mora biti... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime i <b>samo</b> ime primarnog kljua!)';
 $strPrintView = 'Saetak';
 $strPrivileges = 'Privilegije';
-$strProperties = 'Svojstva';
 
 $strQBE = 'Upit po primjeru';
 $strQBEDel = 'Del';
@@ -249,7 +227,6 @@ $strRecords = 'Reci';
 $strReferentialIntegrity = 'Provjeri ispravnost veza:';
 $strReloadFailed = 'ponovno pokretanje MySQL-a nije uspjelo.';
 $strReloadMySQL = 'Ponovo pokreni MySQL (<i>reload</i>)';
-$strRememberReload = 'Ne zaboravite ponovo pokrenuti (<i>reload</i>) server.';
 $strRenameTable = 'Promijeni ime tablice u ';
 $strRenameTableOK = 'Tablici %s promjenjeno ime u %s';
 $strRepairTable = 'Popravi tablicu';
@@ -258,10 +235,7 @@ $strReplaceTable = 'Zamijeni podatke u tablici sa datotekom';
 $strReset = 'Resetiraj';
 $strReType = 'Ponovite unos';
 $strRevoke = 'Opozovi';
-$strRevokeGrant = 'Opozovi Grant';
-$strRevokeGrantMessage = 'Opozvali ste Grant privilegije za  %s';
 $strRevokeMessage = 'Opozvali ste privilegije za %s';
-$strRevokePriv = 'Opozovi privilegije';
 $strRowLength = 'Duina retka';
 $strRows = 'Redaka';
 $strRowsFrom = ' redaka poevi od retka';
@@ -275,7 +249,6 @@ $strRunQuery = 'Izvri SQL upit';
 $strRunSQLQuery = 'Izvri SQL upit(e) na bazi ';
 
 $strSave = 'Spremi';
-$strSelect = 'Oznai';
 $strSelectADb = 'Izaberite bazu';
 $strSelectAll = 'Oznai sve';
 $strSelectFields = 'Izaberite polja (najmanje jedno)';
@@ -286,7 +259,6 @@ $strServerVersion = 'Verzija servera';
 $strSetEnumVal = 'Ako je polje "enum" ili "set", unesite vrijednosti u formatu: \'a\',\'b\',\'c\'...<br />Ako vam zatreba <i>backslash</i> ("\") ili jednostruki navodnik ("\'") navedite ih koristei <i>backslash</i> (npr. \'\\\\xyz\' ili \'a\\\'b\').';
 $strShow = 'Prikai';
 $strShowAll = 'Prikai sve';
-$strShowCols = 'Prikai stupce';
 $strShowingRecords = 'Prikaz redaka';
 $strShowPHPInfo = 'Prikai informacije o PHP-u';
 $strShowTables = 'Prikai tablice';
@@ -299,8 +271,8 @@ $strSQLQuery = 'SQL-upit';
 $strStatement = 'Ime';
 $strStrucCSV = 'CSV format';
 $strStrucData = 'Struktura i podaci';
-$strStrucDrop = 'Dodaj \'drop table\'';
-$strStrucExcelCSV = 'CSV za Ms Excel';
+$strStrucDrop = 'Dodaj DROP TABLE';
+$strStrucExcelCSV = 'CSV za MS Excel';
 $strStrucOnly = 'Samo struktura';
 $strSubmit = 'Pokreni';
 $strSuccess = 'Va SQL upit je uspjeno izvren';
@@ -327,7 +299,6 @@ $strUncheckAll = 'Makni oznake';
 $strUnique = 'Jedinstveni klju';
 $strUnselectAll = 'Makni oznake';
 $strUpdatePrivMessage = 'Promijenili ste privilegije za %s.';
-$strUpdateProfile = 'Promijeni profil:';
 $strUpdateProfileMessage = 'Profil je promijenjen.';
 $strUpdateQuery = 'Promijeni SQL-upit';
 $strUsage = 'Zauzee';
@@ -335,7 +306,6 @@ $strUseBackquotes = 'Koristi \' za ograniavanje imena polja';
 $strUser = 'Korisnik';
 $strUserEmpty = 'Ime korisnika je prazno!';
 $strUserName = 'Ime korisnika';
-$strUsers = 'Korisnici';
 $strUseTables = 'Koristi tablice';
 
 $strValue = 'Vrijednost';
@@ -379,7 +349,6 @@ $strEndCut = 'END CUT';  //to translate
 $strEndRaw = 'END RAW';  //to translate
 $strExplain = 'Explain SQL';  //to translate
 $strExport = 'Export';  //to translate
-$strExportToXML = 'Export to XML format'; //to translate
 
 $strGenBy = 'Generated by'; //to translate
 $strGeneralRelationFeat = 'General relation features';  //to translate
@@ -388,7 +357,6 @@ $strHaveToShow = 'You have to choose at least one Column to display';  //to tran
 
 $strLinkNotFound = 'Link not found';  //to translate
 
-$strMissingBracket = 'Missing Bracket';  //to translate
 $strMySQLCharset = 'MySQL Charset';  //to translate
 
 $strNoDescription = 'no Description';  //to translate
@@ -402,11 +370,9 @@ $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> match(es)';//to translate
 
 $strOK = 'OK';  //to translate
 $strOperations = 'Operations';  //to translate
-$strOptions = 'Options';  //to translate
 
 $strPageNumber = 'Page number:';  //to translate
 $strPdfDbSchema = 'Schema of the the "%s" database - Page %s';  //to translate
-$strPdfInvalidPageNum = 'Undefined PDF page number!';  //to translate
 $strPdfInvalidTblName = 'The "%s" table does not exist!';  //to translate
 $strPdfNoTables = 'No tables';  //to translate
 $strPhp = 'Create PHP Code';  //to translate
@@ -446,7 +412,7 @@ $strInsecureMySQL = 'Your configuration file contains settings (root with no pas
 $strWebServerUploadDirectory = 'web-server upload directory';  //to translate
 $strWebServerUploadDirectoryError = 'The directory you set for upload work cannot be reached';  //to translate
 $strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary php extensions as described in the %sdocumentation%s.'; //to translate
-$strServer = 'Server %s';  //to translate
+$strServer = 'Server';  //to translate
 $strPutColNames = 'Put fields names at first row';  //to translate
 $strImportDocSQL = 'Import docSQL Files';  //to translate
 $strDataDict = 'Data Dictionary';  //to translate
@@ -558,7 +524,6 @@ $strUserNotFound = 'The selected user was not found in the privilege table.'; //
 $strUserAlreadyExists = 'The user %s already exists!'; //to translate
 $strUseTextField = 'Use text field'; //to translate
 
-$strNoUsersSelected = 'No users selected.'; //to translate
 $strDropUsersDb = 'Drop the databases that have the same names as the users.'; //to translate
 $strAddedColumnComment = 'Added comment for column';  //to translate
 $strWritingCommentNotPossible = 'Writing of comment not possible';  //to translate
@@ -602,11 +567,8 @@ $strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user table
 $strWildcard = 'wildcard';  //to translate
 $strRowsModeFlippedHorizontal = 'horizontal (rotated headers)';//to translate
 $strQueryTime = 'Query took %01.4f sec';//to translate
-$strDumpComments = 'Include column comments as inline SQL-comments';//to translate
 $strDBComment = 'Database comment: ';//to translate
 $strQueryFrame = 'Query window';//to translate
-$strQueryFrameDebug = 'Debugging information';//to translate
-$strQueryFrameDebugBox = 'Active variables for the query form:\nDB: %s\nTable: %s\nServer: %s\n\nCurrent variables for the query form:\nDB: %s\nTable: %s\nServer: %s\n\nOpener location: %s\nFrameset location: %s.';//to translate
 $strQuerySQLHistory = 'SQL-history';//to translate
 $strMIME_MIMEtype = 'MIME-type';//to translate
 $strMIME_transformation = 'Browser transformation';//to translate
@@ -618,9 +580,7 @@ $strMIME_available_transform = 'Available transformations';//to translate
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
 $strMIME_description = 'Description';//to translate
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';//to translate
-$strMIME_file = 'Filename';//to translate
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';//to translate
-$strTransformation_text_plain__unformatted = 'Displays HTML code as HTML entities. No HTML formatting is shown.';//to translate
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';//to translate
 $strInnodbStat = 'InnoDB Status';  //to translate
 $strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';  //to translate
@@ -739,7 +699,7 @@ $strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
 $strConstraintsForTable = 'Constraints for table';  //to translate
 $strBookmarkOptions = 'Bookmark options';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
-$strCheckOverhead = 'Check overheaded';  //to translate
+$strCheckOverhead = 'Check tables with overhead';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
 $strDelayedInserts = 'Use delayed inserts';  //to translate
 $strSQLExportType = 'Export type';  //to translate
@@ -748,5 +708,119 @@ $strGeorgian = 'Georgian';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strMaximumSize = 'Maximum size: %s%s';  //to translate
+$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
+$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
+$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
+$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
+$strIgnoreInserts = 'Use ignore inserts';  //to translate
+$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
+$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
+$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
+$strAfterInsertSame = 'Go back to this page';  //to translate
+$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
+$strDatabaseEmpty = 'The database name is empty!';  //to translate
+$strDBRename = 'Rename database to';  //to translate
+$strOperator = 'Operator';  //to translate
+$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
+$strCalendar = 'Calendar';  //to translate
+$strRefresh = 'Refresh';  //to translate
+$strDefragment = 'Defragment table';  //to translate
+$strNoRowsSelected = 'No rows selected';  //to translate
 $strSpanish = 'Spanish';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
+$strServerNotResponding = 'The server is not responding';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
+$strIcelandic = 'Icelandic';  //to translate
+$strLatvian = 'Latvian';  //to translate
+$strPolish = 'Polish';  //to translate
+$strRomanian = 'Romanian';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
