@@ -1,5 +1,5 @@
 <?php
-/* $Id: estonian-iso-8859-1.inc.php,v 2.8.2.2 2004/06/07 10:09:54 rabus Exp $ */
+/* $Id: estonian-iso-8859-1.inc.php,v 2.75 2005/03/30 19:21:39 lem9 Exp $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
@@ -28,10 +28,11 @@ $strAddConstraints = 'Lisa piirangud';
 $strAddDeleteColumn = 'Lisa/Kustuta vlja veerud';
 $strAddDeleteRow = 'Lisa/Kustuta kriteeriumirida';
 $strAddDropDatabase = 'Lisa DROP DATABASE';
+$strAddFields = 'Lisa %s vli(jad)';
+$strAddHeaderComment = 'Lisa vaba kommentaar pisesse (\\n eraldab read)';
+$strAddIfNotExists = 'Lisa IF NOT EXISTS';
 $strAddIntoComments = 'Lisa kommentaaridesse';
 $strAddNewField = 'Lisa uus vli';
-$strAddPriv = 'Lisa uus privileeg';
-$strAddPrivMessage = 'Te lisasite uue privileegi.';
 $strAddPrivilegesOnDb = 'Lisa privileegid antud andmebaasile';
 $strAddPrivilegesOnTbl = 'Lisa privileegid antud tabelile';
 $strAddSearchConditions = 'Lisa otsinguparameetrid ("WHERE" lause sisu):';
@@ -45,6 +46,8 @@ $strAffectedRows = 'Mjutatud read:';
 $strAfter = 'Peale %s';
 $strAfterInsertBack = 'Mine eelmisele lehele tagasi';
 $strAfterInsertNewInsert = 'Lisa jrgmine uus rida';
+$strAfterInsertNext = 'Muuda jrgmist rida';
+$strAfterInsertSame = 'Mine tagasi sellele lehele';
 $strAll = 'Kik';
 $strAllTableSameWidth = 'kuva kik tabelid sama laiusega?';
 $strAlterOrderBy = 'Muuda tabeli sorteeringut';
@@ -52,11 +55,9 @@ $strAnIndex = 'Indeks lisati %s';
 $strAnalyzeTable = 'Analsi tabelit';
 $strAnd = 'ja';
 $strAny = 'kik';
-$strAnyColumn = 'Kik vljad';
-$strAnyDatabase = 'Kik andmebaasid';
 $strAnyHost = 'Kik masinad';
-$strAnyTable = 'Kik tabelid';
 $strAnyUser = 'Kik kasutajad';
+$strApproximateCount = 'Vib olla umbkaudne. Vaadake FAQ 3.11';
 $strArabic = 'Araabia';
 $strArmenian = 'Armeenia';
 $strAscending = 'Kasvav';
@@ -70,8 +71,15 @@ $strBack = 'Tagasi';
 $strBaltic = 'Balti';
 $strBeginCut = 'ALUSTA LIGET';
 $strBeginRaw = 'ALUSTA PUHAST';
+$strBinLogEventType = 'Sndmuse tp';
+$strBinLogInfo = 'Informatsioon';
+$strBinLogName = 'Logi nimi';
+$strBinLogOriginalPosition = 'Originaal positioon';
+$strBinLogPosition = 'Positsioon';
+$strBinLogServerId = 'Serveri ID';
 $strBinary = 'Binaarne';
 $strBinaryDoNotEdit = 'Binaarne - rge muutke';
+$strBinaryLog = 'Binaarne logi';
 $strBookmarkAllUsers = 'Anna kikidele kasutajatele juurdeps sellele jrjehodjale';
 $strBookmarkDeleted = 'Jrjehodja kustutati.';
 $strBookmarkLabel = 'Nimetus';
@@ -86,9 +94,9 @@ $strBzError = 'phpMyAdmin ei suutnud pakkida seda andmebaasivljundit kuna Bz2 mo
 $strBzip = '"bzipitud"';
 
 $strCSVOptions = 'CSV seaded';
+$strCalendar = 'Kalender';
 $strCannotLogin = 'Eei suuda MySQL serverisse logida';
 $strCantLoad = 'ei suutnud lugeda moodulit %s,<br />palun kontrollige PHP konfiguratsiooni';
-$strCantLoadMySQL = 'ei suutnud lugeda MySQL laiendit,<br />palun kontrollige PHP konfiguratsiooni.';
 $strCantLoadRecodeIconv = 'Ei suuda lugeda iconv vi recode moodulit mida on vaja thetabeli konvertimiseks, konfigureerige PHP-d nii, et see sisaldaks antud mooduleid vi keelake thetabeli konvertimine phpMyAdminis.';
 $strCantRenameIdxToPrimary = 'Ei suuda muuta indeksit PRIMAARSEKS!';
 $strCantUseRecodeIconv = 'Ei suuda kasutada iconv-d vi libiconvi vi recode_string funktsiooni kuigi moodul on installitud Kontrollige oma PHP konfiguratsiooni.';
@@ -106,12 +114,11 @@ $strChangeCopyModeRevoke = ' ... kanna kik aktiivsed privileegid le vanast ja ku
 $strChangeCopyUser = 'Vaheta logimisinformatsiooni / Kopeeri kasutaja';
 $strChangeDisplay = 'Vali vli mida kuvada';
 $strChangePassword = 'Muuda parooli';
-$strCharset = 'Theseade';
-$strCharsetOfFile = 'Faili thekodeering:';
+$strCharset = 'Thetabel';
+$strCharsetOfFile = 'Faili thetabel:';
 $strCharsets = 'Thetabelid';
 $strCharsetsAndCollations = 'Thetabelid ja mrangud';
 $strCheckAll = 'Mrgista kik';
-$strCheckDbPriv = 'Vaata andmebaasi privileege';
 $strCheckOverhead = 'Kontrolli lekulusid';
 $strCheckPrivs = 'Kontrollige privileege';
 $strCheckPrivsLong = 'Kontrolli privileege andmebaasile &quot;%s&quot;.';
@@ -119,21 +126,22 @@ $strCheckTable = 'Kontrolli tabelit';
 $strChoosePage = 'Palun valige leht muutmiseks';
 $strColComFeat = 'Nitan veeru kommentaare';
 $strCollation = 'Mrang';
-$strColumn = 'Vli';
 $strColumnNames = 'Vljade nimed';
 $strColumnPrivileges = 'Vli-spetsiifilised privileegid';
 $strCommand = 'Ksk';
 $strComments = 'Kommentaarid';
+$strCommentsForTable = 'KOMMENTAARID TABELILE';
+$strCompatibleHashing = 'MySQL&nbsp;4.0-iga hilduv';
 $strCompleteInserts = 'Tispikk INSERT';
 $strCompression = 'Pakkimine';
 $strConfigFileError = 'phpMyAdmin ei suutnud lugeda Teie konfiguratsioonifaili!<br />See vib juhtuda kui PHP leiab vea selles vi PHP ei leia antud faili les.<br />Palun kutsuge konfiguratsioonifail vlja otseselt kasutades linki allpool ja lugege PHP veateadet(eid) mis teile eldakse. Enamustel juhtudel on kuskilt puudu lakoma vi semikoolon.<br />Kui Teile kuvatakse thi leht on kik korras.';
 $strConfigureTableCoord = 'Palun seadke koordinaadid tabelile %s';
-$strConfirm = 'Kas Te testi tahate seda teha?';
 $strConnectionError = 'Ei saa hendust: vigased seaded.';
 $strConnections = 'hendused';
 $strConstraintsForDumped = 'Piirangud salvestatud tabelitele';
 $strConstraintsForTable = 'Piirangud tabelile';
 $strCookiesRequired = 'Kpsised(cookies) peavad alates sellest momendist lubatud olema.';
+$strCopyDatabaseOK = 'Andmebaas %s on kopeeritud %s';
 $strCopyTable = 'Kopeeri tabel (andmebaas<b>.</b>tabel):';
 $strCopyTableOK = 'Tabel %s on kopeeritud andmebaasi %s.';
 $strCopyTableSameNames = 'Ei saa tabelit iseendasse kopeerida!';
@@ -153,6 +161,7 @@ $strCzech = 'Tsehhi';
 $strCzechSlovak = 'Tsehhi-Slovaki';
 
 $strDBComment = 'Andmebaasi kommentaar: ';
+$strDBCopy = 'Kopeeri andmebaas';
 $strDBGContext = 'Sisu';
 $strDBGContextID = 'Sisu ID';
 $strDBGHits = 'Vajutusi';
@@ -162,15 +171,16 @@ $strDBGMinTimeMs = 'Min aeg, ms';
 $strDBGModule = 'Moodul';
 $strDBGTimePerHitMs = 'Aeg/vajutus, ms';
 $strDBGTotalTimeMs = 'Koguaeg, ms';
+$strDBRename = 'Nimeta andmebaas mber';
 $strDanish = 'Taani';
 $strData = 'Andmed';
 $strDataDict = 'Andmesnastik';
 $strDataOnly = 'Ainult andmed';
-$strDatabase = 'Andmebaas ';
+$strDatabase = 'Andmebaas';
+$strDatabaseEmpty = 'Andmebaasi nimi on thi!';
 $strDatabaseExportOptions = 'Andmebaasi eksportimise seaded';
 $strDatabaseHasBeenDropped = 'Andmebaas %s kustutatud.';
 $strDatabaseNoTable = 'See andmebaas ei sisalda tabelit!';
-$strDatabaseWildcard = 'Andmebaas (lhendid lubatud):';
 $strDatabases = 'andmebaasid';
 $strDatabasesDropped = 'andmebaasid %s kustutati nnestunult.';
 $strDatabasesStats = 'Andmebaaside statistika';
@@ -180,22 +190,22 @@ $strDatabasesStatsHeavyTraffic = 'Mrkus: Lubades siin andmebaasi statistika vite
 $strDbPrivileges = 'Andmebaas-spetsiifilised privileegid';
 $strDbSpecific = 'andmebaasiphine';
 $strDefault = 'Vaikimisi';
+$strDefaultEngine = '%s on vaikimisi varundusmootor sellele MySQL serverile.';
 $strDefaultValueHelp = 'Vaikimisi vrtuse jaoks sisestage lihtsalt ksik vrtus, ilma kaldkriipsudega varjestamata ning jutumrkideta, kasutades jrgmist kirjakuju: a';
+$strDefragment = 'Defrgamenteeri tabel';
 $strDelOld = 'Antud lehel on viiteid tabelitele mida enam ei ole. Kas te soovite kustutada need viited?';
 $strDelayedInserts = 'Kasuta ajastatud lisamisi';
 $strDelete = 'Kustuta';
 $strDeleteAndFlush = 'Kustutage kasutajad ja taaslaadige privileegid prast seda.';
 $strDeleteAndFlushDescr = 'See on parim tee, kuid privileegide taaslaadimine vib vtta aega.';
-$strDeleteFailed = 'Kustutamine ebannestus!';
-$strDeleteUserMessage = 'Te kustutasite kasutaja %s.';
 $strDeleted = 'Rida kustutatud';
 $strDeletedRows = 'Kustuta read:';
 $strDeleting = 'Kustutan %s';
 $strDescending = 'Kahanev';
 $strDescription = 'Kirjeldus';
 $strDictionary = 'snaraamat';
+$strDisableForeignChecks = 'Keela foreign keyde kontroll';
 $strDisabled = 'Keelatud';
-$strDisplay = 'Nita';
 $strDisplayFeat = 'Kuva vimalused';
 $strDisplayOrder = 'Nitamise jrjekord:';
 $strDisplayPDF = 'Nita PDF skeemi';
@@ -203,12 +213,9 @@ $strDoAQuery = 'Tee "pring nite jrgi" (lhend: "%")';
 $strDoYouReally = 'Kas te testi tahate ';
 $strDocu = 'Dokumentatsioon';
 $strDrop = 'Kustuta';
-$strDropDB = 'Kustuta andmebaas ';
 $strDropDatabaseStrongWarning = 'Thelepanu! Te HVITATE kogu andmebaasi!';
 $strDropSelectedDatabases = 'Kustutage valitud andmebaasid';
-$strDropTable = 'Kustuta tabel';
 $strDropUsersDb = 'Kustuta andmebaasid millel on samad nimed nagu kasutajatel.';
-$strDumpComments = 'Lisa veeru kommentaarid siseste SQL-kommentaaridena.';
 $strDumpSaved = 'Vljavte salvestati faili %s.';
 $strDumpXRows = 'Pri %s rida alustades reast %s.';
 $strDumpingData = 'Tabeli andmete salvestamine';
@@ -221,19 +228,24 @@ $strEffective = 'Efektiivne';
 $strEmpty = 'Thjenda';
 $strEmptyResultSet = 'MySQL tagastas thja tulemuse (s.t. null rida).';
 $strEnabled = 'Lubatud';
+$strEncloseInTransaction = 'Lisa eksport lekandesse';
 $strEnd = 'Lpp';
 $strEndCut = 'LPETA LIGE';
 $strEndRaw = 'LPETA PUHAS';
+$strEngineAvailable = '%s on saadaval selles MySQL serveris.';
+$strEngineDisabled = '%s on keelatud selles MySQL serveris.';
+$strEngineUnsupported = 'See MySQL server ei toeta %s varundusmootorit.';
+$strEngines = 'Mootor';
 $strEnglish = 'Inglise';
 $strEnglishPrivileges = ' Mrkus: MySQL privileegide nimed on ingliskeelsed ';
 $strError = 'Viga';
+$strEscapeWildcards = 'Metamrgid _ ja % peaksid olema varjestatud mrgiga \, kui soovite neid sisestada';
 $strEstonian = 'Eesti';
 $strExcelEdition = 'Exceli versioon';
 $strExcelOptions = 'Excel\'i seaded';
 $strExecuteBookmarked = 'Kivita salvestatud pring';
 $strExplain = 'Seleta SQL-i';
 $strExport = 'Ekspordi';
-$strExportToXML = 'Ekspordi XML formaati';
 $strExtendedInserts = 'Laiendatud lisamised';
 $strExtra = 'Ekstra';
 
@@ -268,7 +280,6 @@ $strGlobalPrivileges = 'Globaalsed privileegid';
 $strGlobalValue = 'ldine vrtus';
 $strGo = 'Mine';
 $strGrantOption = 'igused';
-$strGrants = 'igused';
 $strGreek = 'Kreeka';
 $strGzip = '"gzipitud"';
 
@@ -276,17 +287,19 @@ $strHasBeenAltered = 'on muudetud.';
 $strHasBeenCreated = 'on loodud.';
 $strHaveToShow = 'Te peate valima vhemalt he veeru kuvamiseks';
 $strHebrew = 'Heebrea';
+$strHexForBinary = 'Kasuta 16nd koodi binaarvljades';
 $strHome = 'Esileht';
 $strHomepageOfficial = 'Ametlik phpMyAdmini koduleht';
-$strHomepageSourceforge = 'Sourceforge phpMyAdmini allalaadimisleht';
 $strHost = 'Masin';
 $strHostEmpty = 'Masin on thi!';
 $strHungarian = 'Ungari';
 
+$strIcelandic = 'Islandi';
 $strId = 'ID';
 $strIdxFulltext = 'Tistekst';
 $strIfYouWish = 'Kui soovite lugeda ainult mningaid tabeli vlju, sisestage komaga eraldatud vljade loetelu.';
 $strIgnore = 'Ignoreeri';
+$strIgnoreInserts = 'Kasutaja ignoreeritavaid lisamisi';
 $strIgnoringFile = 'Jtan vahele faili %s';
 $strImportDocSQL = 'docSQL failide importimine';
 $strImportFiles = 'Importige failid';
@@ -296,11 +309,16 @@ $strIndex = 'Indeks';
 $strIndexHasBeenDropped = 'Indeks %s kustutatud';
 $strIndexName = 'Indeksi nimi&nbsp;:';
 $strIndexType = 'Indeksi tp&nbsp;:';
+$strIndexWarningMultiple = 'Rohkem kui ks %s vti loodi vljale `%s`';
+$strIndexWarningPrimary = 'PRIMARY ja INDEX vtmed ei tohiks mlemad olla mratud vljale `%s`';
+$strIndexWarningTable = 'Probleemid tabeli `%s` indeksitega';
+$strIndexWarningUnique = 'UNIQUE ja INDEX ei tohiks mlemad olla mratud vljale `%s`';
 $strIndexes = 'Indeksid';
 $strInnodbStat = 'InnoDB staatus';
 $strInsecureMySQL = 'Teie konfiguratsioonifail sisaldab seadeid (root kasutaja ilma paroolita) mis vastab MySQL-i vaikimisi priviligeeritud kasutajale. Kui Teie MySQL-i server jookseb sellise seadega on ta avatud rnnakutele, soovitav on see turvaauk kiiresti parandada.';
 $strInsert = 'Lisa';
 $strInsertAsNewRow = 'Lisa uue reana';
+$strInsertBookmarkTitle = 'Palun sisestage jrjehoidja pealkiri';
 $strInsertNewRow = 'Lisa uus rida';
 $strInsertTextfiles = 'Lisa andmed tekstifailist tabelisse';
 $strInsertedRowId = 'Lisatud rea id:';
@@ -308,7 +326,6 @@ $strInsertedRows = 'Lisatud read:';
 $strInstructions = 'sisestust';
 $strInternalNotNecessary = '* Sisene seos ei ole vajalik kui ta eksisteerib ka InnoDB-s.';
 $strInternalRelations = 'Sisesed seosed';
-$strInvalidName = '"%s" on reserveeritud sna, te ei saa seda kasutada andmebaasi/tabeli/vlja nimena.';
 
 $strJapanese = 'Jaapani';
 $strJumpToDB = 'Hppa andmebaasile &quot;%s&quot;.';
@@ -330,11 +347,10 @@ $strLatexContinuedCaption = 'Jtkuva tabeli seletus';
 $strLatexIncludeCaption = 'Lisa tabeli seletus';
 $strLatexLabel = 'Nimetuse vti';
 $strLatexStructure = 'Tabeli __TABLE__ struktuur';
-$strLength = 'Pikkus';
+$strLatvian = 'Lti';
 $strLengthSet = 'Pikkus/Vrtused*';
 $strLimitNumRows = 'Ridade arv lehel';
 $strLineFeed = 'Realpp: \\n';
-$strLines = 'Read';
 $strLinesTerminatedBy = 'Read lpetatud';
 $strLinkNotFound = 'Linki ei leitud';
 $strLinksTo = 'Lingib ';
@@ -349,12 +365,13 @@ $strLogUsername = 'Kasutajanimi:';
 $strLogin = 'Sisselogimine';
 $strLoginInformation = 'Logimise informatsioon';
 $strLogout = 'Logi vlja';
+$strLongOperation = 'See tegevus vib vtta kaua aega. Jtkan?';
 
+$strMIMETypesForTable = 'MIME TBID TABELILE';
 $strMIME_MIMEtype = 'MIME-tp';
 $strMIME_available_mime = 'Olemasolevad MIME-tbid';
 $strMIME_available_transform = 'Available transformations';
 $strMIME_description = 'Kirjeldus';
-$strMIME_file = 'Failinimi';
 $strMIME_nodescription = 'Selle transformatsiooni jaoks ei ole kirjeldust.<br />Palun ksige autorilt, mida %s teeb.';
 $strMIME_transformation = 'Browseri transformatsioon';
 $strMIME_transformation_note = 'Transformatsiooni vimaluste ja tema MIME-tbi transformatsiooni nimekirjaks vajutage %stransformatsiooni kirjeldusele%s';
@@ -362,7 +379,8 @@ $strMIME_transformation_options = 'Transformeerimise seaded';
 $strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud vrtused, kasutades jrgmist formaati: \'a\',\'b\',\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") vi lakoma ("\'") nende vrtuste seas, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
 $strMIME_without = 'MIME-tbid kursiivis ei oma eraldi transofrmatsiooni funktsiooni';
 $strMaximumSize = 'Maksimaalne suurus: %s%s';
-$strMissingBracket = 'Puuduv lakoma';
+$strMbExtensionMissing = 'Ei leitud mbstring PHP lisa ja tundub, et te kasutate mitmebaidilist thetabelit. Ilma mbstring lisata ei suuda phpMyAdmin poolitada teksti korrektselt ja tulemus vib olla ootustele mittevastav.';
+$strMbOverloadWarning = 'Te olete lubanud mbstring.func_overload oma PHP konfiguratsioonis. See seade ei hildu phpMyAdminiga ja vib osade andmete kadumist phjustada!';
 $strModifications = 'Muutused salvestatud';
 $strModify = 'Muuda';
 $strModifyIndexTopic = 'Muuda indeksit';
@@ -372,7 +390,20 @@ $strMoveTableOK = 'Tabel %s viidu le andmebaasi %s.';
 $strMoveTableSameNames = 'Ei saa tabelit iseendasse liigutada!';
 $strMultilingual = 'mitmekeelne';
 $strMustSelectFile = 'Palun valige fail mida soovite lisada.';
+$strMyISAMDataPointerSize = 'Andmeviida suurus';
+$strMyISAMDataPointerSizeDesc = 'Vaikimisi viida suurus baitides, mida kasutatakse CREATE TABLE ksuga MyISAM tabelite jaoks kui MAX_ROWS seade on mramata.';
+$strMyISAMMaxExtraSortFileSize = 'Maksimaalne failisuurus ajutiste failide jaoks indeksi genereerimisel';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Kui ajutine fail mida kasutatakse kiire MyISAM indeksi loomiseks on suurem kui kasutada siin mratud vtmecache suurust, siis eelistage vtmecache meetodit.';
+$strMyISAMMaxSortFileSize = 'Maksimaalne suurus ajutiste sorteeringufailide jaoks';
+$strMyISAMMaxSortFileSizeDesc = 'Maksimaalne failisuurus MySQL-i ajutise faili jaoks mida kasutatakse MyISAM indeksi uuesti genereerimiseks (REPAIR TABLE, ALTER TABLE vi LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Automaatne taastamine';
+$strMyISAMRecoverOptionsDesc = 'Automaatne taastamine purunenud MyISAM tabelitele, aktiveeritakse vtmega --myisam-recover serveri kivitamisel.';
+$strMyISAMRepairThreads = 'Paranda limud';
+$strMyISAMRepairThreadsDesc = 'Kui see vrtus on suurem kui 1 siis MyISAM tabeli indeksid luuakse paralleelselt (iga indeks oma limus) sorteerimise teel parandamise ajal.';
+$strMyISAMSortBufferSize = 'Sordi puhvri suurus';
+$strMyISAMSortBufferSizeDesc = 'Puhver mis hivatakse kui sorteeritakse MyISAM indekseid REPAIR TABLE ajal vi kui luuakse indekseid CREATE INDEX vi ALTER TABLE kskudega.';
 $strMySQLCharset = 'MySQLi thetabel';
+$strMySQLConnectionCollation = 'MySQL henduse kollatsioon';
 $strMySQLReloaded = 'MySQL uuesti laetud.';
 $strMySQLSaid = 'MySQL tles: ';
 $strMySQLServerProcess = 'MySQL %pma_s1% jookseb %pma_s2%\'is - %pma_s3%';
@@ -381,11 +412,14 @@ $strMySQLShowStatus = 'Nita MySQL-i jooksvat informatsiooni';
 $strMySQLShowVars = 'Nita MySQL ssteemseid muutujaid';
 
 $strName = 'Nimi';
+$strNeedPrimaryKey = 'Te peaksite defineerima primaarse vtme sellele tabelile.';
 $strNext = 'Jrgmine';
 $strNo = 'Ei';
+$strNoActivity = 'Ebaaktiivne %s sekundit vi rohkem, palun sisenege uuesti';
 $strNoDatabases = 'Pole andmebaase';
 $strNoDatabasesSelected = 'htegi andmebaasi ei ole valitud.';
 $strNoDescription = 'pole kirjeldust';
+$strNoDetailsForEngine = 'Detailne seisuinformatsioon antud varundusmootori kohta puudub.';
 $strNoDropDatabases = '"DROP DATABASE" ksud keelatud.';
 $strNoExplain = 'Jta SQL-i seletamine vahele';
 $strNoFrames = 'phpMyAdmin on sbralikum <b>frame toetava</b> browseriga.';
@@ -399,10 +433,11 @@ $strNoPhp = 'ilma PHP koodita';
 $strNoPrivileges = 'Ei oma htegi privileegi';
 $strNoQuery = 'htegi SQL pringut!';
 $strNoRights = 'Teil pole piisavalt igusi, et hetkel siin olla!';
+$strNoRowsSelected = 'Ridu pole valitud';
 $strNoSpace = 'Liiga vhe kettaruumi, et salvestada fail %s.';
 $strNoTablesFound = 'Andmebaasist ei leitud tabeleid.';
+$strNoThemeSupport = 'Teemade tugi puudub, palun kontrollige oma seadeid ja/vi oma teemade kataloogi %s.';
 $strNoUsersFound = 'Ei leitud htegi kasutajat.';
-$strNoUsersSelected = 'Ei valitud htegi kasutajat.';
 $strNoValidateSQL = 'Jta SQL-i kontroll vahele';
 $strNone = 'Pole';
 $strNotNumber = 'See pole number!';
@@ -417,10 +452,10 @@ $strNumTables = 'Tabelid';
 $strOK = 'Korras';
 $strOftenQuotation = 'Kasuta jutumrke koguaeg. VALIKULISELT thendab, et ainult char ja varchar tpi vljad mbritsetakse mratud mrkidega.';
 $strOperations = 'Tegevused';
+$strOperator = 'Operaator';
 $strOptimizeTable = 'Optimiseeri tabelit';
 $strOptionalControls = 'Mittekohustuslik. Kontrollib kuidas kirjutada vi lugeda erimrke.';
 $strOptionally = 'VALIKULISELT';
-$strOptions = 'Valikud';
 $strOr = 'vi';
 $strOverhead = 'lejv';
 $strOverwriteExisting = 'Kirjuta olemasolev(ad) fail(id) le';
@@ -433,23 +468,24 @@ $strPartialText = 'Lhendatud tekstid';
 $strPassword = 'Parool';
 $strPasswordChanged = 'Kasutaja %s parool vahetati nnestunult.';
 $strPasswordEmpty = 'Parool on thi!';
+$strPasswordHashing = 'Parooli trkimine';
 $strPasswordNotSame = 'Paroolid ei hti!';
 $strPdfDbSchema = 'Andmebaasi "%s" skeem - leheklg %s';
-$strPdfInvalidPageNum = 'Defineerimata PDF lehe number!';
 $strPdfInvalidTblName = '"%s" tabel ei eksisteeri!';
 $strPdfNoTables = 'Pole tabeleid';
 $strPerHour = 'tunni kohta';
 $strPerMinute = 'minutis';
 $strPerSecond = 'sekundis';
+$strPersian = 'Prsia';
 $strPhoneBook = 'telefoniraamat';
 $strPhp = 'Loo PHP kood';
 $strPmaDocumentation = 'phpMyAdmini dokumentatsioon';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> konstant peab teie konfiguratsioonifailis mratud olema!';
+$strPolish = 'Poola';
 $strPortrait = 'Portreepilt';
 $strPos1 = 'Algus';
 $strPrevious = 'Eelmine';
 $strPrimary = 'Primaarne';
-$strPrimaryKey = 'Primaarne vti';
 $strPrimaryKeyHasBeenDropped = 'Primaarne vti kustutatud';
 $strPrimaryKeyName = 'Primaarse vtme nimi peab olema... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>peab</b> olema ja <b>ainult</b> olema primaarse vtme nimi!)';
@@ -488,15 +524,12 @@ $strPrivDescUsage = 'Mitte htegi privileegi.';
 $strPrivileges = 'Privileegid';
 $strPrivilegesReloaded = 'Privileegid taaslaeti edukalt.';
 $strProcesslist = 'Protsessinimekiri';
-$strProperties = 'Seaded';
 $strPutColNames = 'Pange vljade nimed esimesse ritta';
 
 $strQBE = 'Pring nite jrgi';
 $strQBEDel = 'Del';
 $strQBEIns = 'Ins';
 $strQueryFrame = 'Pringuaken';
-$strQueryFrameDebug = 'Silumisinformatsioon';
-$strQueryFrameDebugBox = 'Aktiivsed muutujad pringuvormile:\nAB: %s\nTabel: %s\nServer: %s\n\nOlemasolevad muutjad pringuvormile:\nAB: %s\nTabel: %s\nServer: %s\n\nAvaja asukoht: %s\nFreimi asukoht: %s.';
 $strQueryOnDb = 'SQL-pring andmebaasist <b>%s</b>:';
 $strQuerySQLHistory = 'SQL-ajalugu';
 $strQueryStatistics = '<b>Pringu statistika</b>: Alates stardist, %s pringut on saadetud serverile.';
@@ -508,15 +541,17 @@ $strReType = 'Sisesta uuesti';
 $strReceived = 'Saadud';
 $strRecords = 'Kirjeid';
 $strReferentialIntegrity = 'Kontrolli prinevust:';
+$strRefresh = 'Uuenda';
 $strRelationNotWorking = 'Lisavimalused ttamiseks lingitud tabelitega on deaktiveeritud. Et lugeda miks see nii on, vajutage %ssiia%s.';
 $strRelationView = 'Prinevuse vaade';
 $strRelationalSchema = 'Seoseskeem';
 $strRelations = 'Suhted';
+$strRelationsForTable = 'SEOSED TABELILE';
 $strReloadFailed = 'MySQL taaslaadimine ebannestus.';
 $strReloadMySQL = 'Taaslae MySQL';
 $strReloadingThePrivileges = 'Taaslaen privileege';
-$strRememberReload = 'rge unustage serverit taaslaadida.';
 $strRemoveSelectedUsers = 'Eemalda valitud kasutajad';
+$strRenameDatabaseOK = 'Andmebaas %s on mber nimetatud %s';
 $strRenameTable = 'Nimeta tabel mber';
 $strRenameTableOK = 'Tabel %s on mber nimetatud %s';
 $strRepairTable = 'Paranda tabelit';
@@ -528,10 +563,8 @@ $strResourceLimits = 'Ressursilimiidid';
 $strRevoke = 'Vta tagasi';
 $strRevokeAndDelete = 'Eemalda kik aktiivsed privileegid kasutajatelt ning kustuta nad prast seda.';
 $strRevokeAndDeleteDescr = 'Kasutajatel on ikka veel USAGE privileeg, kuni privileegid pole taaslaetud.';
-$strRevokeGrant = 'Vta nudmine tagasi';
-$strRevokeGrantMessage = 'Te vtsite privileegi andmise %s -le tagasi';
 $strRevokeMessage = 'Te vtsite tagasi privileegid %s-lt';
-$strRevokePriv = 'Vtke privileegid';
+$strRomanian = 'Rumeenia';
 $strRowLength = 'Rea pikkus';
 $strRowSize = ' rea suurus ';
 $strRows = 'Ridu';
@@ -547,6 +580,7 @@ $strRunning = 'jookseb masinas %s';
 $strRussian = 'Vene';
 
 $strSQL = 'SQL';
+$strSQLExportCompatibility = 'SQL ekspordiga hilduvus';
 $strSQLExportType = 'Ekspordi tp';
 $strSQLOptions = 'SQL seaded';
 $strSQLParserBugMessage = 'On vimalus, et te leidsite vea SQL parseris. Palun kontrollige oma pringut tpsemalt ja kontrollige, et jutumrgid/lakomad oleks korrektselt lpetatud. Veel on vimalik, et te loete sisse faili kus on binaarne info vljaspool varjestatud tekstiala. Samuti viksite te proovida oma pringut MySQLi ksureal. MySQLi viga vljastatakse pringu all, kui seal testi on mni viga, siis see vib aidata teil leida vea algphjuseid. Kui teil on peale seda ikka veel probleeme vi kui mu parser keeldub ttamast ning MySQL ksurida ttab, siis palun vhendage oma pringuid ksiku pringuni, mis phjustab probleeme ja sisestage vea raport koos viga phjustanud pringuga LIGET sektsioonis allpool:';
@@ -570,16 +604,17 @@ $strSearchOption4 = 'regulaaravaldisena';
 $strSearchResultsFor = 'Otsingu tulemused "<i>%s</i>" %s:';
 $strSearchType = 'Leia:';
 $strSecretRequired = 'Konfiguratsioonifail nuab nd salajast vtmesna (blowfish_secret).';
-$strSelect = 'Vali';
 $strSelectADb = 'Valige andmebaas';
 $strSelectAll = 'Mrgista kik';
+$strSelectBinaryLog = 'Valige binaarne logi vaatamiseks';
 $strSelectFields = 'Vali vljad (vhemalt ks):';
 $strSelectNumRows = 'pringus';
 $strSelectTables = 'Vali tabelid';
 $strSend = 'Salvesta failina';
 $strSent = 'Saadetud';
-$strServer = 'Server %s';
+$strServer = 'Server';
 $strServerChoice = 'Serveri valik';
+$strServerNotResponding = 'Server ei vasta';
 $strServerStatus = 'Jooksev informatsioon';
 $strServerStatusUptime = 'See MySQL server on kinud %s. Kivitusaeg %s.';
 $strServerTabProcesslist = 'Protsessid';
@@ -592,7 +627,6 @@ $strSetEnumVal = 'Kui vlja tp on "enum" vi "set", palun sisestage vrtused kasuta
 $strShow = 'Nita';
 $strShowAll = 'Nita kiki';
 $strShowColor = 'Nita vrvi';
-$strShowCols = 'Nita vlju';
 $strShowDatadictAs = 'Andmesnastiku formaat';
 $strShowFullQueries = 'Nita tispikkasid pringuid';
 $strShowGrid = 'Nita vrgustiku';
@@ -604,19 +638,25 @@ $strShowingRecords = 'Nita ridu';
 $strSimplifiedChinese = 'Lihtsustatud Hiina';
 $strSingly = '(ksikult)';
 $strSize = 'Suurus';
+$strSlovak = 'Slovaki';
+$strSlovenian = 'Sloveenia';
 $strSort = 'Sorteeri';
 $strSortByKey = 'Sorteeri vtme jrgi';
 $strSpaceUsage = 'Ruumivtt';
+$strSpanish = 'Hispaania';
 $strSplitWordsWithSpace = 'Snad on eraldatud thikuga (" ").';
 $strStatCheckTime = 'Viimane vaatamine';
 $strStatCreateTime = 'Loodud';
 $strStatUpdateTime = 'Viimane muudatus';
 $strStatement = 'Parameerid';
 $strStatus = 'Staatus';
+$strStorageEngine = 'Varundusmootor';
+$strStorageEngines = 'Varundusmootorid';
 $strStrucCSV = 'CSV andmed';
 $strStrucData = 'Struktuur ja andmed';
-$strStrucDrop = 'Lisa \'drop table\'';
-$strStrucExcelCSV = 'CSV Ms Exceli jaoks';
+$strStrucDrop = 'Lisa DROP TABLE';
+$strStrucExcelCSV = 'CSV MS Exceli jaoks';
+$strStrucNativeExcel = 'Loomulikud MS Exceli andmed';
 $strStrucOnly = 'Ainult struktuur';
 $strStructPropose = 'Soovita tabeli struktuuri';
 $strStructure = 'Struktuur';
@@ -624,6 +664,7 @@ $strSubmit = 'Vali';
 $strSuccess = 'Teie SQL pring tideti edukalt';
 $strSum = 'Summa';
 $strSwedish = 'Rootsi';
+$strSwitchToDatabase = 'Mine kopeeritud andmebaasile';
 $strSwitchToTable = 'Mine le kopeeritud tabelile';
 
 $strTable = 'Tabel';
@@ -638,12 +679,14 @@ $strTableOptions = 'Tabeli seaded';
 $strTableStructure = 'Struktuur tabelile';
 $strTableType = 'Tabeli tp';
 $strTables = '%s tabel(it)';
+$strTakeIt = 'vta see';
 $strTblPrivileges = 'Tabel-spetsiifilised privileegid';
 $strTextAreaLength = ' Oma suuruse tttu<br /> vib see vli olla mittemuudetav ';
 $strThai = 'Tai';
 $strTheContent = 'Teie faili sisu on lisatud.';
 $strTheContents = 'Faili sisu asendab valitud tabeli sisu ridades kus on identsed primaarsed vi unikaalsed vtmed.';
 $strTheTerminator = 'Vljade eraldaja.';
+$strTheme = 'Teema / Stiil';
 $strThisHost = 'Antud host';
 $strThisNotDirectory = 'See ei olnud kataloog';
 $strThreadSuccessfullyKilled = 'Protsess %s katkestati edukalt.';
@@ -652,6 +695,7 @@ $strToggleScratchboard = 'vaheta mrkmetahvlit';
 $strTotal = 'kokku';
 $strTotalUC = 'Kokku';
 $strTraditionalChinese = 'Traditsionaalne Hiina';
+$strTraditionalSpanish = 'Traditsionaalne Hispaania';
 $strTraffic = 'Liiklus';
 $strTransformation_application_octetstream__download = 'Nita linki millega laadida alla vlja binaarne info. Esimene seade on binaarse faili nimi. Teine seade on vimalik vljanimi tabelis mis sisaldab failinime. Kui te mrate teise seade siis peab esimene seade olema thi tekst';
 $strTransformation_image_jpeg__inline = 'Kuvab lingitud vikepildi; seaded: laius,krgus pikslites (hoiab alles originaalpildi laiuse-krguse suhte)';
@@ -663,7 +707,6 @@ $strTransformation_text_plain__formatted = 'Hoiab alles originaalset vlja formaa
 $strTransformation_text_plain__imagelink = 'Kuvab pildi ja lingi, vli sisaldab failinime; esimene seade on eelnev tekst nagu "http://domain.com/", teine seade on laius pikslites, kolmas on krgus.';
 $strTransformation_text_plain__link = 'Kuvab lingi, vli sisaldab failinime; esimene seade on eelnev tekst niteks "http://domain.com/", teine seade on nimi lingile.';
 $strTransformation_text_plain__substr = 'Nitab ainult osa tekstist. Esimene seade on mrang kust positsioonilt teie teksti kuva hakkab.(vaikimisi 0). Teine seade on kuipalju teksti tagastatakse, kui see thjaks jtta, tagastatakse kogu allesjnud tekst. Kolmas seade defineerib mis tekst lisatakse vljundi lppu kui saadud tekst tagastatakse. (vaikimisi: ...) .';
-$strTransformation_text_plain__unformatted = 'Nitab HTML koodi puhta tekstina. HTML formateerimist ei nidata.';
 $strTruncateQueries = 'Lhenda nidatavad pringud';
 $strTurkish = 'Trgi';
 $strType = 'Tp';
@@ -676,13 +719,13 @@ $strUnknown = 'tundmatu';
 $strUnselectAll = 'Puhasta kik';
 $strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';
 $strUpdatePrivMessage = 'Te uuendasite privileege %s-l.';
-$strUpdateProfile = 'Uuendatav profiil:';
 $strUpdateProfileMessage = 'Profiil uuendatud.';
 $strUpdateQuery = 'Uuenda pringut';
 $strUpgrade = 'Te peaksite uuendama %s -i versioonini %s vi uuemaks.';
 $strUsage = 'Kasutus';
 $strUseBackquotes = 'Kasutage tagurpidi kaldkriipse tabelites vi tabelinimedes';
 $strUseHostTable = 'Kasuta host tabelit';
+$strUseTabKey = 'Kasutage TAB klahvi, et liikuda helt vrtuselt teisele vi CTRL+nool, et liikuda noole suunas';
 $strUseTables = 'Kasuta tabeleid';
 $strUseTextField = 'Kasutage tekstivlja';
 $strUseThisValue = 'Kasuta seda vrtust';
@@ -692,7 +735,6 @@ $strUserEmpty = 'Kasutajanimi on thi!';
 $strUserName = 'Kasutajanimi';
 $strUserNotFound = 'Valitud kasutajat ei leitud privileegide tabelist.';
 $strUserOverview = 'Kasutaja levaade';
-$strUsers = 'Kasutajad';
 $strUsersDeleted = 'Valitud kasutajad on nnestunult kustutatud.';
 $strUsersHavingAccessToDb = 'Kasutajad kellel on ligips &quot;%s&quot;';
 
@@ -700,9 +742,12 @@ $strValidateSQL = 'Kontrolli SQL-i';
 $strValidatorError = 'SQL-i valideerijat ei suudetud avada. Palun kontrollige, et te olete installinud vastavad php moodulid nagu on kirjeldatud %sdokumentatsioonis%s.';
 $strValue = 'Vrtus';
 $strVar = 'Muutuja';
+$strVersionInformation = 'Versiooni info';
+$strView = 'Vaade';
 $strViewDump = 'Vaata tabeli vljundit (skeemi)';
 $strViewDumpDB = 'Vaata andmebaasi vljundit (skeemi)';
 $strViewDumpDatabases = 'Nita andmebaaside sisu (skeemi)';
+$strViewHasBeenDropped = 'Vaade %s on kustutatud';
 
 $strWebServerUploadDirectory = 'webiserveri leslaadimiskataloogi';
 $strWebServerUploadDirectoryError = 'Kataloog mille Te leslaadimiseks sttisite ei ole ligipsetav';
@@ -722,5 +767,44 @@ $strYes = 'Jah';
 $strZeroRemovesTheLimit = 'Mrkus: Mrkides antud seaded 0 (null) , eemaldate limiidi.';
 $strZip = '"zipitud"';
 
-$strSpanish = 'Spanish';  //to translate
+// To translate:
+
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+
+$strDataPages = 'Pages containing data';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+
+$strFreePages = 'Free pages';  //to translate
+
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+
+$strLatchedPages = 'Latched pages';  //to translate
+
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+
+$strReadRequests = 'Read requests';  //to translate
+
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+
+$strWriteRequests = 'Write requests';  //to translate
+
 ?>
