@@ -1,5 +1,5 @@
 <?php
-/* $Id: greek-utf-8.inc.php,v 2.6.2.1 2004/06/07 10:09:55 rabus Exp $ */
+/* $Id: greek-utf-8.inc.php,v 2.66 2005/03/30 19:22:01 lem9 Exp $ */
 
 /* Translated by Kyriakos Xagoraris <theremon at users.sourceforge.net> */
 
@@ -35,8 +35,6 @@ $strAddDeleteRow = 'Προσθήκη/Αφαίρεση Γραμμής Κριτη
 $strAddDropDatabase = 'Προσθήκη DROP DATABASE';
 $strAddIntoComments = 'Προσθήκη στα σχόλια';
 $strAddNewField = 'Προσθήκη νέου Πεδίου';
-$strAddPriv = 'Προσθήκη νέου Προνομίου';
-$strAddPrivMessage = 'Προσθέσατε νέο Προνόμιο.';
 $strAddPrivilegesOnDb = 'Προσθήκη προνομίων στην ακόλουθη βάση δεδομένων'; 
 $strAddPrivilegesOnTbl = 'Προσθήκη δεδομένων στον ακόλουθο πίνακα'; 
 $strAddSearchConditions = 'Προσθήκη νέου όρου (σώμα της "where" πρότασης):';
@@ -57,10 +55,7 @@ $strAnIndex = 'Ένα ευρετήριο προστέθηκε στο %s';
 $strAnalyzeTable = 'Ανάλυση Πίνακα';
 $strAnd = 'Και';
 $strAny = 'Οποιοδήποτε';
-$strAnyColumn = 'Οποιαδήποτε Στήλη';
-$strAnyDatabase = 'Οποιαδήποτε Βάση';
 $strAnyHost = 'Οποιοδήποτε Σύστημα';
-$strAnyTable = 'Οποιοσδήποτε Πίνακας';
 $strAnyUser = 'Οποιοσδήποτε Χρήστης';
 $strArabic = 'Αραβικά';  
 $strArmenian = 'Αρμενικά';  
@@ -90,7 +85,6 @@ $strBzip = 'συμπίεση «bzip»';
 $strCSVOptions = 'Επιλογές CSV';
 $strCannotLogin = 'Δεν ήταν δυνατή η σύνδεση με τον διακομιστή MySQL';  
 $strCantLoad = 'δεν ήταν δυνατή η φόρτωση της επέκτασης %s ,<br />παρακαλώ ελέγξτε τις ρυθμίσεις της PHP';  
-$strCantLoadMySQL = 'δεν μπορεί να φορτωθεί η επέκταση MySQL,<br />παρακαλώ ελέγξτε τις ρυθμίσεις της PHP.';
 $strCantLoadRecodeIconv = 'Δεν είναι δυνατή η φόρτωση της επέκτασης iconv ή recode που χρειάζεται για την μετατροπή του σετ χαρακτήρων. Ρυθμίστε την php να επιτρέπει την χρήση αυτών των επεκτάσεων ή απανεργοποιήστε την μετατροπή χαρακτήρων στο phpMyAdmin.'; 
 $strCantRenameIdxToPrimary = 'Η μετονομασία του ευρετηρίου σε PRIMARY σε είναι εφικτή!';
 $strCantUseRecodeIconv = 'Δεν είναι δυνατή η χρήση της επέκτασης iconv ούτε της libiconv ούτε της ρουτίνας recode_string, ενώ η επέκταση έχει φορτωθεί. Ελέξτε τις ρυθμίσεις της php.'; 
@@ -110,13 +104,11 @@ $strCharset = 'Σετ χαρακτήρων';
 $strCharsetOfFile = 'Σετ χαρακτήρων του αρχείου:'; 
 $strCharsets = 'Σετ χαρακτήρων';  
 $strCheckAll = 'Επιλογή όλων';
-$strCheckDbPriv = 'Έλεγχος προνομίων Βάσης';
 $strCheckPrivs = 'Έλεγχος Προνομίων';  
 $strCheckPrivsLong = 'Έλεγχος προνομίων για τη βάση &quot;%s&quot;.';  
 $strCheckTable = 'Έλεγχος πίνακα';
 $strChoosePage = 'Παρακαλώ επιλέξτε σελίδα για αλλαγή';  
 $strColComFeat = 'Εμφάνιση σχολίων πεδίων';
-$strColumn = 'Στήλη';
 $strColumnNames = 'Ονόματα στηλών';
 $strColumnPrivileges = 'Προνόμια πεδίων'; 
 $strCommand = 'Εντολή'; 
@@ -125,7 +117,6 @@ $strCompleteInserts = 'Ολοκληρωμένες εντολές «Insert»';
 $strCompression = 'Συμπίεση'; 
 $strConfigFileError = 'Το phpMyAdmin δεν μπόρεσε να διαβάσει το αρχείο ρυθμίσεων!<br />Αυτό μπορεί να συμβεί εάν η php βρει κάποιο λάθος στο αρχείο ή εάν η php δεν μπορεί να βρει το αρχείο.<br />Παρακαλώ καλέστε το αρχείο ρυθμίσεων απ\' ευθείας χρησιμοποιώντας το ακόλουθο link και διαβάστε τα μυνήματα λάθους που θα επιστρέψει η php. Στις περισσότερες περιπτώσεις κάπου λείπουν εισαγωγικά (") ή ερωτιματικά (;).<br />Εάν η php επιστρέψει μια λευκή σελίδα, όλα είναι σωστά.'; 
 $strConfigureTableCoord = 'Παρακαλώ ορίστε τις συντεταγμένες για τον πίνακα %s';  
-$strConfirm = 'Πραγματικά θέλετε να το εκτελέσετε;';
 $strConnections = 'Συνδέσεις'; 
 $strCookiesRequired = 'Από αυτό το σημείο πρέπει να έχετε ενεργοποιημένα cookies.';
 $strCopyTable = 'Αντιγραφή πίνακα σε (βάση<b>.</b>πίνακας):';
@@ -158,11 +149,10 @@ $strDanish = 'Δανικά';
 $strData = 'Δεδομένα';
 $strDataDict = 'Λεξικό δεδομένων';  
 $strDataOnly = 'Μόνο τα δεδομένα';
-$strDatabase = 'Βάση ';
+$strDatabase = 'Βάση';
 $strDatabaseExportOptions = 'Επιλογές εξαγωγής βάσης δεδομένων';
 $strDatabaseHasBeenDropped = 'Η βάση δεδομένων %s διεγράφη.';
 $strDatabaseNoTable = 'Αυτή η βάση δεν περιέχει πίνακες!';
-$strDatabaseWildcard = 'Βάση δεδομένων (επιτρέπονται wildcards):';
 $strDatabases = 'Βάσεις Δεδομένων';
 $strDatabasesDropped = '%s βάσεις δεδομένων διεγράφησαν επιτυχώς.';  
 $strDatabasesStats = 'Στατιστικά βάσης';
@@ -177,8 +167,6 @@ $strDelOld = 'Η τρέχουσα σελίδα έχει αναφορές σε π
 $strDelete = 'Διαγραφή';
 $strDeleteAndFlush = 'Διαγραφή των χρηστών και επαναφόρτωση των προνομίων.'; 
 $strDeleteAndFlushDescr = 'Αυτός είναι ο πιο "καθαρός" τρόπος, αλλά η επαναφόρτωση των προνομίων μπορεί να καθυστερήσει.'; 
-$strDeleteFailed = 'Η διαγραφή απέτυχε';
-$strDeleteUserMessage = 'Διαγράψατε τον χρήστη %s.';
 $strDeleted = 'Η Εγγραφή έχει διαγραφεί';
 $strDeletedRows = 'Διαγραμμένες Εγγραφές:';
 $strDeleting = 'Διαγραφή %s'; 
@@ -186,7 +174,6 @@ $strDescending = 'Φθίνουσα';
 $strDescription = 'Περιγραφή';  
 $strDictionary = 'λεξικό';  
 $strDisabled = 'Απενεργοποιημένο';
-$strDisplay = 'Εμφάνιση';
 $strDisplayFeat = 'Λειτουργίες εμφάνισης';
 $strDisplayOrder = 'Σειρά εμφάνισης:';
 $strDisplayPDF = 'Εμφάνιση σχήματος PDF';  
@@ -194,11 +181,8 @@ $strDoAQuery = 'Εκτέλεσε ένα «επερώτημα κατά παράδ
 $strDoYouReally = 'Θέλετε να εκτελέσετε την εντολή';
 $strDocu = 'Τεκμηρίωση';
 $strDrop = 'Διαγραφή';
-$strDropDB = 'Διαγραφή βάσης %s';
 $strDropSelectedDatabases = 'Διαγραφή επιλεγμένων βάσεων δεδομένων';  
-$strDropTable = 'Διαγραφή πίνακα';
 $strDropUsersDb = 'Διαγραφή βάσεων δεδομένων που έχουν ίδια ονόματα με χρήστες.'; 
-$strDumpComments = 'Να συμπεριληφθούν τα σχόλια στηλών ως εσωτερικά σχόλια SQL';
 $strDumpSaved = 'Το αρχείο εξόδου αποθηκεύτηκε ως %s.';  
 $strDumpXRows = 'Εμφάνιση %s εγγραφών ξεκινώντας από την εγγραφή %s.'; 
 $strDumpingData = '\'Αδειασμα δεδομένων του πίνακα';
@@ -222,7 +206,6 @@ $strExcelOptions = 'Επιλογές Excel';
 $strExecuteBookmarked = 'Εκτέλεση αποθηκευμένου επερωτήματος';  
 $strExplain = 'Ανάλυση SQL';  
 $strExport = 'Εξαγωγή';  
-$strExportToXML = 'Εξαγωγή σε μορφή XML'; 
 $strExtendedInserts = 'Εκτεταμένες εντολές «Insert»';
 $strExtra = 'Πρόσθετα';
 
@@ -256,7 +239,6 @@ $strGlobalPrivileges = 'Γενικά προνόμια';
 $strGlobalValue = 'Γενική τιμή'; 
 $strGo = 'Εκτέλεση';
 $strGrantOption = 'Χορήγηση'; // Grant
-$strGrants = 'Παραχωρήσεις';
 $strGreek = 'Ελληνικά';  
 $strGzip = 'συμπίεση «gzip»';
 
@@ -266,7 +248,6 @@ $strHaveToShow = 'Πρέπει να επιλέξετε τουλάχιστον μ
 $strHebrew = 'Εβραϊκά';  
 $strHome = 'Κεντρική σελίδα';
 $strHomepageOfficial = 'Επίσημη σελίδα του phpMyAdmin';
-$strHomepageSourceforge = 'Σελίδα του Sourceforge για την απόκτηση του phpMyAdmin';
 $strHost = 'Σύστημα';
 $strHostEmpty = 'Το όνομα του Συστήματος είναι κενό!';
 $strHungarian = 'Ουγγρικά';  
@@ -294,7 +275,6 @@ $strInsertTextfiles = 'Εισαγωγή αρχείου κειμένου στον
 $strInsertedRowId = 'id εισαγμένης εγγραφής:';  
 $strInsertedRows = 'Εισαγόμενες εγγραφές:';
 $strInstructions = 'Οδηγίες';
-$strInvalidName = 'Η «%s» είναι δεσμευμένη λέξη, δεν μπορείτε να την χρησιμοποιήσετε ως όνομα για Βάση, Πίνακα ή Πεδίο.';
 
 $strJapanese = 'Ιαπωνικά';  
 $strJumpToDB = 'Μεταπήδηση στην βάση &quot;%s&quot;.';  
@@ -309,11 +289,9 @@ $strKorean = 'Κορεατικά';
 $strLaTeX = 'LaTeX';  
 $strLaTeXOptions = 'Επιλογές LaTeX';  
 $strLandscape = 'Οριζόντια διάταξη';  
-$strLength = 'Μήκος';
 $strLengthSet = 'Μήκος/Τιμές*';
 $strLimitNumRows = 'Εγγραφές ανά σελίδα';
 $strLineFeed = 'Χαρακτήρας προώθησης γραμμής: \\n';
-$strLines = 'Γραμμές';
 $strLinesTerminatedBy = 'Γραμμές που τελειώνουν σε';
 $strLinkNotFound = 'Δεν βρέθηκε η σύνδεση';  
 $strLinksTo = 'Σύνδεση με';  
@@ -332,14 +310,12 @@ $strMIME_MIMEtype = 'Τύπος MIME';
 $strMIME_available_mime = 'Διαθέσιμοι τύποι MIME';
 $strMIME_available_transform = 'Διαθέσιμες μετατροπές';
 $strMIME_description = 'Περιγραφή';
-$strMIME_file = 'Όνομα αρχείου';
 $strMIME_nodescription = 'Δεν υπάρχει διαθέσιμη περιγραφή για αυτή τη μετατροπή.<br />Παρακαλώ απευθηνθείτε στον δημιουργό της για να μάθετε, τι κάνει η μετατροπή %s.';
 $strMIME_transformation = 'Μετατροπή περιηγητή';
 $strMIME_transformation_note = 'Για μία λίστα με τις διαθέσιμες μετατροπές και τις μετατροπές τύπου MIME, πατήστε %sπεριγραφές μετατροπών%s';
 $strMIME_transformation_options = 'Επιλογές μετατροπής';
 $strMIME_transformation_options_note = 'Παρακαλώ εισάγετε τις τιμές για τη μετατροπή χρησιμοποιώντας τη μορφή: \'a\',\'b\',\'c\'...<br />Εάν χρειαστείτε να χρησιμοποιήσετε καθέτους ("\") ή μονά εισαγωγικά ("\'") στις τιμές, χρησιμοποιείτε καθέτους (παράδειγμα \'\\\\xyz\' ή \'a\\\'b\').';
 $strMIME_without = 'Οι τύποι MIME που εμφανίζονται με πλάγια γράμματα δεν έχουν ξεχωριστή λειτουργία μετατροπής';
-$strMissingBracket = 'Λείπει μία αγκύλη';  
 $strModifications = 'Οι αλλαγές αποθηκεύτηκαν';
 $strModify = 'Τροποποίηση';
 $strModifyIndexTopic = 'Αλλαγή ενός ευρετηρίου';
@@ -379,7 +355,6 @@ $strNoRights = 'Δεν έχετε αρκετά δικαιώματα να είσ
 $strNoSpace = 'Δεν υπάρχει διαθέσιμος χώρος για την αποθήκευση του αρχείου %s.';  
 $strNoTablesFound = 'Δεν βρέθηκαν Πίνακες στη βάση.';
 $strNoUsersFound = 'Δεν βρέθηκαν χρήστες.';
-$strNoUsersSelected = 'Δεν επιλέξατε χρήστες.'; 
 $strNoValidateSQL = 'Skip Validate SQL';  
 $strNone = 'Κανένα';
 $strNotNumber = 'Αυτό δεν είναι αριθμός!';
@@ -397,7 +372,6 @@ $strOperations = 'Λειτουργίες';
 $strOptimizeTable = 'Βελτιστοποίηση Πίνακα';
 $strOptionalControls = 'Προεραιτικό. Ρυθμίζει πώς να γίνεται η ανάγνωση και η εγγραφή ειδικών χαρακτήρων.';
 $strOptionally = 'ΠΡΟΑΙΡΕΤΙΚΑ';
-$strOptions = 'Επιλογές';  
 $strOr = 'Ή';
 $strOverhead = 'Επιβάρυνση';
 $strOverwriteExisting = 'Αντικατάσταση υπαρχόντων αρχείων';  
@@ -412,7 +386,6 @@ $strPasswordChanged = 'Ο Κωδικός Πρόσβασης για τον χρή
 $strPasswordEmpty = 'Ο Κωδικός Πρόσβασης είναι κενός!';
 $strPasswordNotSame = 'Οι κωδικοί πρόσβασης δεν είναι ίδιοι!';
 $strPdfDbSchema = 'Σχήμα της βάσης "%s" - Σελίδα %s';  
-$strPdfInvalidPageNum = 'Δεν ορίστηκε αριθμός σελίδας PDF!';  
 $strPdfInvalidTblName = 'Ο πίνακας "%s" δεν υπάρχει!';  
 $strPdfNoTables = 'Δεν υπάρχουν πίνακες';
 $strPerHour = 'ανά ώρα'; 
@@ -426,7 +399,6 @@ $strPortrait = 'Κάθετη διάταξη';
 $strPos1 = 'Αρχή';
 $strPrevious = 'Προηγούμενο';
 $strPrimary = 'Πρωτεύον';
-$strPrimaryKey = 'Πρωτεύον κλειδί';
 $strPrimaryKeyHasBeenDropped = 'Το πρωτεύον κλειδί διεγράφη';
 $strPrimaryKeyName = 'Το όνομα του πρωτεύοντος κλειδιού πρέπει να είναι... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>πρέπει</b> να είναι το όνομα του πρωτεύοντος κλειδιού και <b>μόνο αυτού</b> !)';
@@ -464,15 +436,12 @@ $strPrivDescUsage = 'Χωρίς προνόμια.';
 $strPrivileges = 'Προνόμια';
 $strPrivilegesReloaded = 'Τα προνόμια επαναφορτώθηκαν επιτυχώς.'; 
 $strProcesslist = 'Λίστα διεργασιών'; 
-$strProperties = 'Ιδιότητες';
 $strPutColNames = 'Εμφάνιση ονομάτων πεδίων στην πρώτη γραμμή';  
 
 $strQBE = 'Επερώτημα κατά παράδειγμα';
 $strQBEDel = 'Διαγραφή';
 $strQBEIns = 'Εισαγωγή';
 $strQueryFrame = 'Παράθυρο επερωτήματος';
-$strQueryFrameDebug = 'Πληροφορίες διάγνωσης προβλημάτων';
-$strQueryFrameDebugBox = 'Ενεργές μεταβλητές για τη φόρμα επερωτημάτων:\nΒΔ: %s\nΠίνακας: %s\nΔιακομιστής: %s\n\nΤρέχουσες μεταβλητές για τη φόρμα επερωτημάτων:\nΒΔ: %s\nΠίνακας: %s\nΔιακομιστής: %s\n\nΤοποθεσία παραθύρου κλήσης: %s\nΤοποθεσία frameset: %s.';
 $strQueryOnDb = 'Εντολή SQL στη βάση <b>%s</b>:';
 $strQuerySQLHistory = 'Ιστορικό SQL';
 $strQueryStatistics = '<b>Στατιστικά επερωτημάτων</b>: Από την έναρξη λειτουργίας, %s επερωτήματα έχουν σταλεί στον διακομιστή.';
@@ -491,7 +460,6 @@ $strRelations = 'Σχέσεις';
 $strReloadFailed = 'Η επανεκκίνηση της MySQL απέτυχε.';
 $strReloadMySQL = 'Επανεκκίνηση της MySQL';
 $strReloadingThePrivileges = 'Επαναφόρτωση προνομίων'; 
-$strRememberReload = 'Υπενθύμιση: πρέπει να επανεκκινήσετε τον διακομιστή.';
 $strRemoveSelectedUsers = 'Διαγραφή των επιλεγμένων χρηστών'; 
 $strRenameTable = 'Μετονομασία πίνακα σε';
 $strRenameTableOK = 'Ο Πίνακας %s μετονομάσθηκε σε %s';
@@ -504,10 +472,7 @@ $strResourceLimits = 'Όρια πόρων';
 $strRevoke = 'Ανάκληση';
 $strRevokeAndDelete = 'Ανάκληση όλων των ενεργών προνομίων από τους χρήστες και διαγραφή τους.'; 
 $strRevokeAndDeleteDescr = 'Οι χρήστες θα συνεχίσουν να έχουν το προνόμιο USAGE μέχρις ότου επαναφορτωθούν τα προνόμια.'; 
-$strRevokeGrant = 'Ανάκληση Παραχώρησης';
-$strRevokeGrantMessage = 'Ανακαλέσατε τα προνόμια Παραχώρησης του %s';
 $strRevokeMessage = 'Ανακαλέσατε τα προνόμια για %s';
-$strRevokePriv = 'Ανάκληση προνομίων';
 $strRowLength = 'Μέγεθος Γραμμής';
 $strRowSize = ' Μέγεθος Εγγραφής ';
 $strRows = 'Εγγραφές';
@@ -545,7 +510,6 @@ $strSearchOption4 = 'ως regular expression';
 $strSearchResultsFor = 'Αποτελέσματα αναζήτησης για "<i>%s</i>" %s:';
 $strSearchType = 'Έυρεση:';
 $strSecretRequired = 'Το αρχείο ρυθμίσεων χρειάζεται τώρα μία μυστική φράση-κλειδί (blowfish_secret).';  
-$strSelect = 'Επιλογή';
 $strSelectADb = 'Παρακαλώ επιλέξτε μία βάση δεδομένων';
 $strSelectAll = 'Επιλογή όλων';
 $strSelectFields = 'Επιλογή πεδίων (τουλάχιστον ένα)';
@@ -553,7 +517,7 @@ $strSelectNumRows = 'στην εντολή';
 $strSelectTables = 'Επιλογή Πινάκων';  
 $strSend = 'Αποστολή';
 $strSent = 'Εστάλησαν'; 
-$strServer = 'Διακομιστής %s';  
+$strServer = 'Διακομιστής';  
 $strServerChoice = 'Επιλογή Διακομιστή';
 $strServerStatus = 'Πληροφορίες εκτέλεσης'; 
 $strServerStatusUptime = 'Αυτός ο διακομιστής MySQL λειτουργεί για %s. Ξεκίνησε στις %s.'; 
@@ -567,7 +531,6 @@ $strSetEnumVal = 'Αν ο τύπος του πεδίου είναι «enum» ή
 $strShow = 'Εμφάνιση';
 $strShowAll = 'Εμφάνιση όλων';
 $strShowColor = 'Εμφάνιση χρωμάτων';  
-$strShowCols = 'Εμφάνιση στηλών';
 $strShowDatadictAs = 'Μορφή λεξικού δεδομένων';  
 $strShowFullQueries = 'Πλήρης εμφάνιση επερωτημάτων';  
 $strShowGrid = 'Εμφάνιση πλέγματος';  
@@ -636,7 +599,6 @@ $strTransformation_text_plain__formatted = 'Διατηρεί την αρχική
 $strTransformation_text_plain__imagelink = 'Εμφανίζει μία εικόνα και ένα σύνδεσμο, το πεδίο περιέχει το όνομα αρχείου. Η πρώτη επιλογή είναι ένα πρόθεμα όπως "http://domain.com/", η δεύτερη επιλογή είναι το πλάτος σε pixels, η τρίτη είναι το ύψος.';  
 $strTransformation_text_plain__link = 'Εμφανίζει ένα σύνδεσμο, το πεδίο περιέχει το όνομα αρχείου. Η πρώτη επιλογή είναι ένα πρόθεμα όπως "http://domain.com/", η δεύτερη επιλογή είναι ένας τίτλος για τον σύνδεσμο.';  
 $strTransformation_text_plain__substr = 'Εμφανίζει μόνο μέρος ενός αλφαριθμητικού. Η πρώτη επιλογή είναι η θέση στην οποία ξεκινά η εμφάνιση του κειμένου (Εξ\' ορισμού 0). Η δεύτερη επιλογή είναι το μήκος του κειμένου. Αν μείνει κενό θα επιστραφεί όλο το αλφαριθμητικό. Η τρίτη επιλογή καθορίζει ποιοι χαρακτήρες θα ακολουθούν το κείμενο όταν εμφανίζεται μέρος του (Εξ\' ορισμού: ...) .';
-$strTransformation_text_plain__unformatted = 'Εμφανίζει τον κώδικά HTML ως οντότητες HTML. Δεν γίνεται μορφοποίηση HTML.';
 $strTruncateQueries = 'Αποκοπή εμφανιζόμενων επερωτημάτων';  
 $strTurkish = 'Τουρκικά';  
 $strType = 'Τύπος';
@@ -649,7 +611,6 @@ $strUnknown = 'άγνωστο';
 $strUnselectAll = 'Απεπιλογή όλων';
 $strUpdComTab = 'Παρακαλώ διαβάστε στην τεκμηρίωση για το πως μπορείτε να ανανεώσετε τον πίνακα Column_comments';  
 $strUpdatePrivMessage = 'Τα προνόμια του χρήστη %s ενημερώθηκαν.';
-$strUpdateProfile = 'Ενημέρωση στοιχείων:';
 $strUpdateProfileMessage = 'Τα στοιχεία ανανεώθηκαν.';
 $strUpdateQuery = 'Ενημέρωση της εντολής';
 $strUsage = 'Χρήση';
@@ -664,7 +625,6 @@ $strUserEmpty = 'Το όνομα του χρήστη είναι κενό!';
 $strUserName = 'Όνομα χρήστη';
 $strUserNotFound = 'Ο επιλεγμένος χρήστης δεν βρέθηκε στον πίνακα προνομίων.'; 
 $strUserOverview = 'Περίληψη χρηστών'; 
-$strUsers = 'Χρήστες';
 $strUsersDeleted = 'Οι επιλεγμένοι χρήστες διεγράφησαν επιτυχώς.'; 
 $strUsersHavingAccessToDb = 'Χρήστες με πρόσβαση στη βάση &quot;%s&quot;';  
 
@@ -721,7 +681,7 @@ $strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
 $strConstraintsForTable = 'Constraints for table';  //to translate
 $strBookmarkOptions = 'Bookmark options';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
-$strCheckOverhead = 'Check overheaded';  //to translate
+$strCheckOverhead = 'Check tables with overhead';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
 $strDelayedInserts = 'Use delayed inserts';  //to translate
 $strSQLExportType = 'Export type';  //to translate
@@ -730,5 +690,119 @@ $strGeorgian = 'Georgian';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strMaximumSize = 'Maximum size: %s%s';  //to translate
+$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
+$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
+$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
+$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
+$strIgnoreInserts = 'Use ignore inserts';  //to translate
+$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
+$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
+$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
+$strAfterInsertSame = 'Go back to this page';  //to translate
+$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
+$strDatabaseEmpty = 'The database name is empty!';  //to translate
+$strDBRename = 'Rename database to';  //to translate
+$strOperator = 'Operator';  //to translate
+$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
+$strCalendar = 'Calendar';  //to translate
+$strRefresh = 'Refresh';  //to translate
+$strDefragment = 'Defragment table';  //to translate
+$strNoRowsSelected = 'No rows selected';  //to translate
 $strSpanish = 'Spanish';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
+$strServerNotResponding = 'The server is not responding';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
+$strIcelandic = 'Icelandic';  //to translate
+$strLatvian = 'Latvian';  //to translate
+$strPolish = 'Polish';  //to translate
+$strRomanian = 'Romanian';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
