@@ -1,8 +1,8 @@
 <?php
-/* $Id: italian-iso-8859-1.inc.php,v 2.6.2.2 2004/06/07 10:09:55 rabus Exp $ */
+/* $Id: italian-iso-8859-1.inc.php,v 2.73 2005/03/30 19:22:54 lem9 Exp $ */
 
 /**
- * Translated by: Pietro Danesi <danone at users.sourceforge.net>  2002-03-29
+ * translated by: Pietro Danesi <danone at users.sourceforge.net>  2002-03-29
  * Revised by:    "DPhantom" <dphantom at users.sourceforge.net>  2002-04-16
  */
 
@@ -33,10 +33,11 @@ $strAddConstraints = 'Aggiungi vincoli';
 $strAddDeleteColumn = 'Aggiungi/Cancella campo';
 $strAddDeleteRow = 'Aggiungi/Cancella criterio';
 $strAddDropDatabase = 'Aggiungi DROP DATABASE';
+$strAddFields = 'Aggiungi %s campo(i)';
+$strAddHeaderComment = 'Aggiunge un commento personalizzato all\'header (\\n per tornare a capo)';
+$strAddIfNotExists = 'Aggiunge IF NOT EXISTS';
 $strAddIntoComments = 'Aggiungi nei commenti';
 $strAddNewField = 'Aggiungi un nuovo campo';
-$strAddPriv = 'Aggiungi un nuovo privilegio';
-$strAddPrivMessage = 'Hai aggiunto un nuovo privilegio.';
 $strAddPrivilegesOnDb = 'Aggiungi privilegi sul seguente database';
 $strAddPrivilegesOnTbl = 'Aggiungi privilegi sulla seguente tabella';
 $strAddSearchConditions = 'Aggiungi condizioni di ricerca (corpo della clausola "where"):';
@@ -46,10 +47,12 @@ $strAddUserMessage = 'Hai aggiunto un nuovo utente.';
 $strAddedColumnComment = 'Agginto commento sulla colonna';
 $strAddedColumnRelation = 'Aggiunta Relazione per la colonna';
 $strAdministration = 'Amministrazione';
-$strAffectedRows = 'Righe affette:';
+$strAffectedRows = 'Righe interessate:';
 $strAfter = 'Dopo %s';
 $strAfterInsertBack = 'Indietro';
 $strAfterInsertNewInsert = 'Inserisci un nuovo record';
+$strAfterInsertNext = 'Modifica il record successivo';
+$strAfterInsertSame = 'Torna a questa pagina';
 $strAll = 'Tutti';
 $strAllTableSameWidth = 'mostra tutte le Tabelle con la stessa larghezza?';
 $strAlterOrderBy = 'Altera tabella ordinata per';
@@ -57,11 +60,9 @@ $strAnIndex = 'Un indice  stato aggiunto in %s';
 $strAnalyzeTable = 'Analizza tabella';
 $strAnd = 'E';
 $strAny = 'Qualsiasi';
-$strAnyColumn = 'Qualsiasi colonna';
-$strAnyDatabase = 'Qualsiasi database';
 $strAnyHost = 'Qualsiasi host';
-$strAnyTable = 'Qualsiasi tabella';
 $strAnyUser = 'Qualsiasi utente';
+$strApproximateCount = 'Pu essere approssimato. Vedere FAQ 3.11';
 $strArabic = 'Arabo';
 $strArmenian = 'Armeno';
 $strAscending = 'Crescente';
@@ -75,8 +76,15 @@ $strBack = 'Indietro';
 $strBaltic = 'Baltico';
 $strBeginCut = 'INIZIO CUT';
 $strBeginRaw = 'INIZIO RAW';
+$strBinLogEventType = 'Tipo di evento';
+$strBinLogInfo = 'Informazioni';
+$strBinLogName = 'Nome del Log';
+$strBinLogOriginalPosition = 'Posizione originale';
+$strBinLogPosition = 'Posizione';
+$strBinLogServerId = 'ID del server';
 $strBinary = 'Binario';
 $strBinaryDoNotEdit = 'Tipo di dato Binario - non modificare';
+$strBinaryLog = 'Log binario';
 $strBookmarkAllUsers = 'Permetti ad ogni utente di accedere a questo bookmark';
 $strBookmarkDeleted = 'Il bookmark  stato cancellato.';
 $strBookmarkLabel = 'Etichetta';
@@ -91,9 +99,9 @@ $strBzError = 'phpMyAdmin non  capace di comprimere il dump a causa dell\'estens
 $strBzip = '"compresso con bzip2"';
 
 $strCSVOptions = 'Opzioni CSV';
+$strCalendar = 'Calendario';
 $strCannotLogin = 'Impossibile eseguire il login nel server MySQL';
 $strCantLoad = 'Impossibile caricare l\'estensione %s,<br />prego controllare la configurazione di PHP';
-$strCantLoadMySQL = 'impossibile caricare l\'estensione MySQL,<br />controlla la configurazione di PHP.';
 $strCantLoadRecodeIconv = 'Impossibile caricare l\'estensione iconv o recode necessaria per la conversione del set di caratteri, configurare il PHP per permettere di utilizzare queste estenzioni o disabilitare la conversione dei set di caratteri in phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Impossibile rinominare l\'indice a PRIMARIO!';
 $strCantUseRecodeIconv = 'Impossibile utilizzare le funzioni iconv o libiconv o recode_string in quanto l\'estensione deve essere caricata. Controllare la configurazione del PHP.';
@@ -116,7 +124,6 @@ $strCharsetOfFile = 'Set di caratteri del file:';
 $strCharsets = 'Set di caratteri';
 $strCharsetsAndCollations = 'Set di Caratteri e Collations';
 $strCheckAll = 'Seleziona tutti';
-$strCheckDbPriv = 'Controlla i privilegi del database';
 $strCheckOverhead = 'Controllo addizionale';
 $strCheckPrivs = 'Controlla i privilegi';
 $strCheckPrivsLong = 'Controlla i privilegi per il database &quot;%s&quot;.';
@@ -124,25 +131,26 @@ $strCheckTable = 'Controlla tabella';
 $strChoosePage = 'Prego scegliere una Page da modificare';
 $strColComFeat = 'Visualizzazione commenti delle colonne';
 $strCollation = 'Collation';
-$strColumn = 'Colonna';
 $strColumnNames = 'Nomi delle colonne';
 $strColumnPrivileges = 'Privilegi relativi alle colonne';
 $strCommand = 'Comando';
 $strComments = 'Commenti';
+$strCommentsForTable = 'COMMENTS FOR TABLE';
+$strCompatibleHashing = 'Compatibile con MySQL&nbsp;4.0';
 $strCompleteInserts = 'Inserimenti completi';
 $strCompression = 'Compressione';
 $strConfigFileError = 'phpMyAdmin non riesce a leggere il file di configurazione!<br />Questo pu accadere se il php trova un parse error in esso oppure il php non trova il file.<br />Richiamate il file di configurazione direttamente utilizzando il link sotto e leggete il/i messaggio/i di errore del php che ricevete. Nella maggior parte dei casi ci sono un apostrofo o una virgoletta mancanti.<br />Se ricevete una pagina bianca, allora  tutto a posto.';
 $strConfigureTableCoord = 'Prego, configurare le coordinate per la tabella %s';
-$strConfirm = 'Sicuro di volerlo fare?';
 $strConnectionError = 'Impossibile connettersi: impostazioni non valide.';
 $strConnections = 'Connessioni';
 $strConstraintsForDumped = 'Limiti per le tabelle scaricate';
 $strConstraintsForTable = 'Limiti per la tabella';
 $strCookiesRequired = 'Da questo punto in poi, i cookies devono essere abilitati.';
+$strCopyDatabaseOK = 'Il Database %s  stato copiato in %s';
 $strCopyTable = 'Copia la tabella nel (database<b>.</b>tabella):';
 $strCopyTableOK = 'La tabella %s  stata copiata su %s.';
 $strCopyTableSameNames = 'Impossibile copiare la tabella su se stessa!';
-$strCouldNotKill = 'phpMyAdmin non  capace di terminare il thread %s. Probabilmente  gi stato terminato.';
+$strCouldNotKill = 'phpMyAdmin non  in grado di terminare il thread %s. Probabilmente  gi stato terminato.';
 $strCreate = 'Crea';
 $strCreateIndex = 'Crea un indice su &nbsp;%s&nbsp;columns';
 $strCreateIndexTopic = 'Crea un nuovo indice';
@@ -158,6 +166,7 @@ $strCzech = 'Ceco';
 $strCzechSlovak = 'Ceco-Slovacco';
 
 $strDBComment = 'Commento al Database: ';
+$strDBCopy = 'Copia il Database in';
 $strDBGContext = 'Contesto';
 $strDBGContextID = 'ID del Contesto';
 $strDBGHits = 'Hits';
@@ -167,15 +176,16 @@ $strDBGMinTimeMs = 'Tempo minimo, ms';
 $strDBGModule = 'Modulo';
 $strDBGTimePerHitMs = 'Tempo/Hit, ms';
 $strDBGTotalTimeMs = 'Tempo totale, ms';
+$strDBRename = 'Rinomina il DataBase in';
 $strDanish = 'Danese';
 $strData = 'Dati';
 $strDataDict = 'Data Dictionary';
 $strDataOnly = 'Solo dati';
-$strDatabase = 'Database ';
+$strDatabase = 'Database';
+$strDatabaseEmpty = 'Il nome del DataBase  vuoto!';
 $strDatabaseExportOptions = 'Opzioni di esportazione del database';
 $strDatabaseHasBeenDropped = 'Il Database %s  stato eliminato.';
 $strDatabaseNoTable = 'Questo database non contiene tabelle!';
-$strDatabaseWildcard = 'Database (wildcards permesse):';
 $strDatabases = 'Database';
 $strDatabasesDropped = '%s databases sono stati cancellati correttamente.';
 $strDatabasesStats = 'Statistiche dei databases';
@@ -185,22 +195,22 @@ $strDatabasesStatsHeavyTraffic = 'N.B.: Abilitare qui le statistiche del Databas
 $strDbPrivileges = 'Privilegi specifici al database';
 $strDbSpecific = 'specifico del database';
 $strDefault = 'Predefinito';
+$strDefaultEngine = '%s  il motore di memorizzazione predefinito su questo server MySQL.';
 $strDefaultValueHelp = 'Per i valori predefiniti, prego inserire un singolo valore, senza backslashes escaping o virgolette, utilizzando questo formato: a';
+$strDefragment = 'Deframmenta la tabella';
 $strDelOld = 'La Pagina corrente contiene Riferimenti a Tabelle che non esistono pi. Volete cancellare questi Riferimenti?';
 $strDelayedInserts = 'Utilizza inserimenti ritardati';
 $strDelete = 'Cancella';
 $strDeleteAndFlush = 'Cancella gli utenti e dopo ricarica i privilegi.';
 $strDeleteAndFlushDescr = 'Questa  la vita pi giusta, ma il caricamento dei privilegi pu durare qualche secondo.';
-$strDeleteFailed = 'Cancellazione fallita!';
-$strDeleteUserMessage = 'Hai cancellato l\'utente %s.';
 $strDeleted = 'La riga  stata cancellata';
 $strDeletedRows = 'Righe cancellate:';
 $strDeleting = 'Cancellazione in corso di %s';
 $strDescending = 'Decrescente';
 $strDescription = 'Descrizione';
 $strDictionary = 'dizionario';
+$strDisableForeignChecks = 'Disabilita i controlli sulle chiavi straniere';
 $strDisabled = 'Disabilitata';
-$strDisplay = 'Visualizza';
 $strDisplayFeat = 'Mostra Caratteristiche';
 $strDisplayOrder = 'Ordine di visualizzazione:';
 $strDisplayPDF = 'Mostra lo schema del PDF';
@@ -208,11 +218,9 @@ $strDoAQuery = 'Esegui "query da esempio" (carattere jolly: "%")';
 $strDoYouReally = 'Confermi: ';
 $strDocu = 'Documentazione';
 $strDrop = 'Elimina';
-$strDropDB = 'Elimina database %s';
+$strDropDatabaseStrongWarning = 'Si sta per DISTRUGGERE COMPLETAMENTE un intero DataBase!';
 $strDropSelectedDatabases = 'Elimina i Databases selezionati';
-$strDropTable = 'Elimina la tabella';
 $strDropUsersDb = 'Elimina i databases gli stessi nomi degli utenti.';
-$strDumpComments = 'Includi commenti alle colonne come commenti-SQL in linea';
 $strDumpSaved = 'Il dump  stato salvato sul file %s.';
 $strDumpXRows = 'Dump di %s righe a partire dalla riga %s.';
 $strDumpingData = 'Dump dei dati per la tabella';
@@ -225,19 +233,24 @@ $strEffective = 'Effettivo';
 $strEmpty = 'Svuota';
 $strEmptyResultSet = 'MySQL ha restituito un insieme vuoto (i.e. zero righe).';
 $strEnabled = 'Abilitata';
+$strEncloseInTransaction = 'Includi export in una transazione';
 $strEnd = 'Fine';
 $strEndCut = 'FINE CUT';
 $strEndRaw = 'FINE RAW';
+$strEngineAvailable = '%s  disponibile su questo server MySQL.';
+$strEngineDisabled = '%s  stato disabilitato su questo server MySQL.';
+$strEngineUnsupported = 'Questo server MySQL non supporta il motore di memorizzazione %s.';
+$strEngines = 'Motori';
 $strEnglish = 'Inglese';
 $strEnglishPrivileges = 'Nota: i nomi dei privilegi di MySQL sono in Inglese';
 $strError = 'Errore';
+$strEscapeWildcards = 'I caratteri jolly _ e % dovrebbero essere preceduti da un \ per l\'utilizzo letterale';
 $strEstonian = 'Estone';
 $strExcelEdition = 'Edizione Excel';
 $strExcelOptions = 'Opzioni di Excel';
 $strExecuteBookmarked = 'Esegue la query dalle preferite';
 $strExplain = 'Spiega SQL';
 $strExport = 'Esporta';
-$strExportToXML = 'Esporta in formato XML';
 $strExtendedInserts = 'Inserimenti estesi';
 $strExtra = 'Extra';
 
@@ -272,7 +285,6 @@ $strGlobalPrivileges = 'Privilegi globali';
 $strGlobalValue = 'Valore globale';
 $strGo = 'Esegui';
 $strGrantOption = 'Grant';
-$strGrants = 'Permetti';
 $strGreek = 'Greco';
 $strGzip = '"compresso con gzip"';
 
@@ -280,17 +292,19 @@ $strHasBeenAltered = ' stato modificato.';
 $strHasBeenCreated = ' stato creato.';
 $strHaveToShow = 'Devi scegliere almeno una Colonna da mostrare';
 $strHebrew = 'Ebreo';
+$strHexForBinary = 'Usa l\'esadecimale per i dati binari';
 $strHome = 'Home';
 $strHomepageOfficial = 'Home page ufficiale di phpMyAdmin';
-$strHomepageSourceforge = 'Home page di phpMyAdmin su sourceforge.net';
 $strHost = 'Host';
 $strHostEmpty = 'Il nome di host  vuoto!';
 $strHungarian = 'Ungherese';
 
+$strIcelandic = 'Islandese';
 $strId = 'ID';
 $strIdxFulltext = 'Testo completo';
 $strIfYouWish = 'Per caricare i dati solo per alcune colonne della tabella, specificare la lista dei campi (separati da virgole).';
 $strIgnore = 'Ignora';
+$strIgnoreInserts = 'Utilizza gli IGNORE INSERTS';
 $strIgnoringFile = 'File %s ignorato';
 $strImportDocSQL = 'Importa Files docSQL';
 $strImportFiles = 'Importa files';
@@ -300,11 +314,16 @@ $strIndex = 'Indice';
 $strIndexHasBeenDropped = 'L\'indice %s  stato eliminato';
 $strIndexName = 'Nome dell\'indice&nbsp;:';
 $strIndexType = 'Tipo di indice&nbsp;:';
+$strIndexWarningMultiple = 'Pi di una chiave %s  stata creata per la colonna `%s`';
+$strIndexWarningPrimary = 'Le chiavi PRIMARY e INDEX non dovrebbero essere assegnate entrambe per la colonna `%s`';
+$strIndexWarningTable = 'Problemi con gli indici della tabella `%s`';
+$strIndexWarningUnique = 'Le chiavi UNIQUE e INDEX non dovrebbero essere assegnate entrambe per la colonna `%s`';
 $strIndexes = 'Indici';
 $strInnodbStat = 'Stato InnoDB';
 $strInsecureMySQL = 'Il file di configurazione in uso contiene impostazioni (root con nessuna password) che corrispondono ai privilegi dell\'account MySQL predefinito. Un server MySQL funzionante con queste impostazioni  aperto a intrusioni, e si dovrebbe realmente riparare a questa falla nella sicurezza.';
 $strInsert = 'Inserisci';
 $strInsertAsNewRow = 'Inserisci come nuova riga';
+$strInsertBookmarkTitle = 'Inserire il titolo del segnalibro';
 $strInsertNewRow = 'Inserisci una nuova riga';
 $strInsertTextfiles = 'Inserisci un file di testo nella tabella';
 $strInsertedRowId = 'Inserito id riga:';
@@ -312,7 +331,6 @@ $strInsertedRows = 'Righe inserite:';
 $strInstructions = 'Istruzioni';
 $strInternalNotNecessary = '* Non  necessaria una relazione interna quando gi esiste in InnoDB.';
 $strInternalRelations = 'Relazioni interne';
-$strInvalidName = '"%s"  una parola riservata; non  possibile utilizzarla come nome di database/tabella/campo.';
 
 $strJapanese = 'Giapponese';
 $strJumpToDB = 'Passa al database &quot;%s&quot;.';
@@ -334,11 +352,10 @@ $strLatexContinuedCaption = 'Sottotitolo della tabella continuato';
 $strLatexIncludeCaption = 'Includi sottotitolo della tabella';
 $strLatexLabel = 'Chiave etichetta';
 $strLatexStructure = 'Struttura della tabella __TABLE__';
-$strLength = 'Lunghezza';
+$strLatvian = 'Lituano';
 $strLengthSet = 'Lunghezza/Set*';
 $strLimitNumRows = 'record per pagina';
 $strLineFeed = 'Fine riga: \\n';
-$strLines = 'Record';
 $strLinesTerminatedBy = 'Linee terminate da';
 $strLinkNotFound = 'Link non trovato';
 $strLinksTo = 'Collegamenti a';
@@ -354,11 +371,11 @@ $strLogin = 'Connetti';
 $strLoginInformation = 'Informazioni di Login';
 $strLogout = 'Disconnetti';
 
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';
 $strMIME_MIMEtype = 'tipo MIME';
 $strMIME_available_mime = 'Tipi-MIME disponibili';
 $strMIME_available_transform = 'Trasformazioni disponibili';
 $strMIME_description = 'Descrizione';
-$strMIME_file = 'Nome file';
 $strMIME_nodescription = 'Nessuna descrizione  disponibile per questa trasformazione.<br />Prego, chiedere all\'autore cosa %s faccia.';
 $strMIME_transformation = 'Trasformazione del Browser';
 $strMIME_transformation_note = 'Per una lista di opzioni di trasformazione disponibili e le loro rispettive trasformazioni di tipi-MIME, cliccate su %strasformazione descrizioni%s';
@@ -366,7 +383,8 @@ $strMIME_transformation_options = 'Opzioni di Transformation';
 $strMIME_transformation_options_note = 'Prego, immettere i valori per le opzioni di trasformazioneutilizzando questo formato: \'a\',\'b\',\'c\'...<br />Se c\' la necessit di immettere un backslash ("\") o un apostrofo ("\'") tra questi valori, essi vanno backslashati (per es. \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'Tipi-MIME stampati in italics non hanno una funzione di trasformazione separata';
 $strMaximumSize = 'Dimensione massima: %s%s';
-$strMissingBracket = 'Parentesi mancante';
+$strMbExtensionMissing = 'L\'estensione PHP mbstring non  stata trovata e sembra che si stia utilizzando un set di caratteri multibyte. Senza l\'estensione mbstring, phpMyAdmin non  in grado di dividere correttamente le stringhe di caratteri e questo pu portare a risultati inaspettati.';
+$strMbOverloadWarning = 'Avete abilitato mbstring.func_overload nella configurazione del PHP. Questa opzione  incompatibile con phpMyAdmin e potrebbe causare la corruzione di alcuni dati!';
 $strModifications = 'Le modifiche sono state salvate';
 $strModify = 'Modifica';
 $strModifyIndexTopic = 'Modifica un indice';
@@ -376,7 +394,20 @@ $strMoveTableOK = 'La tabella %s  stata spostata in %s.';
 $strMoveTableSameNames = 'Impossibile spostare la tabella su se stessa!';
 $strMultilingual = 'multilingua';
 $strMustSelectFile = 'Si dovrebbe selezionare il file che si vuole inserire.';
+$strMyISAMDataPointerSize = 'Domensione del puntatore dati';
+$strMyISAMDataPointerSizeDesc = 'Dimensione del puntatore predefinito in Bytes, che deve essere usata da CREATE TABLE per le tabelle MyISAM quando non  stata specificata l\'opzione MAX_ROWS.';
+$strMyISAMMaxExtraSortFileSize = 'Dimensione massima per i files temporanei nella creazione di un indice';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Se il file temporaneo  usato per la creazione veloce di un indice MyISAM, occuperebbe pi spazio dell\'utilizzo del metodo key cache con la quantit ivi specificata: perci si deve prediligere il metodo key cache.';
+$strMyISAMMaxSortFileSize = 'Dimensione massima dei file temporanei di ordinamento';
+$strMyISAMMaxSortFileSizeDesc = 'La dimensione massima dei file temporanei MySQL pu essere utilizzata nella rigenerazione di un indice MyISAM (durante un REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Modalit di ripristino automatico';
+$strMyISAMRecoverOptionsDesc = 'La modalit di irppristino automatico di tabelle MyISAM corrotte, come impostato tramite l\'opzione di lan cio del server --myisam-recover.';
+$strMyISAMRepairThreads = 'Thread di riparazione';
+$strMyISAMRepairThreadsDesc = 'Se questo valore  maggiore di 1, gli indici della tabella MyISAM vengono creati in parallelo (ogni indice nel suo thread) durante il processo di ordinamento Repair by.';
+$strMyISAMSortBufferSize = 'Ordina la dimensione del buffer';
+$strMyISAMSortBufferSizeDesc = 'Il buffer che viene allocato nell\'ordinamento degli indici MyISAM durante un REPAIR TABLE o nella creazione degli indici con CREATE INDEX o ALTER TABLE.';
 $strMySQLCharset = 'Set di caratteri MySQL';
+$strMySQLConnectionCollation = 'collazione della connessione di MySQL';
 $strMySQLReloaded = 'MySQL riavviato.';
 $strMySQLSaid = 'Messaggio di MySQL: ';
 $strMySQLServerProcess = 'MySQL %pma_s1% in esecuzione su %pma_s2% come %pma_s3%';
@@ -385,11 +416,14 @@ $strMySQLShowStatus = 'Visualizza informazioni di runtime di MySQL';
 $strMySQLShowVars = 'Visualizza variabili di sistema di MySQL';
 
 $strName = 'Nome';
+$strNeedPrimaryKey = 'Si deve definire una chiave primaria per questa tabella.';
 $strNext = 'Prossimo';
 $strNo = ' No ';
+$strNoActivity = 'Nessuna attivit da %s secondi o pi, si prega di autenticarsi nuovamente';
 $strNoDatabases = 'Nessun database';
 $strNoDatabasesSelected = 'Nessun database selezionato.';
 $strNoDescription = 'nessuna Description';
+$strNoDetailsForEngine = 'Non  disponibile nessuna informazione dettagliata sullo stato di questo motore di memorizzazione.';
 $strNoDropDatabases = 'I comandi "DROP DATABASE" sono disabilitati.';
 $strNoExplain = 'Non Spiegare SQL';
 $strNoFrames = 'phpMyAdmin funziona meglio con browser che supportano frames';
@@ -403,10 +437,11 @@ $strNoPhp = 'senza codice PHP';
 $strNoPrivileges = 'Nessun Privilegio';
 $strNoQuery = 'Nessuna query SQL!';
 $strNoRights = 'Non hai i permessi per effettuare questa operazione!';
+$strNoRowsSelected = 'Nessuna riga selezionata';
 $strNoSpace = 'Spazio insufficiente per salvare il file %s.';
 $strNoTablesFound = 'Non ci sono tabelle nel database.';
+$strNoThemeSupport = 'Nessun supporto per i temi, si prega di controllare la configurazione e/o i temi nella cartella %s.';
 $strNoUsersFound = 'Nessun utente trovato.';
-$strNoUsersSelected = 'Nessun utente selezionato.';
 $strNoValidateSQL = 'Non Validare SQL';
 $strNone = 'Nessuno';
 $strNotNumber = 'Questo non  un numero!';
@@ -419,12 +454,12 @@ $strNumSearchResultsTotal = '<b>Totale:</b> <i>%s</i> corrispondenza/e';
 $strNumTables = 'Tabelle';
 
 $strOK = 'OK';
-$strOftenQuotation = 'In genere da doppi apici (virgolette). OPZIONALE indica che solo i campi <I>char</I> e <I>varchar</I> devono essere delimitati dal carattere indicato.';
+$strOftenQuotation = 'In genere da doppi apici (virgolette). OPZIONALE indica che solo i campi <i>char</i> e <i>varchar</i> devono essere delimitati dal carattere indicato.';
 $strOperations = 'Operazioni';
+$strOperator = 'Operatore';
 $strOptimizeTable = 'Ottimizza tabella';
 $strOptionalControls = 'Opzionale. Questo carattere controlla come scrivere o leggere i caratteri speciali.';
 $strOptionally = 'OPZIONALE';
-$strOptions = 'Opzioni';
 $strOr = 'Oppure';
 $strOverhead = 'In eccesso';
 $strOverwriteExisting = 'Sovrascrivi file(s) esistente/i';
@@ -437,23 +472,24 @@ $strPartialText = 'Testo parziale';
 $strPassword = 'Password';
 $strPasswordChanged = 'La password per l\'utente %s  cambiata con successo.';
 $strPasswordEmpty = 'La password  vuota!';
+$strPasswordHashing = 'Password Hashing';
 $strPasswordNotSame = 'La password non coincide!';
 $strPdfDbSchema = 'Schema del database "%s" - Pagina %s';
-$strPdfInvalidPageNum = 'Pagina del PDF non definita!';
 $strPdfInvalidTblName = 'La tabella "%s" non esiste!';
 $strPdfNoTables = 'Nessuna Tabella';
 $strPerHour = 'all\'ora';
 $strPerMinute = 'al minuto';
 $strPerSecond = 'al secondo';
+$strPersian = 'Persiano';
 $strPhoneBook = 'rubrica';
 $strPhp = 'Crea il codice PHP';
 $strPmaDocumentation = 'Documentazione di phpMyAdmin';
 $strPmaUriError = 'La direttiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> DEVE essere impostata nel file di configurazione!';
+$strPolish = 'Polacco';
 $strPortrait = 'Verticale';
 $strPos1 = 'Inizio';
 $strPrevious = 'Precedente';
 $strPrimary = 'Primaria';
-$strPrimaryKey = 'Chiave primaria';
 $strPrimaryKeyHasBeenDropped = 'La chiave primaria  stata eliminata';
 $strPrimaryKeyName = 'Il nome della chiave primaria deve essere... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>deve</b> essere il nome di, e <b>solo di</b>, una chiave primaria!)';
@@ -492,18 +528,14 @@ $strPrivDescUsage = 'Nessun privilegio.';
 $strPrivileges = 'Privilegi';
 $strPrivilegesReloaded = 'I privilegi sono stati ricaricati con successo.';
 $strProcesslist = 'Lista Processi';
-$strProperties = 'Propriet';
 $strPutColNames = 'Mette i nomi delle colonne alla prima riga';
 
 $strQBE = 'Query da esempio';
 $strQBEDel = 'Cancella';
 $strQBEIns = 'Aggiungi';
 $strQueryFrame = 'Finestra della Query';
-$strQueryFrameDebug = 'Informazioni di Debug';
-$strQueryFrameDebugBox = 'Variabili attive per il form della query:\nDB: %s\nTabella: %s\nServer: %s\n\nLe variabili correnti per il form della query:\nDB: %s\nTabella: %s\nServer: %s\n\nLocazione dell\'Opener: %s\nLocazione del Frameset: %s.';
 $strQueryOnDb = 'SQL-query sul database <b>%s</b>:';
 $strQuerySQLHistory = 'Storico dell\'SQL';
-$strQueryStatistics = '<b>Statistiche delle Query</b>: Dal suo avvio, sono state inviate al server %s queries.';
 $strQueryTime = 'La query ha impiegato %01.4f sec';
 $strQueryType = 'Tipo di Query';
 $strQueryWindowLock = 'Non sovrascrivere questa query da fuori della finestra';
@@ -512,15 +544,17 @@ $strReType = 'Reinserisci';
 $strReceived = 'Ricevuti';
 $strRecords = 'Record';
 $strReferentialIntegrity = 'Controlla l\'integrit delle referenze:';
+$strRefresh = 'Aggiorna';
 $strRelationNotWorking = 'Le caratteristiche aggiuntive sono state disattivate per funzionare con le tabelle linkate. Per scoprire perch clicca %squi%s.';
 $strRelationView = 'Vedi relazioni';
 $strRelationalSchema = 'Schema relazionale';
 $strRelations = 'Relazioni';
+$strRelationsForTable = 'RELATIONS FOR TABLE';
 $strReloadFailed = 'Riavvio di MySQL fallito.';
 $strReloadMySQL = 'Riavvia MySQL';
 $strReloadingThePrivileges = 'Caricamento dei privilegi in corso';
-$strRememberReload = 'Ricorda di riavviare MySQL.';
 $strRemoveSelectedUsers = 'Rimuove gli utenti selezionati';
+$strRenameDatabaseOK = 'Il DataBase %s  stato rinominato in %s';
 $strRenameTable = 'Rinomina la tabella in';
 $strRenameTableOK = 'La tabella %s  stata rinominata %s';
 $strRepairTable = 'Ripara tabella';
@@ -532,10 +566,8 @@ $strResourceLimits = 'Limiti di risorse';
 $strRevoke = 'Revoca';
 $strRevokeAndDelete = 'Revoca tutti i privilegi attivi agli utenti e dopo li cancella.';
 $strRevokeAndDeleteDescr = 'Gli utenti UTILIZZERANNO comunque il privilegio finch i privilegi non saranno ricaricati.';
-$strRevokeGrant = 'Revoca permessi';
-$strRevokeGrantMessage = 'Hai revocato i privilegi di permesso per %s';
 $strRevokeMessage = 'Hai revocato i privilegi per %s';
-$strRevokePriv = 'Revoca privilegi';
+$strRomanian = 'Rumeno';
 $strRowLength = 'Lunghezza riga';
 $strRowSize = 'Dimensione riga';
 $strRows = 'Righe';
@@ -551,6 +583,7 @@ $strRunning = 'in esecuzione su %s';
 $strRussian = 'Russo';
 
 $strSQL = 'SQL';
+$strSQLExportCompatibility = 'Compatibilit dell\'esportazione SQL';
 $strSQLExportType = 'Tipo di esportazione';
 $strSQLOptions = 'Opzioni SQL';
 $strSQLParserBugMessage = 'C\' la possibilit che ci sia un bug nel parser SQL. Per favore, esaminate la query accuratamente, e controllate che le virgolette siano corrette e non sbagliate. Altre possibili cause d\'errori possono essere che si stia cercando di uploadare un file binario al di fuori di un\'area di testo virgolettata. Si pu anche provare la query MySQL dalla riga di comando di MySQL. L\'errore qui sotto restituito dal server MySQL, se ce n\' uno, pu anche aiutare nella diagnostica del problema. Se ci sono ancora problemi, o se il parser SQL di phpMyAdmin sbaglia quando invece l\'interfaccia a riga di comando non mostra problemi, si pu ridurre la query SQL in ingresso alla singola query che causa problemi, e inviare un bug report con i dati riportati nella sezione CUT qui sotto:';
@@ -574,16 +607,17 @@ $strSearchOption4 = 'come espressione regolare';
 $strSearchResultsFor = 'Cerca i risultati per "<i>%s</i>" %s:';
 $strSearchType = 'Trova:';
 $strSecretRequired = 'Adesso c\' bisogno di una password per il file di configurazione (blowfish_secret).';
-$strSelect = 'Seleziona';
 $strSelectADb = 'Prego, selezionare un database';
 $strSelectAll = 'Seleziona Tutto';
+$strSelectBinaryLog = 'Selezionare il log binario da visualizzare';
 $strSelectFields = 'Seleziona campi (almeno uno):';
 $strSelectNumRows = 'nella query';
 $strSelectTables = 'Seleziona Tables';
 $strSend = 'Salva con nome...';
 $strSent = 'Spediti';
-$strServer = 'Server %s';
+$strServer = 'Server';
 $strServerChoice = 'Scelta del server';
+$strServerNotResponding = 'Il server non risponde';
 $strServerStatus = 'Informazioni di Runtime';
 $strServerStatusUptime = 'Questo server MySQL sta girando da %s. E\' stato avviato il %s.';
 $strServerTabProcesslist = 'Processi';
@@ -596,7 +630,6 @@ $strSetEnumVal = 'Se il tipo di campo  "enum" o "set", immettere i valori usando
 $strShow = 'Mostra';
 $strShowAll = 'Mostra tutti';
 $strShowColor = 'Mostra il colore';
-$strShowCols = 'Mostra le colonne';
 $strShowDatadictAs = 'Formato del Data Dictionary';
 $strShowFullQueries = 'Mostra query complete';
 $strShowGrid = 'Mostra la griglia';
@@ -608,19 +641,25 @@ $strShowingRecords = 'Visualizzazione record ';
 $strSimplifiedChinese = 'Cinese Semplificato';
 $strSingly = '(singolarmente)';
 $strSize = 'Dimensione';
+$strSlovak = 'Slovacco';
+$strSlovenian = 'Sloveno';
 $strSort = 'Ordinamento';
 $strSortByKey = 'Ordina per chiave';
 $strSpaceUsage = 'Spazio utilizzato';
+$strSpanish = 'Spagnolo';
 $strSplitWordsWithSpace = 'Le parole sono spezzate sulle spaziature (" ").';
 $strStatCheckTime = 'Ultimo controllo';
 $strStatCreateTime = 'Creazione';
 $strStatUpdateTime = 'Ultimo cambiamento';
 $strStatement = 'Istruzioni';
 $strStatus = 'Stato';
+$strStorageEngine = 'Motore di Memorizzazione';
+$strStorageEngines = 'Motori di Memorizzazione';
 $strStrucCSV = 'dati CSV';
 $strStrucData = 'Struttura e dati';
-$strStrucDrop = 'Aggiungi \'drop table\'';
-$strStrucExcelCSV = 'CSV per dati Ms Excel';
+$strStrucDrop = 'Aggiungi DROP TABLE';
+$strStrucExcelCSV = 'CSV per dati MS Excel';
+$strStrucNativeExcel = 'Dati nativi di MS Excel';
 $strStrucOnly = 'Solo struttura';
 $strStructPropose = 'Proponi la struttura della tabella';
 $strStructure = 'Struttura';
@@ -628,6 +667,7 @@ $strSubmit = 'Invia';
 $strSuccess = 'La query  stata eseguita con successo';
 $strSum = 'Totali';
 $strSwedish = 'Svedese';
+$strSwitchToDatabase = 'Passare al Database copiato';
 $strSwitchToTable = 'Passa alla tabella copiata';
 
 $strTable = 'Tabella';
@@ -642,12 +682,14 @@ $strTableOptions = 'Opzioni della tabella';
 $strTableStructure = 'Struttura della tabella';
 $strTableType = 'Tipo tabella';
 $strTables = '%s tabella(e)';
+$strTakeIt = 'prendilo';
 $strTblPrivileges = 'Privilegi relativi alle tabelle';
 $strTextAreaLength = ' A causa della sua lunghezza,<br /> questo campo non pu essere modificato ';
 $strThai = 'Thai';
 $strTheContent = 'Il contenuto del file  stato inserito.';
 $strTheContents = 'Il contenuto del file sostituisce le righe della tabella con la stessa chiave primaria o chiave unica.';
 $strTheTerminator = 'Il carattere terminatore dei campi.';
+$strTheme = 'Tema / Stile';
 $strThisHost = 'Questo Host';
 $strThisNotDirectory = 'Questa non  una directory';
 $strThreadSuccessfullyKilled = 'Il thread %s  stato terminato con successo.';
@@ -656,6 +698,7 @@ $strToggleScratchboard = '(dis)attiva scratchboard';
 $strTotal = 'Totali';
 $strTotalUC = 'Totale';
 $strTraditionalChinese = 'Cinese Tradizionale';
+$strTraditionalSpanish = 'Spagnolo tradizionale';
 $strTraffic = 'Traffico';
 $strTransformation_application_octetstream__download = 'Visualizza un collegamento per trasferire i dati di un campo in formato binario.  La prima opzione  il nome del file binario.  La seconda opzione  un nome di campo possibile di una riga della tabella che contiene il nome di schedario.  Se fornite una seconda opzione dovete avere la prima opzione settata ad una stringa vuota';
 $strTransformation_image_jpeg__inline = 'Mostra un thumbnalil cliccabile; opzioni: larghezza,altezza in pixel (mantiere la proporzione iniziale)';
@@ -667,7 +710,6 @@ $strTransformation_text_plain__formatted = 'Preserva l\'originale formattazione
 $strTransformation_text_plain__imagelink = 'Mostra un collegamento ad una immagine esterna; il campo contiene il nome del file; la prima opzione  un prefisso come "http://tuodominio.com/", la seconda opzione  la larghezza in pixel, la terza  l\'altezza.';
 $strTransformation_text_plain__link = 'Mostra un collegamento, il campo contiene il nome del file; la prima opzione  un prefisso come "http://tuodominio.com/", la seconda opzione  un titolo per il collegamento.';
 $strTransformation_text_plain__substr = 'Mostra soltanto una parte della stringa. La prima opzione  l\'offset che serve a definire dove inizia l\'output del vostro testo (Prefinito: 0). La seconda opzione  un offset che indica quanto testo viene restituito. Se vuoto, restituisce tutto il testo rimanente. La terza opzione definisce quali caratteri saranno aggiunti in fondo all\'output quando una soptto-stringa viene restituita (Predefinito: ...) .';
-$strTransformation_text_plain__unformatted = 'Mostra il codice HTML come entit HTML. Nessuna formattazione HTML viene applicata.';
 $strTruncateQueries = 'Tronca le Query Mostrate';
 $strTurkish = 'Turco';
 $strType = 'Tipo';
@@ -680,13 +722,13 @@ $strUnknown = 'sconosciuto';
 $strUnselectAll = 'Deseleziona Tutto';
 $strUpdComTab = 'Prego leggere la documentazione su come aggiornare la vostra tabella Column_comments';
 $strUpdatePrivMessage = 'Hai aggiornato i permessi per %s.';
-$strUpdateProfile = 'Aggiorna profilo:';
 $strUpdateProfileMessage = 'Il profilo  stato aggiornato.';
 $strUpdateQuery = 'Aggiorna Query';
 $strUpgrade = 'Si dovrebbe aggiornare %s alla versione %s o successiva.';
 $strUsage = 'Utilizzo';
 $strUseBackquotes = 'Usa i backquotes con i nomi delle tabelle e dei campi';
 $strUseHostTable = 'Utilizza la Tabella dell\'Host';
+$strUseTabKey = 'Usare il tasto TAB per spostare il cursore di valore in valore, o CTRL+frecce per spostarlo altrove';
 $strUseTables = 'Utilizza tabelle';
 $strUseTextField = 'Utilizza campo text';
 $strUseThisValue = 'Usa questa opzione';
@@ -696,7 +738,6 @@ $strUserEmpty = 'Il nome utente  vuoto!';
 $strUserName = 'Nome utente';
 $strUserNotFound = 'L\'utente selezionato non  stato trovato nella tabella dei privilegi.';
 $strUserOverview = 'Vista d\'insieme dell\'utente';
-$strUsers = 'Utenti';
 $strUsersDeleted = 'Gli utenti selezionati sono stati cancellati con successo.';
 $strUsersHavingAccessToDb = 'Utenti che hanno accesso a &quot;%s&quot;';
 
@@ -704,9 +745,11 @@ $strValidateSQL = 'Valida SQL';
 $strValidatorError = 'L\' SQL validator non pu essere inizializzato. Prego controllare di avere installato le estensioni php necessarie come descritto nella %sdocumentazione%s.';
 $strValue = 'Valore';
 $strVar = 'Variabile';
+$strView = 'Vista';
 $strViewDump = 'Visualizza dump (schema) della tabella';
 $strViewDumpDB = 'Visualizza dump (schema) del database';
 $strViewDumpDatabases = 'Visualizza il dump (schema) dei databases';
+$strViewHasBeenDropped = 'La vista %s  stata eliminata';
 
 $strWebServerUploadDirectory = 'directory di upload del web-server';
 $strWebServerUploadDirectoryError = 'La directory impostata per l\'upload non pu essere trovata';
@@ -726,5 +769,40 @@ $strYes = ' Si ';
 $strZeroRemovesTheLimit = 'N.B.: 0 (zero) significa nessun limite.';
 $strZip = '"compresso con zip"';
 
-$strSpanish = 'Spanish';  //to translate
+// To translate:
+
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+
+$strVersionInformation = 'Version information';  //to translate
+
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+
+$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
 ?>
