@@ -1,5 +1,5 @@
 <?php
-/* $Id: malay-iso-8859-1.inc.php,v 2.6.2.1 2004/06/07 10:09:55 rabus Exp $ */
+/* $Id: malay-iso-8859-1.inc.php,v 2.66 2005/03/30 19:23:27 lem9 Exp $ */
 
 /*
 Projek Penterjemahan (l10n) phpmyadmin.net boleh diakses di laman http://shapik.johordt.com/l10n
@@ -31,9 +31,7 @@ $number_decimal_separator = '.';
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 $timespanfmt = '%s hari, %s jam, %s minit dan %s saat';
 
-// Does the malay week only have 6 days??? Please re-translate!
-//$day_of_week = array('Aha', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum');
-$day_of_week = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
+$day_of_week = array('Aha', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum', 'Sab');
 $month = array('Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun', 'Jul', 'Ogos', 'Sept', 'Okt', 'Nov', 'Dis');
 // See http://www.php.net/manual/en/function.strftime.php to define the
 // variable below
@@ -46,8 +44,6 @@ $strAction = 'Aksi';
 $strAddDeleteColumn = 'Tambah/Padam Kolum Medan';
 $strAddDeleteRow = 'Tambah/Padam Baris Kriteria';
 $strAddNewField = 'Tambah medan baru';
-$strAddPriv = 'Tambah privilej baru';
-$strAddPrivMessage = 'Anda telah menambah privilej baru.';
 $strAddSearchConditions = 'Tambah kriteria carian (badan bagi klausa "where"):';
 $strAddToIndex = 'Tambah ke indeks &nbsp;%s&nbsp;kolum';
 $strAddUser = 'Tambah Pengguna Baru';
@@ -63,10 +59,7 @@ $strAnIndex = 'Indeks telah ditambah pada %s';
 $strAnalyzeTable = 'Analyze table';
 $strAnd = 'Dan';
 $strAny = 'Sebarang';
-$strAnyColumn = 'Sebarang Kolum';
-$strAnyDatabase = 'Sebarang pangkalan data';
 $strAnyHost = 'Sebarang hos';
-$strAnyTable = 'Sebarang jadual';
 $strAnyUser = 'Sebarang pengguna';
 $strAscending = 'Menaik';
 $strAtBeginningOfTable = 'Pada Awalan Jadual';
@@ -88,7 +81,6 @@ $strBzError = 'phpMyAdmin tidak dapat memampatkan longgokan kerana terdapat masa
 $strBzip = 'bzipped';
 
 $strCannotLogin = 'Tidak boleh log-masuk ke server MySQL';
-$strCantLoadMySQL = 'tidak dapat memuat sambungan MySQL,<br />sila semak konfigurasi PHP.';
 $strCantLoadRecodeIconv = 'Tidak dapat memuat iconv atau kodsemula sambungan yang diperlukan untuk menukar set aksara, konfigur php utk membolehkan penggunaan sambungan ini atau abaikan pengubahan set aksara di phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Tidak boleh menukar indekx ke PRIMARY!';
 $strCantUseRecodeIconv = 'Tidak boleh menggunakan fungsi iconv mahupun libiconv mahupun recode_string apabila sambungan lapuran dimuat. Periksa konfigurasi php anda.';
@@ -99,11 +91,9 @@ $strChangeDisplay = 'Pilih Medan untuk dipapar';
 $strChangePassword = 'Ubah Katalaluan';
 $strCharsetOfFile = 'Fail bagi set Aksara:';
 $strCheckAll = 'Tanda Semua';
-$strCheckDbPriv = 'Periksa Keutamaan Pengkalan Data';
 $strCheckTable = 'Periksa Jadual';
 $strChoosePage = 'Sila Pilih Laman untuk diubah';
 $strColComFeat = 'Memaparkan Komen Kolum';
-$strColumn = 'Kolum';
 $strColumnNames = 'Nama Kolum';
 $strCommand = 'Arahan';
 $strComments = 'Komen';
@@ -111,7 +101,6 @@ $strCompleteInserts = 'Kemasukkan Selesai';
 $strCompression = 'Mampatan';
 $strConfigFileError = 'phpMyAdmin tidak dapat membaca fail konfigurasi!<br \\>Ini mungkin terjadi apabila ada kesalahan dalam php ataupun php tidak jumpa fail tersebut.<br />Sila panggil fail konfigurasi menggunakan pautan dibawah dan baca kesalahan php yang diterima. Dalam kebanyakan kes quote atau semicolon tertinggal.<br />Jika kamu terima laman kosong, semuanya berjalan lancar.';
 $strConfigureTableCoord = 'Sila konfigurasikan kordinat bagi jadual %s';
-$strConfirm = 'Anda pasti mahu lakukan?';
 $strConnections = 'Hubungan';
 $strCookiesRequired = 'Cecikut mestilah dihidupkan ketika ini.';
 $strCopyTable = 'Salin jadual ke (pangkalandata<b>.</b>jadual):';
@@ -129,20 +118,16 @@ $strCriteria = 'Kriteria';
 $strData = 'Data';
 $strDataDict = 'Kamus Data';
 $strDataOnly = 'Data sahaja';
-$strDatabase = 'Pangkalan Data ';
+$strDatabase = 'Pangkalan Data';
 $strDatabaseHasBeenDropped = 'angkalan data %s telah digugurkan.';
-$strDatabaseWildcard = 'Pangkalan data (wildcard diizinkan):';
 $strDatabases = 'pangkalan data';
 $strDatabasesStats = 'Statistik pangkalan data';
 $strDefault = 'Asal';
 $strDelete = 'Padam';
-$strDeleteFailed = 'Pemadaman gagal!';
-$strDeleteUserMessage = 'Anda telah memadam pengguna %s.';
 $strDeleted = 'Baris telah dipadam';
 $strDeletedRows = 'Baris dipadam:';
 $strDescending = 'Menurun';
 $strDisabled = 'Tidak Membenarkan';
-$strDisplay = 'Papar';
 $strDisplayFeat = 'Paparkan Ciri-ciri';
 $strDisplayOrder = 'Turutan paparan:';
 $strDisplayPDF = 'Papar Skema PDF';
@@ -150,8 +135,6 @@ $strDoAQuery = 'Lakukan "kueri melalui contoh" (wilidcard: "%")';
 $strDoYouReally = 'Adakah anda ingin ';
 $strDocu = 'Dokumentasi';
 $strDrop = 'Gugur';
-$strDropDB = 'Gugurkan pangkalan data %s';
-$strDropTable = 'Gugurkan jadual';
 $strDumpXRows = 'Longgok %s baris bermula pada rekod # %s.';
 $strDumpingData = 'Melonggok data bagi jadual';
 $strDynamic = 'dinamik';
@@ -170,7 +153,6 @@ $strEnglishPrivileges = ' Nota: Nama privilej MySQL adalah dinyatakan dalam B.In
 $strError = 'Ralat';
 $strExplain = 'Terangkan Kod SQL';
 $strExport = 'Eksport';
-$strExportToXML = 'Eksport ke format XML';
 $strExtendedInserts = 'Penyelitan Lanjutan';
 $strExtra = 'Ekstra';
 
@@ -194,7 +176,6 @@ $strGenTime = 'Masa dijana';
 $strGeneralRelationFeat = 'Ciri-ciri hubungan am';
 $strGlobalValue = 'Nilai Global';
 $strGo = 'Pergi';
-$strGrants = 'Kabulkan';
 $strGzip = '"digzip"';
 
 $strHasBeenAltered = 'telah diubahsuai.';
@@ -202,7 +183,6 @@ $strHasBeenCreated = 'telah dicipta.';
 $strHaveToShow = 'Anda mesti pilih sekurang-kurangnya satu Kolum untuk dipapar';
 $strHome = 'Rumah';
 $strHomepageOfficial = 'Laman Rasmi phpMyAdmin';
-$strHomepageSourceforge = 'Laman Muaturun phpMyAdmin Sourceforge';
 $strHost = 'Hos';
 $strHostEmpty = 'Nama hos adalah kosong!';
 
@@ -224,7 +204,6 @@ $strInsertNewRow = 'Selitkan baris baru';
 $strInsertTextfiles = 'Selit data dari fail teks ke jadual';
 $strInsertedRows = 'Baris diselit:';
 $strInstructions = 'Arahan';
-$strInvalidName = '"%s" adalah kata pencam, anda tidak boleh menggunakan ia sebagai pangkalan data/jadual/medan .';
 
 $strKeepPass = 'Jangan tukar katalaluan';
 $strKeyname = 'Nama Kekunci';
@@ -232,11 +211,9 @@ $strKill = 'Bunuh';
 
 $strLandscape = 'Menegak';
 $strLaTeX = 'LaTeX';
-$strLength = 'Panjang';
 $strLengthSet = 'Panjang/Nilai*';
 $strLimitNumRows = 'Bilangan baris per halaman';
 $strLineFeed = 'Suapanbaris: \\n';
-$strLines = 'Baris';
 $strLinesTerminatedBy = 'Baris ditamatkan oleh';
 $strLinkNotFound = 'Pautan tidak dijumpai';
 $strLinksTo = 'Pautan ke';
@@ -246,7 +223,6 @@ $strLogUsername = 'Namapengguna:';
 $strLogin = 'Logmasuk';
 $strLogout = 'Log keluar';
 
-$strMissingBracket = 'Kehilangan Kurungan \'(\' atau \')\'';
 $strModifications = 'Pengubahsuaian telah disimpan';
 $strModify = 'Ubahsuai';
 $strModifyIndexTopic = 'Ubahsuai indeks';
@@ -296,7 +272,6 @@ $strOperations = 'Operasi';
 $strOptimizeTable = 'Optimakan jadual';
 $strOptionalControls = 'Opsional. Kawal bagaimana menulis dan membaca aksara istimewa.';
 $strOptionally = 'Opsional';
-$strOptions = 'Pilihan';
 $strOr = 'Atau';
 $strOverhead = 'Melebihi';
 
@@ -308,7 +283,6 @@ $strPassword = 'Katalaluan';
 $strPasswordEmpty = 'Katalaluan adalah kosong!';
 $strPasswordNotSame = 'Katalaluan tidak sama!';
 $strPdfDbSchema = 'Skema bagi pangkalan data "%s" database - Laman %s';
-$strPdfInvalidPageNum = 'bilangan halaman PDF tak tertakrif!';
 $strPdfInvalidTblName = 'Jadual "%s" tidak wujud!';
 $strPdfNoTables = 'Tiada Jadual';
 $strPerHour = 'per jam';
@@ -319,7 +293,6 @@ $strPortrait = 'Melintang';
 $strPos1 = 'Mula';
 $strPrevious = 'Terdahulu';
 $strPrimary = 'Utama';
-$strPrimaryKey = 'Kekunci utama';
 $strPrimaryKeyHasBeenDropped = 'Kekunci utama telah digugurkan';
 $strPrimaryKeyName = 'Nama kekunci utama mestilah... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>mesti</b> nama dan <b>semesti</b> dari kekunci utama!)';
@@ -327,7 +300,6 @@ $strPrint = 'Cetak';
 $strPrintView = 'Paparan Cetak';
 $strPrivileges = 'Privilej';
 $strProcesslist = 'Senarai Proses';
-$strProperties = 'Ciri-ciri';
 $strPutColNames = 'Letakkan medan di baris pertama';
 
 $strQBE = 'Kueri';
@@ -346,7 +318,6 @@ $strRelationNotWorking = 'Ciri-ciri tambahan ini adalah untuk bekerja dengan pau
 $strRelationView = 'Paparan Hubungan';
 $strReloadFailed = 'Pengulangmuatan MySQL gagal.';
 $strReloadMySQL = 'Ulangmuat MySQL';
-$strRememberReload = 'Ingat untuk ulatmuat ke pelayan.';
 $strRenameTable = 'Tukarnama jadual ke';
 $strRenameTableOK = 'Jadual %s telah ditukarnama ke %s';
 $strRepairTable = 'Baiki jadual';
@@ -354,10 +325,7 @@ $strReplace = 'Ganti';
 $strReplaceTable = 'Ganti data jadual dengan fail';
 $strReset = 'Ulangtetap';
 $strRevoke = 'TarikBalik';
-$strRevokeGrant = 'TarikBalik Keistimewaan';
-$strRevokeGrantMessage = 'You have revoked the Grant privilege for %s';
 $strRevokeMessage = 'Anda telah menarikbalik privilej Keistimewaan untuk %s';
-$strRevokePriv = 'Anda telah menarikbalik privilej untuk %s';
 $strRowLength = 'Panjang baris';
 $strRowSize = ' Saiz baris ';
 $strRows = 'Baris';
@@ -390,7 +358,6 @@ $strSearchOption3 = 'Frasa tepat';
 $strSearchOption4 = 'sebagai penyataan regular (regexp)';
 $strSearchResultsFor = 'Hasil carian bagi "<i>%s</i>" %s:';
 $strSearchType = 'Cari:';
-$strSelect = 'Pilih';
 $strSelectADb = 'Sila pilih pangkalan data';
 $strSelectAll = 'Sila pilih pangkalan data';
 $strSelectFields = 'Pilih medan (sekurang-kurangnya satu):';
@@ -398,7 +365,7 @@ $strSelectNumRows = 'pada kueri';
 $strSelectTables = 'Pilih Jadual';
 $strSend = 'Simpan sebagai fail';
 $strSent = 'Hantar';
-$strServer = 'Pelayan %s';
+$strServer = 'Pelayan';
 $strServerChoice = 'Pilihan Pelayan';
 $strServerStatus = 'Informasi MasaJana';
 $strServerStatusUptime = 'Pelayan MySQL ini telah berjalan selama %s. Ia dihidupkan pada %s.';
@@ -412,7 +379,6 @@ $strSetEnumVal = 'Jika jenis medan ialah "enum" atau "set", sila masukkan nilai
 $strShow = 'Papar';
 $strShowAll = 'Papar semua';
 $strShowColor = 'Papar warna';
-$strShowCols = 'Papar kolum';
 $strShowDatadictAs = 'Format Kamus Data';
 $strShowGrid = 'Papar grid';
 $strShowPHPInfo = 'Papar maklumat PHP';
@@ -429,7 +395,7 @@ $strStatement = 'Penyataan';
 $strStatus = 'Status';
 $strStrucCSV = 'data CSV';
 $strStrucData = 'Struktur dan data';
-$strStrucDrop = 'Tambah \'drop table\'';
+$strStrucDrop = 'Tambah DROP TABLE';
 $strStrucExcelCSV = 'CSV untuk sata MS Excel';
 $strStrucOnly = 'Struktur sahaja';
 $strStructPropose = 'Cadangkan struktur jadual';
@@ -464,7 +430,6 @@ $strUncheckAll = 'Nyahtanda Semua';
 $strUnique = 'Unik';
 $strUnselectAll = 'Nyahpilih Semua';
 $strUpdatePrivMessage = 'Anda telah mengemaskini privilej bagi %s.';
-$strUpdateProfile = 'Kemaskini profil:';
 $strUpdateProfileMessage = 'Profil telah dikemaskini.';
 $strUpdateQuery = 'Kemaskini Kueri';
 $strUsage = 'Penggunaan';
@@ -473,7 +438,6 @@ $strUseTables = 'Guna Jadual';
 $strUser = 'Pengguna';
 $strUserEmpty = 'Kata Pengenalan kosong!';
 $strUserName = 'Kata Pengenalan';
-$strUsers = 'Pengguna-Pengguna';
 
 $strValidateSQL = 'Mengesahkan SQL';
 $strValidatorError = 'Pengesahan SQL tidak dapat disahkan. Sila semak sama ada anda telah memasang sambungan php seperti yang tercatit di %sdocumentation%s.';
@@ -556,7 +520,6 @@ $strUserNotFound = 'The selected user was not found in the privilege table.'; //
 $strUserAlreadyExists = 'The user %s already exists!'; //to translate
 $strUseTextField = 'Use text field'; //to translate
 
-$strNoUsersSelected = 'No users selected.'; //to translate
 $strDropUsersDb = 'Drop the databases that have the same names as the users.'; //to translate
 $strAddedColumnComment = 'Added comment for column';  //to translate
 $strWritingCommentNotPossible = 'Writing of comment not possible';  //to translate
@@ -600,11 +563,8 @@ $strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user table
 $strWildcard = 'wildcard';  //to translate
 $strRowsModeFlippedHorizontal = 'horizontal (rotated headers)';//to translate
 $strQueryTime = 'Query took %01.4f sec';//to translate
-$strDumpComments = 'Include column comments as inline SQL-comments';//to translate
 $strDBComment = 'Database comment: ';//to translate
 $strQueryFrame = 'Query window';//to translate
-$strQueryFrameDebug = 'Debugging information';//to translate
-$strQueryFrameDebugBox = 'Active variables for the query form:\nDB: %s\nTable: %s\nServer: %s\n\nCurrent variables for the query form:\nDB: %s\nTable: %s\nServer: %s\n\nOpener location: %s\nFrameset location: %s.';//to translate
 $strQuerySQLHistory = 'SQL-history';//to translate
 $strMIME_MIMEtype = 'MIME-type';//to translate
 $strMIME_transformation = 'Browser transformation';//to translate
@@ -616,9 +576,7 @@ $strMIME_available_transform = 'Available transformations';//to translate
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
 $strMIME_description = 'Description';//to translate
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';//to translate
-$strMIME_file = 'Filename';//to translate
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';//to translate
-$strTransformation_text_plain__unformatted = 'Displays HTML code as HTML entities. No HTML formatting is shown.';//to translate
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';//to translate
 $strInnodbStat = 'InnoDB Status';  //to translate
 $strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';  //to translate
@@ -737,7 +695,7 @@ $strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
 $strConstraintsForTable = 'Constraints for table';  //to translate
 $strBookmarkOptions = 'Bookmark options';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
-$strCheckOverhead = 'Check overheaded';  //to translate
+$strCheckOverhead = 'Check tables with overhead';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
 $strDelayedInserts = 'Use delayed inserts';  //to translate
 $strSQLExportType = 'Export type';  //to translate
@@ -746,5 +704,119 @@ $strGeorgian = 'Georgian';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strMaximumSize = 'Maximum size: %s%s';  //to translate
+$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
+$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
+$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
+$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
+$strIgnoreInserts = 'Use ignore inserts';  //to translate
+$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
+$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
+$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
+$strAfterInsertSame = 'Go back to this page';  //to translate
+$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
+$strDatabaseEmpty = 'The database name is empty!';  //to translate
+$strDBRename = 'Rename database to';  //to translate
+$strOperator = 'Operator';  //to translate
+$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
+$strCalendar = 'Calendar';  //to translate
+$strRefresh = 'Refresh';  //to translate
+$strDefragment = 'Defragment table';  //to translate
+$strNoRowsSelected = 'No rows selected';  //to translate
 $strSpanish = 'Spanish';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
+$strServerNotResponding = 'The server is not responding';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
+$strIcelandic = 'Icelandic';  //to translate
+$strLatvian = 'Latvian';  //to translate
+$strPolish = 'Polish';  //to translate
+$strRomanian = 'Romanian';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
