@@ -1,8 +1,8 @@
 <?php
-/* $Id: norwegian-iso-8859-1.inc.php,v 2.7.2.1 2004/06/07 10:09:55 rabus Exp $ */
+/* $Id: norwegian-iso-8859-1.inc.php,v 2.77 2005/03/30 19:23:40 lem9 Exp $ */
 
 /**
- * Translated by Sven-Erik Andersen <sven_erik at andersen.as>
+ * Translated by Sven-Erik Andersen <sven-erik.andersen at pkf107.no>
  */
 
 $charset = 'iso-8859-1';
@@ -32,10 +32,11 @@ $strAddConstraints = 'Legg til begrensninger';
 $strAddDeleteColumn = 'Legg til/Slett kolonne';
 $strAddDeleteRow = 'Legg til/Slett kriterierad';
 $strAddDropDatabase = 'Legg til DROP DATABASE';
+$strAddFields = 'Legg til %s felt(er)';
+$strAddHeaderComment = 'Legg til egen kommentar i hodet (\\n lager linjeskift)';
+$strAddIfNotExists = 'Legg til IF NOT EXISTS';
 $strAddIntoComments = 'Legg til i kommentarer';
 $strAddNewField = 'Legg til felt';
-$strAddPriv = 'Legg til nytt privilegium';
-$strAddPrivMessage = 'Du har lagt til ett nytt privilegium.';
 $strAddPrivilegesOnDb = 'Legg til privilegier til flgende database';
 $strAddPrivilegesOnTbl = 'Legg til privilegier til flgende tabell';
 $strAddSearchConditions = 'Legg til skekriterier (innhold i "where"-setningen):';
@@ -49,6 +50,7 @@ $strAffectedRows = 'Berrte rader:';
 $strAfter = 'Etter %s';
 $strAfterInsertBack = 'Returner';
 $strAfterInsertNewInsert = 'Sett inn en ny post';
+$strAfterInsertSame = 'Tilbake til denne siden';
 $strAll = 'Alle';
 $strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
 $strAlterOrderBy = 'Endre tabellrekkeflge ved';
@@ -56,11 +58,9 @@ $strAnIndex = 'En indeks har blitt lagt til %s';
 $strAnalyzeTable = 'Analyser tabell';
 $strAnd = 'og';
 $strAny = 'Alle';
-$strAnyColumn = 'Alle kolonner';
-$strAnyDatabase = 'Alle databaser';
 $strAnyHost = 'Alle verter';
-$strAnyTable = 'Alle tabeller';
 $strAnyUser = 'Alle brukere';
+$strApproximateCount = 'Kan vre unyaktig. Se FAQ 3.11';
 $strArabic = 'arabisk';
 $strArmenian = 'armensk';
 $strAscending = 'Stigende';
@@ -74,8 +74,15 @@ $strBack = 'Tilbake';
 $strBaltic = 'baltisk';
 $strBeginCut = 'START KUTT';
 $strBeginRaw = 'START UFORMATERT';
+$strBinLogEventType = 'Hendelsestype';
+$strBinLogInfo = 'Informasjon';
+$strBinLogName = 'Loggnavn';
+$strBinLogOriginalPosition = 'Original posisjon';
+$strBinLogPosition = 'Posisjon';
+$strBinLogServerId = 'Tjener ID';
 $strBinary = ' Binr ';
 $strBinaryDoNotEdit = ' Binr - m ikke redigeres ';
+$strBinaryLog = 'Binrlogg';
 $strBookmarkAllUsers = 'La alle brukere ha adgang til dette bokmerket';
 $strBookmarkDeleted = 'Bokmerket har blitt slettet.';
 $strBookmarkLabel = 'Navn';
@@ -90,9 +97,9 @@ $strBzError = 'phpMyAdmin kunne ikke komprimere dumpede data fordi Bz2 tillegget
 $strBzip = 'Komprimert (bz2)';
 
 $strCSVOptions = 'CSV valg';
+$strCalendar = 'Kalender';
 $strCannotLogin = 'Kan ikke logge inn til MySQL tjeneren';
 $strCantLoad = 'kan ikke starte %s tillegget,<br />vennligst kontroller PHP-konfigurasjonen';
-$strCantLoadMySQL = 'kan ikke starte MySQL-modulen,<br />vennligst kontroller PHP-konfigureringen.';
 $strCantLoadRecodeIconv = 'Kan ikke laste iconv- eller recode-modulen som trengs for tegnsett konvertering, konfigurer php slik at disse kan lastes eller sl av tegnsettkonvertering i phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Kan ikke endre indeks til PRIMARY!';
 $strCantUseRecodeIconv = 'Kan ikke bruke hverken iconv, libiconv eller recode_string funksjonene selv om modulene sier de er lastet. Sjekk din php-konfigurasjon.';
@@ -115,7 +122,6 @@ $strCharsetOfFile = 'Filens tegnsett:';
 $strCharsets = 'Tegnsett';
 $strCharsetsAndCollations = 'Tegnsett og kollasjoneringer';
 $strCheckAll = 'Merk alle';
-$strCheckDbPriv = 'Kontroller databaseprivilegier';
 $strCheckOverhead = 'Kontroller overheng';
 $strCheckPrivs = 'Kontroller privilegier';
 $strCheckPrivsLong = 'Kontroller privilegier for databasen &quot;%s&quot;.';
@@ -123,20 +129,22 @@ $strCheckTable = 'Kontroller tabell';
 $strChoosePage = 'Vennligst velg en side for redigering';
 $strColComFeat = 'Vis kolonnekommentarer';
 $strCollation = 'Kollasjonering';
-$strColumn = 'Kolonne';
 $strColumnNames = 'Kolonnenavn';
 $strColumnPrivileges = 'Kolonne-spesifikke privilegier';
 $strCommand = 'Kommando';
 $strComments = 'Kommentarer';
+$strCommentsForTable = 'TABELLKOMMENTARER';
+$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
 $strCompleteInserts = 'Komplette innlegg';
 $strCompression = 'Kompresjon';
 $strConfigFileError = 'phpMyAdmin kunne ikke lese din konfigurasjonsfil!<br />Dette kan skje hvis PHP finner en syntaksfeil eller ikke kan finne filen.<br />Vennligst kall opp konfigurasjonsfilen direkte via linken under og les PHP feilmeldingen(e) som du vil f. I de fleste tilfeller s mangler det et anfrselstegn eller et semikolon et sted.<br />Hvis du fr en blank side s er alt ok.';
 $strConfigureTableCoord = 'Vennligst konfigurer koordinatene for tabell %s';
-$strConfirm = 'nsker du virkelig  gjre det?';
+$strConnectionError = 'Kan ikke koble til: ugyldige innstillinger.';
 $strConnections = 'tilkoblinger';
 $strConstraintsForDumped = 'Begrensninger for dumpede tabeller';
 $strConstraintsForTable = 'Begrensninger for tabell';
 $strCookiesRequired = 'Cookies m vre sltt p forbi dette punkt.';
+$strCopyDatabaseOK = 'Databasen %s har blitt kopiert til %s';
 $strCopyTable = 'Kopier tabell til (database<b>.</b>tabell):';
 $strCopyTableOK = 'Tabellen %s er kopiert til %s.';
 $strCopyTableSameNames = 'Kan ikke kopiere tabellen til samme navn!';
@@ -156,6 +164,7 @@ $strCzech = 'tjekkisk';
 $strCzechSlovak = 'Tjekkoslovakisk';
 
 $strDBComment = 'Database kommentar: ';
+$strDBCopy = 'Kopier databasen til';
 $strDBGContext = 'Sammenheng';
 $strDBGContextID = 'Sammenhengs-ID';
 $strDBGHits = 'Treff';
@@ -165,15 +174,16 @@ $strDBGMinTimeMs = 'Min tid, ms';
 $strDBGModule = 'Modul';
 $strDBGTimePerHitMs = 'Tid/Treff, ms';
 $strDBGTotalTimeMs = 'Total tid, ms';
+$strDBRename = 'Endre databasens navn til';
 $strDanish = 'dansk';
 $strData = 'Data';
 $strDataDict = 'Dataordbok';
 $strDataOnly = 'Bare data';
-$strDatabase = 'Database ';
-$strDatabaseExportOptions = 'Database eksportinnstillinger';
+$strDatabase = 'Database';
+$strDatabaseEmpty = 'Databasens navn er tomt!';
+$strDatabaseExportOptions = 'Databaseeksportinnstillinger';
 $strDatabaseHasBeenDropped = 'Databasen %s har blitt slettet';
 $strDatabaseNoTable = 'Denne databasen har ingen tabeller!';
-$strDatabaseWildcard = 'Database (jokertegn er tillatt):';
 $strDatabases = 'databaser';
 $strDatabasesDropped = '%s databasene har blitt slettet.';
 $strDatabasesStats = 'Statistikk for databaser';
@@ -184,21 +194,20 @@ $strDbPrivileges = 'Database-spesifikke privilegier';
 $strDbSpecific = 'databasespesifikk';
 $strDefault = 'Standard';
 $strDefaultValueHelp = 'Sett inn en enkelt verdi for standard verdier uten skrstrek, anfrselstegn eller annen &quot;escaping&quot; med dette formatet: a';
+$strDefragment = 'Defragmenter tabell';
 $strDelOld = 'Den nvrende siden har referanser til tabeller som ikke lenger eksisterer. Vil du slette disse referansene?';
 $strDelayedInserts = 'Bruk forsinkede innsettinger';
 $strDelete = 'Slett';
 $strDeleteAndFlush = 'Slett brukeren og oppfrisk privilegiene etterp.';
 $strDeleteAndFlushDescr = 'Dette er den beste mten, men oppfrisking av privilegiene kan ta litt tid.';
-$strDeleteFailed = 'Slettingen mislyktes!';
-$strDeleteUserMessage = 'Du har slettet brukeren %s.';
 $strDeleted = 'Raden er slettet';
 $strDeletedRows = 'Slettede rader:';
 $strDeleting = 'Sletter %s';
 $strDescending = 'Synkende';
 $strDescription = 'Beskrivelse';
 $strDictionary = 'ordbok';
+$strDisableForeignChecks = 'Sl av kontroll av fremmednkler';
 $strDisabled = 'Avsltt';
-$strDisplay = 'Vis';
 $strDisplayFeat = 'Vis egenskaper';
 $strDisplayOrder = 'Visningsrekkeflge:';
 $strDisplayPDF = 'Vis PDF-skjema';
@@ -206,11 +215,9 @@ $strDoAQuery = 'Utfr en "sprring ved eksempel" (jokertegn: "%")';
 $strDoYouReally = 'Vil du virkelig ';
 $strDocu = 'Dokumentasjon';
 $strDrop = 'Slett';
-$strDropDB = 'Slett databasen %s';
+$strDropDatabaseStrongWarning = 'Du er i ferd med  SLETTE en komplett database!';
 $strDropSelectedDatabases = 'Slett valgte databaser';
-$strDropTable = 'Slett tabell';
 $strDropUsersDb = 'Slett databasene som har det samme navnet som brukerne.';
-$strDumpComments = 'Inkluder kolonnekommentarer som SQL-kommentarer';
 $strDumpSaved = 'Dump har blitt lagret til fila %s.';
 $strDumpXRows = 'Dumpe %s rader fra rad %s.';
 $strDumpingData = 'Dataark for tabell';
@@ -223,6 +230,7 @@ $strEffective = 'Effektiv';
 $strEmpty = 'Tm';
 $strEmptyResultSet = 'MySQL returnerte ett tomt resultat (m.a.o. ingen rader).';
 $strEnabled = 'Psltt';
+$strEncloseInTransaction = 'Inneslutt eksport i en transaksjon';
 $strEnd = 'Slutt';
 $strEndCut = 'STOPP KUTT';
 $strEndRaw = 'STOPP UFORMATERT';
@@ -235,7 +243,6 @@ $strExcelOptions = 'Excel-innstillinger';
 $strExecuteBookmarked = 'Utfr lagret sprring';
 $strExplain = 'Forklar SQL';
 $strExport = 'Eksporter';
-$strExportToXML = 'Eksporter til XML format';
 $strExtendedInserts = 'Utvidete innlegg';
 $strExtra = 'Ekstra';
 
@@ -245,7 +252,7 @@ $strFieldHasBeenDropped = 'Feltet %s har blitt slettet';
 $strFields = 'Felter';
 $strFieldsEmpty = ' Antall felter er tommt! ';
 $strFieldsEnclosedBy = 'Felter omsluttet av';
-$strFieldsEscapedBy = 'Felter "escaped" med';
+$strFieldsEscapedBy = 'Felter beskyttet med';
 $strFieldsTerminatedBy = 'Felter avsluttet med';
 $strFileAlreadyExists = 'Fila %s eksisterer alt p serveren, endre navnet eller merk av for overskriving av fil.';
 $strFileCouldNotBeRead = 'Fila kunne ikke leses';
@@ -270,7 +277,6 @@ $strGlobalPrivileges = 'Globale privilegier';
 $strGlobalValue = 'Global verdi';
 $strGo = 'Utfr';
 $strGrantOption = 'Rettighet';
-$strGrants = 'Rettigheter';
 $strGreek = 'gresk';
 $strGzip = 'Komprimert (gz)';
 
@@ -278,17 +284,19 @@ $strHasBeenAltered = 'er endret.';
 $strHasBeenCreated = 'er opprettet.';
 $strHaveToShow = 'Du m velge minst en kolonne for visning';
 $strHebrew = 'hebraisk';
+$strHexForBinary = 'Bruk heksadesimal for binre felter';
 $strHome = 'Hjem';
 $strHomepageOfficial = 'Offisiell phpMyAdmin-hjemmeside';
-$strHomepageSourceforge = 'Sourceforge phpMyAdmin-nedlastingsside';
 $strHost = 'Vert';
 $strHostEmpty = 'Vertsnavnet er tomt!';
 $strHungarian = 'ungarsk';
 
+$strIcelandic = 'Islandsk';
 $strId = 'ID';
 $strIdxFulltext = 'Fulltekst';
 $strIfYouWish = 'Hvis du kun nsker  lese inn enkelte av tabellens kolonner, angi en kommaseparert feltliste.';
 $strIgnore = 'Ignorer';
+$strIgnoreInserts = 'Bruk ignore inserts';
 $strIgnoringFile = 'Ignorerer fil %s';
 $strImportDocSQL = 'Importer docSQL-filer';
 $strImportFiles = 'Importer filer';
@@ -298,11 +306,16 @@ $strIndex = 'Indeks';
 $strIndexHasBeenDropped = 'Indeksen %s har blitt slettet';
 $strIndexName = 'Indeksnavn&nbsp;:';
 $strIndexType = 'Indekstype&nbsp;:';
+$strIndexWarningMultiple = 'Mer enn en %s nkkel ble opprettet for kolonne `%s`';
+$strIndexWarningPrimary = 'Bde PRIMARY og INDEX nkler br ikke settes for kolonne `%s`';
+$strIndexWarningTable = 'Problemer med indeksene i tabellen `%s`';
+$strIndexWarningUnique = 'Bde UNIQUE og INDEX nkler br ikke settes for kolonne `%s`';
 $strIndexes = 'Indekser';
 $strInnodbStat = 'InnoDB status';
 $strInsecureMySQL = 'Din konfigurasjonsfil inneholder innstillinger (root uten passord) som korrensponderer med MySQLs standard priviligerte brukerkonto. Din MySQL-tjener kjrer med denne standardinnstillingen, er pen for misbruk, og du burde fikse dette sikkerhetshullet snarest.';
 $strInsert = 'Sett inn';
 $strInsertAsNewRow = 'Sett inn som ny rad';
+$strInsertBookmarkTitle = 'Skriv inn bokmerketittel';
 $strInsertNewRow = 'Sett inn ny rad';
 $strInsertTextfiles = 'Les tekstfil inn i tabell';
 $strInsertedRowId = 'Satt inn rad id:';
@@ -310,7 +323,6 @@ $strInsertedRows = 'Innsatte rader:';
 $strInstructions = 'Instruksjoner';
 $strInternalNotNecessary = '* En intern relasjon er ikke ndvendig nr den ogs eksisterer i InnoDB.';
 $strInternalRelations = 'Interne relasjoner';
-$strInvalidName = '"%s" er ett reservert ord, du kan ikke bruke det som et database-, tabell- eller feltnavn.';
 
 $strJapanese = 'japansk';
 $strJumpToDB = 'Hopp til databasen &quot;%s&quot;.';
@@ -332,11 +344,10 @@ $strLatexContinuedCaption = 'Fortsettet tabelloverskrift';
 $strLatexIncludeCaption = 'Inkluder tabelloverskrift';
 $strLatexLabel = 'Merkelappnkkel';
 $strLatexStructure = 'Struktur i tabell __TABLE__';
-$strLength = 'Lengde';
+$strLatvian = 'Latvisk';
 $strLengthSet = 'Lengde/Sett*';
 $strLimitNumRows = 'Antall poster per side';
 $strLineFeed = 'Linjeskift: \\n';
-$strLines = 'Linjer';
 $strLinesTerminatedBy = 'Linker avsluttet med';
 $strLinkNotFound = 'Link ikke funnet';
 $strLinksTo = 'Linker til';
@@ -352,19 +363,18 @@ $strLogin = 'Logg inn';
 $strLoginInformation = 'Innlogingsinformasjon';
 $strLogout = 'Logg ut';
 
-$strMaximumSize = 'Maksimum strelse: %s%s';
+$strMIMETypesForTable = 'MIME TYPER FOR TABELLEN';
 $strMIME_MIMEtype = 'MIME-type';
 $strMIME_available_mime = 'Tilgjengelige MIME-typer';
 $strMIME_available_transform = 'Tilgjengelige transformationer';
 $strMIME_description = 'Beskrivelse';
-$strMIME_file = 'Filenavn';
 $strMIME_nodescription = 'Ingen beskrivelse er tilgjengelig for denne transformasjonen.<br />Spr forfatteren hva %s gjr.';
 $strMIME_transformation = 'Nettvisertransformasjon';
 $strMIME_transformation_note = 'For en liste over tilgjengelige transformasjonsvalg, klikk p %stransformasjonsbeskrivelser%s';
 $strMIME_transformation_options = 'Transformasjonsvalg';
 $strMIME_transformation_options_note = 'Skriv inn verdiene for transformasjon med dette formatet: \'a\',\'b\',\'c\'...<br />Hvis du trenger  bruke en skrstrek ("\") eller en enkel apostrof ("\'") blant disse verdiene s sett en skrstrek foran (eks. \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_without = 'MIME-typer skrevet i kursiv har ikke en separat transformasjonsfunksjon';
-$strMissingBracket = 'Manglende parantes';
+$strMaximumSize = 'Maksimum strelse: %s%s';
 $strModifications = 'Endringene er lagret';
 $strModify = 'Endre';
 $strModifyIndexTopic = 'Endre en indeks';
@@ -375,6 +385,7 @@ $strMoveTableSameNames = 'Kan ikke flytte tabellen til samme navn!';
 $strMultilingual = 'flersprkelig';
 $strMustSelectFile = 'Du m velge fila du nsker  sette inn.';
 $strMySQLCharset = 'MySQL-tegnsett';
+$strMySQLConnectionCollation = 'Kollasjon av MySQL-oppkobling';
 $strMySQLReloaded = 'MySQL omstartet.';
 $strMySQLSaid = 'MySQL sa: ';
 $strMySQLServerProcess = 'MySQL %pma_s1% som kjrer p %pma_s2% som %pma_s3%';
@@ -383,8 +394,10 @@ $strMySQLShowStatus = 'Vis MySQL driftsstatus';
 $strMySQLShowVars = 'Vis MySQL systemvariabler';
 
 $strName = 'Navn';
+$strNeedPrimaryKey = 'Du burde definere en primrnkkel for denne tabellen.';
 $strNext = 'Neste';
 $strNo = 'Nei';
+$strNoActivity = 'Ingen aktivitet p %s sekunder eller mer, du m logge inn p nytt';
 $strNoDatabases = 'Ingen databaser';
 $strNoDatabasesSelected = 'Ingen databaser er valgt.';
 $strNoDescription = 'ingen beskrivelse';
@@ -401,10 +414,11 @@ $strNoPhp = 'uten PHP kode';
 $strNoPrivileges = 'Ingen privilegier';
 $strNoQuery = 'Ingen SQL sprring!';
 $strNoRights = 'Du har ikke nok rettigheter til  vre her n!';
+$strNoRowsSelected = 'Ingen rader valgt';
 $strNoSpace = 'Ikke nok plass til  lagre fila %s.';
 $strNoTablesFound = 'Ingen tabeller i databasen.';
+$strNoThemeSupport = 'Ikke sttte for maler, kontroller konfigureringen og/eller dine maler i katalogen %s.';
 $strNoUsersFound = 'Ingen bruker(e) funnet.';
-$strNoUsersSelected = 'Ingen brukere valgt.';
 $strNoValidateSQL = 'Ikke teste SQL';
 $strNone = 'Ingen';
 $strNotNumber = 'Dette er ikke ett tall!';
@@ -419,10 +433,10 @@ $strNumTables = 'Tabeller';
 $strOK = 'OK';
 $strOftenQuotation = 'Ofte anfrselstegn. Valgfritt innebrer at kun tekstfelter ("char" og "varchar"-felter) er omfattet av tegnet.';
 $strOperations = 'Operasjoner';
+$strOperator = 'Operator';
 $strOptimizeTable = 'Optimiser tabell';
 $strOptionalControls = 'Valgfritt. Angir hvordan spesialtegn skrives eller leses.';
 $strOptionally = 'Valgfritt';
-$strOptions = 'Innstillinger';
 $strOr = 'Eller';
 $strOverhead = 'Overheng';
 $strOverwriteExisting = 'Overskriv eksisterende fil(-er)';
@@ -435,23 +449,24 @@ $strPartialText = 'Delvis tekst';
 $strPassword = 'Passord';
 $strPasswordChanged = 'Passordet til %s er endret.';
 $strPasswordEmpty = 'Passordet er blankt!';
+$strPasswordHashing = 'Passordnkling';
 $strPasswordNotSame = 'Passordene er ikke like!';
 $strPdfDbSchema = 'Skjema for "%s"-databasen - Side %s';
-$strPdfInvalidPageNum = 'Undefinert PDF-sidenummer!';
 $strPdfInvalidTblName = 'Tabellen "%s" eksisterer ikke!';
 $strPdfNoTables = 'Ingen tabeller';
 $strPerHour = 'per time';
 $strPerMinute = 'per minutt';
 $strPerSecond = 'per sekund';
+$strPersian = 'Persisk';
 $strPhoneBook = 'telefonkatalog';
 $strPhp = 'Lag PHP kode';
 $strPmaDocumentation = 'phpMyAdmin-Dokumentasjon';
 $strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> variabelen M vre innstilt i din konfigurasjonsfil!';
+$strPolish = 'Polsk';
 $strPortrait = 'Portrettformat';
 $strPos1 = 'Start';
 $strPrevious = 'Forrige';
 $strPrimary = 'Primr';
-$strPrimaryKey = 'Primrnkkel';
 $strPrimaryKeyHasBeenDropped = 'Primrnkkelen har blitt slettet';
 $strPrimaryKeyName = 'Navnet til  primrnkkelen m vre... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>m</b> vre navnet til og <b>bare til</b> en primrnkkel!)';
@@ -490,15 +505,12 @@ $strPrivDescUsage = 'Ingen privilegier.';
 $strPrivileges = 'Privilegier';
 $strPrivilegesReloaded = 'Oppfriskingen av privilegiene lyktes.';
 $strProcesslist = 'Prosess liste';
-$strProperties = 'Egenskaper';
 $strPutColNames = 'Sett inn feltnavn i frste rad';
 
 $strQBE = 'Sprring ved eksempel (Query by Example)';
 $strQBEDel = 'Slett';
 $strQBEIns = 'Sett inn';
 $strQueryFrame = 'Sprringsvindu';
-$strQueryFrameDebug = 'Feilskingsinformasjon';
-$strQueryFrameDebugBox = 'Aktive variabler for sprringsskjemaet:\nDB: %s\nTabell: %s\nServer: %s\n\nNvrende variabler for sprringsskjemaet:\nDB: %s\nTabell: %s\nServer: %s\n\npningssted: %s\nRammesettsted: %s.';
 $strQueryOnDb = 'SQL-sprring i database <b>%s</b>:';
 $strQuerySQLHistory = 'SQL-historie';
 $strQueryStatistics = '<b>Sprrings statistikk</b>: Siden oppstart, har %s sprringer blitt sendt til tjeneren.';
@@ -510,15 +522,17 @@ $strReType = 'Gjenta';
 $strReceived = 'Mottatt';
 $strRecords = 'Rader';
 $strReferentialIntegrity = 'Sjekk referanseintegritet:';
+$strRefresh = 'Oppdater';
 $strRelationNotWorking = 'Tilleggsfunksjonene for  kunne jobbe med koblede tabeller er deaktivert. For  finne ut hvorfor, klikk %sher%s.';
 $strRelationView = 'Relasjonsvisning';
 $strRelationalSchema = 'Relasjonsskjema';
 $strRelations = 'Relasjoner';
+$strRelationsForTable = 'RELASJONER FOR TABELLEN';
 $strReloadFailed = 'Omstart av MySQL feilet.';
 $strReloadMySQL = 'Omstart av MySQL';
 $strReloadingThePrivileges = 'Oppfrisker privilegiene';
-$strRememberReload = 'Husk  restarte tjeneren.';
 $strRemoveSelectedUsers = 'Fjern valgte brukere';
+$strRenameDatabaseOK = 'Databasen %s har endret navn til %s';
 $strRenameTable = 'Endre tabellens navn';
 $strRenameTableOK = 'Tabellen %s har ftt nytt navn %s';
 $strRepairTable = 'Reparer tabell';
@@ -530,10 +544,8 @@ $strResourceLimits = 'Ressursbegrensninger';
 $strRevoke = 'Tilbakekall';
 $strRevokeAndDelete = 'Tilbakekall alle aktive privilegier fra brukerne og slett dem etterp.';
 $strRevokeAndDeleteDescr = 'Inntill privilegiene er oppfrisket vil brukerne fortsatt ha USAGE privilegiet.';
-$strRevokeGrant = 'Tilbakekall Grant';
-$strRevokeGrantMessage = 'Du har tilbakekalt Grant-privilegiet til %s';
 $strRevokeMessage = 'Du har fjernet privilegiene til %s';
-$strRevokePriv = 'Tibakekall privilegier';
+$strRomanian = 'Rumensk';
 $strRowLength = 'Radlengde';
 $strRowSize = ' Radstrelse ';
 $strRows = 'Rader';
@@ -572,16 +584,17 @@ $strSearchOption4 = 'som "regular expression"';
 $strSearchResultsFor = 'Skeresultat for "<i>%s</i>" %s:';
 $strSearchType = 'Finn:';
 $strSecretRequired = 'Konfigurasjonsfila trenger n et hemmelig passordfrase (blowfish_secret).';
-$strSelect = 'Sprring';
 $strSelectADb = 'Vennligst velg en database';
 $strSelectAll = 'Velg alle';
+$strSelectBinaryLog = 'Velg binrlogg for visning';
 $strSelectFields = 'Velg felt (minst ett):';
 $strSelectNumRows = 'i sprring';
 $strSelectTables = 'Velg tabeller';
 $strSend = 'Last ned som fil';
 $strSent = 'Sendt';
-$strServer = 'Tjener %s';
+$strServer = 'Tjener';
 $strServerChoice = 'Tjenervalg';
+$strServerNotResponding = 'Tjeneren svarer ikke';
 $strServerStatus = 'Kjringsinformasjon';
 $strServerStatusUptime = 'Denne MySQL tjeneren har kjrt i %s. Den startet opp den %s.';
 $strServerTabProcesslist = 'Prosesser';
@@ -594,7 +607,6 @@ $strSetEnumVal = 'Hvis felttypen er "enum" eller "set", skriv inn verdien med de
 $strShow = 'Vis';
 $strShowAll = 'Vis alle';
 $strShowColor = 'Vis farger';
-$strShowCols = 'Vis kolonner';
 $strShowDatadictAs = 'Data Ordbok Format';
 $strShowFullQueries = 'Vis hele sprringen';
 $strShowGrid = 'Vis rutenett';
@@ -606,9 +618,12 @@ $strShowingRecords = 'Viser rader ';
 $strSimplifiedChinese = 'forenklet kinesisk';
 $strSingly = '(enkeltvis)';
 $strSize = 'Strrelse';
+$strSlovak = 'Slovakisk';
+$strSlovenian = 'Slovensk';
 $strSort = 'Sorter';
 $strSortByKey = 'Sorter etter nkkel';
 $strSpaceUsage = 'Plassbruk';
+$strSpanish = 'Spansk';
 $strSplitWordsWithSpace = 'Ord er separert med et mellomrom (" ").';
 $strStatCheckTime = 'Sist kontrollert';
 $strStatCreateTime = 'Opprettet';
@@ -617,8 +632,9 @@ $strStatement = 'Oversikt';
 $strStatus = 'Status';
 $strStrucCSV = 'CSV-data';
 $strStrucData = 'Struktur og data';
-$strStrucDrop = 'Legg til \'drop table\'';
-$strStrucExcelCSV = 'CSV for Ms Excel data';
+$strStrucDrop = 'Legg til DROP TABLE';
+$strStrucExcelCSV = 'CSV for MS Excel data';
+$strStrucNativeExcel = 'Originale MS Excel data';
 $strStrucOnly = 'Kun struktur';
 $strStructPropose = 'Foresl tabellstruktur';
 $strStructure = 'Struktur';
@@ -626,6 +642,7 @@ $strSubmit = 'Send';
 $strSuccess = 'Kommandoen/sprringen er utfrt';
 $strSum = 'Sum';
 $strSwedish = 'svensk';
+$strSwitchToDatabase = 'Bytt til kopiert database';
 $strSwitchToTable = 'Bytt til kopiert tabell';
 
 $strTable = 'Tabell';
@@ -640,12 +657,14 @@ $strTableOptions = 'Tabellinnstillinger';
 $strTableStructure = 'Tabellstruktur for tabell';
 $strTableType = 'Tabelltype';
 $strTables = '%s tabell(er)';
+$strTakeIt = 'velg';
 $strTblPrivileges = 'Tabell-spesifikke privilegier';
 $strTextAreaLength = ' P grunn av sin lengde,<br /> s vil muligens dette feltet ikke vre redigerbart ';
 $strThai = 'thai';
 $strTheContent = 'Innholdet av filen er lagt inn.';
 $strTheContents = 'Innholdet av filen erstatter valgt tabell for rader med lik identifikator eller unikt felt';
 $strTheTerminator = 'Tegn som angir slutt p felt.';
+$strTheme = 'Tema / Stil';
 $strThisHost = 'Denne vert';
 $strThisNotDirectory = 'Dette var ikke en katalog';
 $strThreadSuccessfullyKilled = 'Trd %s ble avsluttet med suksess.';
@@ -653,7 +672,8 @@ $strTime = 'Tid';
 $strToggleScratchboard = 'sl av/p kladdevindu';
 $strTotal = 'totalt';
 $strTotalUC = 'Totalt';
-$strTraditionalChinese = 'tradisjonell kinesisk';
+$strTraditionalChinese = 'Tradisjonell kinesisk';
+$strTraditionalSpanish = 'Tradisjonell spansk';
 $strTraffic = 'Trafikk';
 $strTransformation_application_octetstream__download = 'Vis en link for  kunne laste ned de binre dataene til et felt. Den frste opsjonen er filnavnet til den binre fila. Den andre opsjonen er et potensielt feltnavn i en tabell som inneholder filnavnet. Hvis du velger den andre opsjonen s m den frste vre satt til en tom strengverdi';
 $strTransformation_image_jpeg__inline = 'Viser et klikkbart tommelfingerbilde; valg: bredde, hyde i piksler (bevarer originale forhold)';
@@ -665,7 +685,6 @@ $strTransformation_text_plain__formatted = 'Bevarer original formatering av felt
 $strTransformation_text_plain__imagelink = 'Viser et bilde og en link, feltet inneholder filnavnet; frste verdi er et prefiks slik som "http://domain.com/", andre verdien er bredden i piksler, tredje er hyden.';
 $strTransformation_text_plain__link = 'Viser en link, feltet inneholder filnavnet, ; frste verdi er et prefiks slik som "http://domain.com/", andre verdien er en tittel for linken.';
 $strTransformation_text_plain__substr = 'Viser bare en delstreng. Frste verdien er antall tegn fra starten hvor din tekst begynner (Standard: 0). Andre verdien er hvor mange tegn som skal returneres. Hvis den er tom s returneres resten av teksten. Den tredje verdien definerer hvilke tegn som vil bli lagt til resultatet nr en delstreng blir returnert (Standard: ...).';
-$strTransformation_text_plain__unformatted = 'Vis HTML kode som HTML enheter. Ingen HTML formatering blir vist.';
 $strTruncateQueries = 'Forkort vist sprring';
 $strTurkish = 'tyrkisk';
 $strType = 'Type';
@@ -678,13 +697,13 @@ $strUnknown = 'ukjent';
 $strUnselectAll = 'Fjern alle valgte';
 $strUpdComTab = 'Les i dokumentasjonen hvordan du oppdaterer din Column_comments tabell';
 $strUpdatePrivMessage = 'Du har oppdatert privilegiene til %s.';
-$strUpdateProfile = 'Oppdater profil:';
 $strUpdateProfileMessage = 'Profilen har blitt oppdatert.';
 $strUpdateQuery = 'Oppdater sprring';
 $strUpgrade = 'Du burde oppgradere til %s %s eller nyere.';
 $strUsage = 'Bruk';
 $strUseBackquotes = 'Bruk venstre anfrselstegn med tabell og feltnavn';
 $strUseHostTable = 'Vis vert tabell';
+$strUseTabKey = 'Bruk TAB tasten for  flytte fra verdi til verdi, eller CTRL+piltastene for  bevege deg hvor som helst';
 $strUseTables = 'Bruk tabeller';
 $strUseTextField = 'Bruk tekstfelt';
 $strUseThisValue = 'Bruk denne verdien';
@@ -694,7 +713,6 @@ $strUserEmpty = 'Brukernavnet er tomt!';
 $strUserName = 'Brukernavn';
 $strUserNotFound = 'Den valgte brukeren ble ikke funnet i privilegietabellen.';
 $strUserOverview = 'Brukeroversikt';
-$strUsers = 'Brukere';
 $strUsersDeleted = 'De valgte brukerne har blitt slettet.';
 $strUsersHavingAccessToDb = 'Brukere som har adgang til &quot;%s&quot;';
 
@@ -721,10 +739,69 @@ $strXML = 'XML';
 
 $strYes = 'Ja';
 
-$strZeroRemovesTheLimit = 'Merk: Ved  sette disse til 0 (null) fjerner begrensningen.';
+$strZeroRemovesTheLimit = 'Merk: Ved  sette disse til 0 (null) fjernes begrensningen.';
 $strZip = 'Komprimert (zip)';
 
-// To translate
+// To translate:
+$strAfterInsertNext = 'Edit next row';  //to translate
 
-$strSpanish = 'Spanish';  //to translate
+$strEscapeWildcards = 'Jokertegnene _ og % m beskyttes med en \ for  bruke dem direkte';  //to translate
+
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
