@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovak-windows-1250.inc.php,v 2.7.2.2 2004/06/07 10:09:56 rabus Exp $ */
+/* $Id: slovak-windows-1250.inc.php,v 2.71 2005/03/30 19:24:23 lem9 Exp $ */
 
 /* By: lubos klokner <erkac@vault-tec.sk> */
 
@@ -30,10 +30,10 @@ $strAddConstraints = 'Prida obmedzenia';
 $strAddDeleteColumn = 'Prida/Odobra polia stpcov';
 $strAddDeleteRow = 'Prida/Odobra kritria riadku';
 $strAddDropDatabase = 'Prida DROP DATABASE';
+$strAddHeaderComment = 'Prida vlastn komentr do hlaviky (\\n oddeuje riadky)';
+$strAddIfNotExists = 'Prida IF NOT EXISTS';
 $strAddIntoComments = 'Prida do komentrov';
 $strAddNewField = 'Prida nov pole';
-$strAddPriv = 'Prida nov oprvnenie';
-$strAddPrivMessage = 'Oprvnenie bolo pridan.';
 $strAddPrivilegesOnDb = 'Prida oprvnenia pre nasledujcu databzu';
 $strAddPrivilegesOnTbl = 'Prida oprvnenia pre nasledujcu tabuku';
 $strAddSearchConditions = 'Prida vyhadvacie parametre (obsah dotazu po "where" prkaze):';
@@ -47,6 +47,7 @@ $strAffectedRows = ' Ovplyvnen riadky: ';
 $strAfter = 'Po %s';
 $strAfterInsertBack = 'Sp';
 $strAfterInsertNewInsert = 'Vloi nov zznam';
+$strAfterInsertSame = 'Sp na tto strnku';
 $strAll = 'Vetko';
 $strAllTableSameWidth = 'zobrazi vetky tabuky s rovnakou rkou?';
 $strAlterOrderBy = 'Zmeni poradie tabuky poda';
@@ -54,10 +55,7 @@ $strAnIndex = 'Bol pridan index pre %s';
 $strAnalyzeTable = 'Analyzova tabuku';
 $strAnd = 'a';
 $strAny = 'Akkovek';
-$strAnyColumn = 'Akkovek stpec';
-$strAnyDatabase = 'Akkovek databza';
 $strAnyHost = 'Akkovek hostite';
-$strAnyTable = 'Akkovek tabuka';
 $strAnyUser = 'Akkovek pouvate';
 $strArabic = 'Arabtina';
 $strArmenian = 'Armntina';
@@ -88,9 +86,9 @@ $strBzError = 'nepodarilo sa skomprimova vstup z dvodu chybnho rozrenia pre komp
 $strBzip = '"bzipped"';
 
 $strCSVOptions = 'CSV nastavenia';
+$strCalendar = 'Kalendr';
 $strCannotLogin = 'Ned sa prihlsi k MySQL serveru';
 $strCantLoad = 'ned sa nahra rozrenie %s,<br />prosm skontrolujte konfigurciu PHP';
-$strCantLoadMySQL = 'nie je mon nahra rozrenie pre MySQL,<br />prosm skontrolujte konfigurciu PHP.';
 $strCantLoadRecodeIconv = 'Nie je mon nahra rozrenie iconv alebo recode potrebn pre prevod znakovch sad. Upravte nastavenie php tak aby umoovalo poui tieto rozrenia alebo vypnite tto vlastnos v konfigurcii phpMyAdmina.';
 $strCantRenameIdxToPrimary = 'Nie je mon premenova index na PRIMARY!';
 $strCantUseRecodeIconv = 'Nie je mon poui funkcie iconv,libiconv a recode_string aj napriek tomu, e rozrenia s nahran. Skontrolujte prosm nastavenie PHP.';
@@ -113,7 +111,6 @@ $strCharsetOfFile = 'Znakov sada sboru:';
 $strCharsets = 'Znakov sady';
 $strCharsetsAndCollations = 'Znakov sady a porovnvanie';
 $strCheckAll = 'Oznai vetko';
-$strCheckDbPriv = 'Skontrolova oprvnenia databzy';
 $strCheckOverhead = 'Zvoli neoptimlne';
 $strCheckPrivs = 'Skontrolova oprvnenia';
 $strCheckPrivsLong = 'Skontrolova oprvnenia pre databzu &quot;%s&quot;.';
@@ -121,16 +118,15 @@ $strCheckTable = 'Skontrolova tabuku';
 $strChoosePage = 'Prosm zvolte si Strnku, ktor chcete upravi';
 $strColComFeat = 'Zobrazova komentre stpcov';
 $strCollation = 'Porovnvanie';
-$strColumn = 'Stpec';
 $strColumnNames = 'Nzvy stpcov';
 $strColumnPrivileges = 'Oprvnenia pre jednotliv stpce';
 $strCommand = 'Prkaz';
 $strComments = 'Komentre';
+$strCommentsForTable = 'KOMENTRE PRE TABUKU';
 $strCompleteInserts = 'pln vloenie';
 $strCompression = 'Kompresia';
 $strConfigFileError = 'phpMyAdmin was unable to read your configuration file!<br />This might happen if php finds a parse error in it or php cannot find the file.<br />Please call the configuration file directly using the link below and read the php error message(s) that you recieve. In most cases a quote or a semicolon is missing somewhere.<br />If you recieve a blank page, everything is fine.';
 $strConfigureTableCoord = 'Prosm skonfigurujte koordinty pre tabuku %s';
-$strConfirm = 'Skutone si elte toto vykona?';
 $strConnectionError = 'Nepodarilo sa pripoji: chybn nastavenia.';
 $strConnections = 'Spojenia';
 $strConstraintsForDumped = 'Obmedzenie pre exportovan tabuky';
@@ -164,15 +160,16 @@ $strDBGMinTimeMs = 'Min as, ms';
 $strDBGModule = 'Modul';
 $strDBGTimePerHitMs = 'as/Zsah, ms';
 $strDBGTotalTimeMs = 'Celkov as, ms';
+$strDBRename = 'Premenova databzu na';
 $strDanish = 'Dnsky';
 $strData = 'Dta';
 $strDataDict = 'Dtov slovnk';
 $strDataOnly = 'Iba dta';
-$strDatabase = 'Databza ';
+$strDatabase = 'Databza';
+$strDatabaseEmpty = 'Meno databzy je przdne!';
 $strDatabaseExportOptions = 'Nastavenia exportu databz';
 $strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
 $strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
-$strDatabaseWildcard = 'Databza (nahradzujce znaky povolen):';
 $strDatabases = 'databz(y)';
 $strDatabasesDropped = 'spene zruench databz: %s.';
 $strDatabasesStats = 'tatistiky databzy';
@@ -183,21 +180,20 @@ $strDbPrivileges = 'Oprvnenia pre jednotliv databzy';
 $strDbSpecific = 'zvisl na databze';
 $strDefault = 'Predvolen';
 $strDefaultValueHelp = 'Pre predvolen hodnoty, prosm zadajte iba jednu hodnotu bez vodzoviek alebo uvdzacch znakov, napr.: a';
+$strDefragment = 'Defragmentova tabuku';
 $strDelOld = 'Aktulna strnka sa odkazuje na tabuky, ktor u neexistuj, elte si odstrni tieto odkazy?';
 $strDelayedInserts = 'Poui oneskoren vloenia';
 $strDelete = 'Zmaza';
 $strDeleteAndFlush = 'Odstrni pouvateov a znovunata prva.';
 $strDeleteAndFlushDescr = 'Toto je najistejie rieenie, ale znovunatanie prv me chvu trva.';
-$strDeleteFailed = 'Mazanie bolo nespen!';
-$strDeleteUserMessage = 'Pouvate %s bol zmazan.';
 $strDeleted = 'Riadok bol zmazan';
 $strDeletedRows = 'Zmazan riadky:';
 $strDeleting = 'Odstrauje sa %s';
 $strDescending = 'Zostupne';
 $strDescription = 'Popis';
 $strDictionary = 'slovnk';
+$strDisableForeignChecks = 'Vypn kontrolu cudzch kov';
 $strDisabled = 'Vypnut';
-$strDisplay = 'Zobrazi';
 $strDisplayFeat = 'Zobrazi vlastnosti';
 $strDisplayOrder = 'Zobrazi zoraden:';
 $strDisplayPDF = 'Zobrazi schmu PDF';
@@ -205,11 +201,9 @@ $strDoAQuery = 'Vykona "dotaz poda prkladu" (nahradzujci znak: "%")';
 $strDoYouReally = 'Skutone chcete vykona prkaz ';
 $strDocu = 'Dokumentcia';
 $strDrop = 'Odstrni';
-$strDropDB = 'Odstrni databzu %s';
+$strDropDatabaseStrongWarning = 'Chystte sa ZRUI cel databzu!';
 $strDropSelectedDatabases = 'Zrui vybran databzy';
-$strDropTable = 'Zrui tabuku';
 $strDropUsersDb = 'Odstrni databzy s rovnakm menom ako maj pouvatelia.';
-$strDumpComments = 'Vloi komentre stpcov ako SQL komentre';
 $strDumpSaved = 'Dump (schma) bol uloen do sboru %s.';
 $strDumpXRows = 'Zobrazi %s riadkov od riadku %s.';
 $strDumpingData = 'Sahujem dta pre tabuku';
@@ -222,6 +216,7 @@ $strEffective = 'Efektvny';
 $strEmpty = 'Vyprzdni';
 $strEmptyResultSet = 'MySQL vrtil przdny vsledok (tj. nulov poet riadkov).';
 $strEnabled = 'Zapnut';
+$strEncloseInTransaction = 'Uzatvori prkazy v transakcii';
 $strEnd = 'Koniec';
 $strEndCut = 'KONIEC VSEKU';
 $strEndRaw = 'KONIEC TOKU';
@@ -234,7 +229,6 @@ $strExcelOptions = 'Nastavenie exportu do Excelu';
 $strExecuteBookmarked = 'Spusti obben dotaz';
 $strExplain = 'Vysvetli SQL';
 $strExport = 'Exportova';
-$strExportToXML = 'Exportova do formtu XML';
 $strExtendedInserts = 'Rozren vkladanie';
 $strExtra = 'Extra';
 
@@ -269,7 +263,6 @@ $strGlobalPrivileges = 'Globlne prva';
 $strGlobalValue = 'Globlna hodnota';
 $strGo = 'Vykonaj';
 $strGrantOption = 'Prideli';
-$strGrants = 'Oprvnenia';
 $strGreek = 'Grtina';
 $strGzip = '"gzip-ovan"';
 
@@ -277,17 +270,19 @@ $strHasBeenAltered = 'bola zmenen.';
 $strHasBeenCreated = 'bola vytvoren.';
 $strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
 $strHebrew = 'Hebrejsky';
+$strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
 $strHome = 'Domov';
 $strHomepageOfficial = 'Oficilne strnky phpMyAdmin-a';
-$strHomepageSourceforge = 'Download strnka phpMyAdmin-a (Sourceforge)';
 $strHost = 'Hostite';
 $strHostEmpty = 'Nzov hostitea je przdny!';
 $strHungarian = 'Maarsky';
 
+$strIcelandic = 'Islandina';
 $strId = 'ID';
 $strIdxFulltext = 'Cel text';
 $strIfYouWish = 'Ak si elte nahra iba urit stpce tabuky, pecifikujte ich ako zoznam pol oddelen iarkou.';
 $strIgnore = 'Ignorova';
+$strIgnoreInserts = 'Poui IGNORE';
 $strIgnoringFile = 'Ignorujem sbor %s';
 $strImportDocSQL = 'Importova sbory docSQL';
 $strImportFiles = 'Importova sbory';
@@ -309,7 +304,6 @@ $strInsertedRows = 'Vloen riadky:';
 $strInstructions = 'Intrukcie';
 $strInternalNotNecessary = '* Vntorn vzah nie je nutn ak u vzah existuje v InnoDB.';
 $strInternalRelations = 'Intern vzahy';
-$strInvalidName = '"%s" je rezervovan slovo, neme by pouit ako nzov databzy/tabuky/poa.';
 
 $strJapanese = 'Japonina';
 $strJumpToDB = 'Na databzu &quot;%s&quot;.';
@@ -331,11 +325,10 @@ $strLatexContinuedCaption = 'Nadpis pokraovania tabuky';
 $strLatexIncludeCaption = 'Zahrn nadpis tabuky';
 $strLatexLabel = 'Nvestie';
 $strLatexStructure = 'truktra tabuky __TABLE__';
-$strLength = 'Dka';
+$strLatvian = 'Lotystina';
 $strLengthSet = 'Dka/Nastavi*';
 $strLimitNumRows = 'zznamov na strnku';
 $strLineFeed = 'Ukonenie riadku (Linefeed): \\n';
-$strLines = 'Riadky';
 $strLinesTerminatedBy = 'Riadky ukonen';
 $strLinkNotFound = 'Linka nebola njden';
 $strLinksTo = 'Linkova na';
@@ -351,11 +344,11 @@ $strLogin = 'Login';
 $strLoginInformation = 'Prihlsenie';
 $strLogout = 'Odhlsi sa';
 
+$strMIMETypesForTable = 'MIME TYPY PRE TABUKU';
 $strMIME_MIMEtype = 'MIME typ';
 $strMIME_available_mime = 'Dostupn MIME typy';
 $strMIME_available_transform = 'Dostupn transformcie';
 $strMIME_description = 'Popis';
-$strMIME_file = 'Meno sboru';
 $strMIME_nodescription = 'Nie je dostupn iadny popis pre tto transformciu.<br />Kontaktujte autora, ktor %s vytra.';
 $strMIME_transformation = 'Transformcia pri prehliadan';
 $strMIME_transformation_note = 'Pre zoznam dostupnch parametrov a ich MIME typov kliknite na %spopisy transformci';
@@ -363,7 +356,6 @@ $strMIME_transformation_options = 'Parametre transformcie';
 $strMIME_transformation_options_note = 'Prosm zadajte hodnoty pre parametre transformcie v nasledujcom tvare: \'a\',\'b\',\'c\'...<br />Ak potrebujete poui sptn lomtko ("\") alebo jednoduch vodzovky ("\'") medzi tmito hodnotami, vlote pred nich sptn lomtko (napr. \'\\\\xyz\' alebo \'a\\\'b\').';
 $strMIME_without = 'MIME typy zobrazen kurzvou nemaj vlastn transforman funkciu';
 $strMaximumSize = 'Maximlna vekos: %s%s';
-$strMissingBracket = 'Chba ztvorka';
 $strModifications = 'Zmeny boli uloen';
 $strModify = 'Zmeni';
 $strModifyIndexTopic = 'Modifikova index';
@@ -374,6 +366,7 @@ $strMoveTableSameNames = 'Ned sa presun tabuka sama do seba!';
 $strMultilingual = 'mnohojazyn';
 $strMustSelectFile = 'Zvolte prosm sbor, ktor si elte vloi.';
 $strMySQLCharset = 'Znakov sada v MySQL';
+$strMySQLConnectionCollation = 'Overenie MySQL spojenia';
 $strMySQLReloaded = 'MySQL znovu-natan.';
 $strMySQLSaid = 'MySQL hlsi: ';
 $strMySQLServerProcess = 'MySQL %pma_s1% be na %pma_s2% ako %pma_s3%';
@@ -382,6 +375,7 @@ $strMySQLShowStatus = 'Zobrazi MySQL informcie o behu';
 $strMySQLShowVars = 'Zobrazi MySQL systmov premenn';
 
 $strName = 'Nzov';
+$strNeedPrimaryKey = 'Pre tto tabuku by ste mali definova primrny k.';
 $strNext = 'al';
 $strNo = 'Nie';
 $strNoDatabases = 'iadne databzy';
@@ -400,10 +394,10 @@ $strNoPhp = 'bez PHP kdu';
 $strNoPrivileges = 'iadne oprvnenia';
 $strNoQuery = 'iadny SQL dotaz!';
 $strNoRights = 'Nemte dostaton prva na vykonanie tejto akcie!';
+$strNoRowsSelected = 'Nebol vybran iadny riadok';
 $strNoSpace = 'Nedostatok miesta pre uloenie sboru %s.';
 $strNoTablesFound = 'Neboli njden iadne tabuky v tejto datbaze.';
 $strNoUsersFound = 'Nebol njden iadny pouvate.';
-$strNoUsersSelected = 'Nebol vybran iaden pouvate.';
 $strNoValidateSQL = 'Preskoi potvrdenie platnosti SQL';
 $strNone = 'iadny';
 $strNotNumber = 'Toto nie je slo!';
@@ -418,10 +412,10 @@ $strNumTables = 'Tabuky';
 $strOK = 'OK';
 $strOftenQuotation = 'asto uvodzujce znaky. Volitene znamen, e iba polia typu char a varchar s uzatvoren do "uzatvracch" znakov.';
 $strOperations = 'Opercie';
+$strOperator = 'Opertor';
 $strOptimizeTable = 'Optimalizova tabuku';
 $strOptionalControls = 'Voliten. Uruje ako zapisova alebo ta pecilne znaky.';
 $strOptionally = 'Volitene';
-$strOptions = 'Voby';
 $strOr = 'alebo';
 $strOverhead = 'Naviac';
 $strOverwriteExisting = 'Prepsa existujci sbor(y)';
@@ -436,7 +430,6 @@ $strPasswordChanged = 'Heslo pre %s bolo spene zmenen.';
 $strPasswordEmpty = 'Heslo je przdne!';
 $strPasswordNotSame = 'Hesl sa nezhoduj!';
 $strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
-$strPdfInvalidPageNum = 'Nedefinovan slo strnky v PDF!';
 $strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
 $strPdfNoTables = 'iadne tabuky';
 $strPerHour = 'za hodinu';
@@ -446,11 +439,11 @@ $strPhoneBook = 'adresr';
 $strPhp = 'Vytvori PHP kd';
 $strPmaDocumentation = 'phpMyAdmin Dokumentcia';
 $strPmaUriError = 'Direktva <tt>$cfg[\'PmaAbsoluteUri\']</tt> v konfiguranom sbore MUS by nastaven!';
+$strPolish = 'Potina';
 $strPortrait = 'Na vku';
 $strPos1 = 'Zaiatok';
 $strPrevious = 'Predchdzajci';
 $strPrimary = 'Primrny';
-$strPrimaryKey = 'Primrny k';
 $strPrimaryKeyHasBeenDropped = 'Primrny k bol zruen';
 $strPrimaryKeyName = 'Nzov primrneho ka mus by... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>mus</b> by <b>iba</b> meno primrneho ka!)';
@@ -489,15 +482,12 @@ $strPrivDescUsage = 'iadne prva.';
 $strPrivileges = 'Oprvnenia';
 $strPrivilegesReloaded = 'Prva boli spene znovunatan.';
 $strProcesslist = 'Zoznam procesov';
-$strProperties = 'Vlastnosti';
 $strPutColNames = 'Prida nzvy pol na prv riadok';
 
 $strQBE = 'Dotaz poda prkladu';
 $strQBEDel = 'Zmaza';
 $strQBEIns = 'Vloi';
 $strQueryFrame = 'SQL okno';
-$strQueryFrameDebug = 'Ladiace informcie';
-$strQueryFrameDebugBox = 'Aktvne premenn pre formulr dotazu:\nDB: %s\nTabuka: %s\nServer: %s\n\nAktulne premenne pre formulr dotazu:\nDB: %s\nTabuka: %s\nServer: %s\n\nOtvoren z: %s\nFrameset: %s.';
 $strQueryOnDb = ' SQL dotaz v databze <b>%s</b>:';
 $strQuerySQLHistory = 'SQL histria';
 $strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
@@ -509,15 +499,17 @@ $strReType = 'Potvrdi';
 $strReceived = 'Prijat';
 $strRecords = 'Zznamov';
 $strReferentialIntegrity = 'Skontrolova referenn integritu:';
+$strRefresh = 'Obnovi';
 $strRelationNotWorking = 'Prdavn vlastnosti pre prcu s prepojenmi tabukami boli deaktivovan. Ak chcete zisti preo, kliknite %ssem%s.';
 $strRelationView = 'Zobrazi spojitosti';
 $strRelationalSchema = 'Relan schma';
 $strRelations = 'Prepojenia';
+$strRelationsForTable = 'VZAHY PRE TABUKU';
 $strReloadFailed = 'Znovu-natanie MySQL bolo nespen.';
 $strReloadMySQL = 'Znovu-nata MySQL';
 $strReloadingThePrivileges = 'Znovunatanie prv';
-$strRememberReload = 'Nezabudnite znovu-nata MySQL server.';
 $strRemoveSelectedUsers = 'Odstrni vybranch pouvateov';
+$strRenameDatabaseOK = 'Databza %s bola premenovan na %s';
 $strRenameTable = 'Premenova tabuku na';
 $strRenameTableOK = 'Tabuka %s bola premenovan na %s';
 $strRepairTable = 'Opravi tabuku';
@@ -529,10 +521,8 @@ $strResourceLimits = 'Obmedzenie zdrojov';
 $strRevoke = 'Zrui';
 $strRevokeAndDelete = 'Odobranie vetkch aktvnych prv pouvateom a ich nsledn odstrnenie.';
 $strRevokeAndDeleteDescr = 'Uvatelia bud ma stle prvo USAGE (pouvanie) a do znovunatania prv.';
-$strRevokeGrant = 'Zrui polovenie prideova oprvnenia';
-$strRevokeGrantMessage = 'Bolo zruen prvo prideova oprvnenia pre %s';
 $strRevokeMessage = 'Boli zruen oprvnenia pre %s';
-$strRevokePriv = 'Zrui oprvnenia';
+$strRomanian = 'Rumuntina';
 $strRowLength = 'Dka riadku';
 $strRowSize = ' Vekos riadku ';
 $strRows = 'Riadkov';
@@ -571,7 +561,6 @@ $strSearchOption4 = 'ako regulrny vraz';
 $strSearchResultsFor = 'Prehada vsledky na "<i>%s</i>" %s:';
 $strSearchType = 'Njdi:';
 $strSecretRequired = 'Nastavte prosm k pre ifrovanie cookies v konfiguranom sbore (blowfish_secret).';
-$strSelect = 'Vybra';
 $strSelectADb = 'Prosm vyberte si databzu';
 $strSelectAll = 'Oznai vetko';
 $strSelectFields = 'Zvoli pole (najmenej jedno):';
@@ -579,8 +568,9 @@ $strSelectNumRows = 'v dotaze';
 $strSelectTables = 'Vybra Tabuky';
 $strSend = 'Poli';
 $strSent = 'Odoslan';
-$strServer = 'Server %s';
+$strServer = 'Server';
 $strServerChoice = 'Voba serveru';
+$strServerNotResponding = 'Server neodpoved';
 $strServerStatus = 'Stav serveru';
 $strServerStatusUptime = 'Tento server be %s. Bol spusten %s.';
 $strServerTabProcesslist = 'Procesy';
@@ -593,7 +583,6 @@ $strSetEnumVal = 'Ak je pole typu "enum" alebo "set", prosm zadvajte hodnoty v t
 $strShow = 'Ukza';
 $strShowAll = 'Zobrazi vetko';
 $strShowColor = 'Zobrazi farbu';
-$strShowCols = 'Zobrazi stpce';
 $strShowDatadictAs = 'Formt dtovho slovnka';
 $strShowFullQueries = 'Zobrazi kompletn dotazy';
 $strShowGrid = 'Zobrazi mrieku';
@@ -605,9 +594,12 @@ $strShowingRecords = 'Ukza zznamy ';
 $strSimplifiedChinese = 'Zjednoduen ntina';
 $strSingly = '(po jednom)';
 $strSize = 'Vekos';
+$strSlovak = 'Slovenina';
+$strSlovenian = 'Slovinina';
 $strSort = 'Triedi';
 $strSortByKey = 'Zoradi poda ka';
 $strSpaceUsage = 'Zabran miesto';
+$strSpanish = 'panielsky';
 $strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
 $strStatCheckTime = 'Posledn kontrola';
 $strStatCreateTime = 'Vytvorenie';
@@ -617,7 +609,8 @@ $strStatus = 'Stav';
 $strStrucCSV = 'CSV dta';
 $strStrucData = 'truktru a dta';
 $strStrucDrop = 'Pridaj \'vyma tabuku\'';
-$strStrucExcelCSV = 'CSV pre Ms Excel dta';
+$strStrucExcelCSV = 'CSV pre MS Excel dta';
+$strStrucNativeExcel = 'Natvne dta MS Excel';
 $strStrucOnly = 'Iba truktru';
 $strStructPropose = 'Navrhn truktru tabuky';
 $strStructure = 'truktra';
@@ -639,12 +632,14 @@ $strTableOptions = 'Parametre tabuky';
 $strTableStructure = 'truktra tabuky pre tabuku';
 $strTableType = 'Typ tabuky';
 $strTables = '%s tabuka(y)';
+$strTakeIt = 'zvoli';
 $strTblPrivileges = 'Oprvnenia pre jednotliv tabuky';
 $strTextAreaLength = ' Toto mono nepjde upravi,<br /> kvli svojej dke ';
 $strThai = 'Thajina';
 $strTheContent = 'Obsah Vho sboru bol vloen.';
 $strTheContents = 'Obsah sboru prepe obsah vybranej tabuky v riadkoch s identickm primrnym alebo uniktnym kom.';
 $strTheTerminator = 'Ukonenie pol.';
+$strTheme = 'Vzhad';
 $strThisHost = 'Tento pota';
 $strThisNotDirectory = 'Nebol zadan adresr';
 $strThreadSuccessfullyKilled = 'Vlkno %s bol spene zabit.';
@@ -653,6 +648,7 @@ $strToggleScratchboard = 'zobrazi grafick nvrh';
 $strTotal = 'celkovo';
 $strTotalUC = 'Celkom';
 $strTraditionalChinese = 'Tradin ntina';
+$strTraditionalSpanish = 'Tradin panielina';
 $strTraffic = 'Prevdzka';
 $strTransformation_application_octetstream__download = 'Zobraz odkaz na stiahnutie dt. Prv parameter je meno sboru, druh je meno stpca v tabuke obsahujci meno sboru. Ak zadte druh parameter, prv mus by przdny.';
 $strTransformation_image_jpeg__inline = 'Zobraz nhad obrzku s odkazom na obrzok; parametre rka a vka v bodoch (pomer strn obrzku zostane zachovan)';
@@ -664,7 +660,6 @@ $strTransformation_text_plain__formatted = 'Zachov pvodn formtovanie poa tak ako
 $strTransformation_text_plain__imagelink = 'Zobraz obrzok a odkaz z poa obsahujceho odkaz na obrzok. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh a tret parameter uruj rku a vku obrzku.';
 $strTransformation_text_plain__link = 'Zobraz odkaz z poa obsahujceho odkaz. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh parameter je text odkazu.';
 $strTransformation_text_plain__substr = 'Zobraz iba as reazca. Prv parameter je posun od zaiatku (predvolen je 0) a druh uruje dku textu, ktor sa ma zobrazi, ak nie je zadan bude zobrazen zvyok textu. Tret parameter uruje znaky, ktor bud pridan na koniec skrtenho textu (predvolen je ...).';
-$strTransformation_text_plain__unformatted = 'Zobraz HTML kd pomocou HMTL entt. Prpadn HTML kd sa zobraz v pvodnom stave.';
 $strTruncateQueries = 'Zobrazi skrtene dotazy';
 $strTurkish = 'Turecky';
 $strType = 'Typ';
@@ -677,7 +672,6 @@ $strUnknown = 'neznmy';
 $strUnselectAll = 'Odznai vetko';
 $strUpdComTab = 'Prosm pretajte si dokumentciu ako aktualizova tabuku s informciami o stpcoch (Column_comments Table)';
 $strUpdatePrivMessage = 'Boli aktualizovan oprvnenia pre %s.';
-$strUpdateProfile = 'Aktualizova profil:';
 $strUpdateProfileMessage = 'Profil bol aktualizovan.';
 $strUpdateQuery = 'Aktualizova dotaz';
 $strUpgrade = 'Mali by ste aktualizova %s na verziu %s alebo vyiu.';
@@ -693,7 +687,6 @@ $strUserEmpty = 'Meno pouvatea je przdne!';
 $strUserName = 'Meno pouvatea';
 $strUserNotFound = 'Zvolen pouvate nebol njden v tabuke prv.';
 $strUserOverview = 'Prehad uvatelov';
-$strUsers = 'Pouvatelia';
 $strUsersDeleted = 'Vybran uvatelia bol spene odstrnen.';
 $strUsersHavingAccessToDb = 'Pouvatelia majci prstup k &quot;%s&quot;';
 
@@ -723,5 +716,85 @@ $strYes = 'no';
 $strZeroRemovesTheLimit = 'Poznmka: Nastavenie tchto parametrov na 0 (nulu) odstrni obmedzenia.';
 $strZip = '"zo zipovan"';
 
-$strSpanish = 'Spanish';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
