@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovenian-utf-8.inc.php,v 2.6.2.1 2004/06/07 10:09:56 rabus Exp $ */
+/* $Id: slovenian-utf-8.inc.php,v 2.69 2005/03/30 19:24:39 lem9 Exp $ */
 
 /* By: urska.colner, agenda d.o.o. <urska.colner@agenda.si>, uros kositer, agenda d.o.o. <urosh@agenda.si> */
 
@@ -27,13 +27,14 @@ $strAccessDenied = 'Dostop zavrnjen';
 $strAccessDeniedExplanation = 'phpMyAdmin se je poskušal povezati na MySQL strežnik, ki je zavrnil povezavo. Preverite, ali gostitelj, uporabniško ime in geslo v datoteki config.inc.php ustrezajo podatkom administratorja MySQL strežnika.';
 $strAction = 'Akcija';
 $strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
+$strAddConstraints = 'Dodaj omejitve';
 $strAddDeleteColumn = 'Dodaj/Odstrani stolpec \'Polje\'';
 $strAddDeleteRow = 'Dodaj/Odstrani vrstico \'Kriterij\'';
 $strAddDropDatabase = 'Dodaj DROP DATABASE';
+$strAddHeaderComment = 'Dodaj prilagojen komentar v glavo (\\n prelomi vrstice)';
+$strAddIfNotExists = 'Dodaj ČE NE OBSTAJA';
 $strAddIntoComments = 'Dodaj med komentarje';
 $strAddNewField = 'Dodaj novo polje';
-$strAddPriv = 'Dodaj nov privilegij';
-$strAddPrivMessage = 'Dodali ste nov privilegij.';
 $strAddPrivilegesOnDb = 'Dodaj privilegije na naslednji podatkovni bazi';
 $strAddPrivilegesOnTbl = 'Dodaj privilegije na naslednji tabeli';
 $strAddSearchConditions = 'Dodaj iskalne pogoje (telo "where" stavka):';
@@ -47,6 +48,7 @@ $strAffectedRows = 'Spremenjene vrstice:';
 $strAfter = 'Po %s';
 $strAfterInsertBack = 'Nazaj na prejšnjo stran';
 $strAfterInsertNewInsert = 'Vstavi še eno novo vrstico';
+$strAfterInsertSame = 'Pojdi nazaj na stran';
 $strAll = 'Vse/Vsi';
 $strAllTableSameWidth = 'prikažem vse tabele enake širine?';
 $strAlterOrderBy = 'Spremeni vrstni red prikaza tabele za';
@@ -54,10 +56,7 @@ $strAnIndex = 'Na %s je dodan indeks';
 $strAnalyzeTable = 'Analiziraj tabelo';
 $strAnd = 'In';
 $strAny = 'Katerikoli';
-$strAnyColumn = 'Katerikoli stolpec';
-$strAnyDatabase = 'Katerakoli podatkovna baza';
 $strAnyHost = 'Katerikoli gostitelj';
-$strAnyTable = 'Katerakoli tabela';
 $strAnyUser = 'Katerikoli uporabnik';
 $strArabic = 'Arabsko';
 $strArmenian = 'Armensko';
@@ -88,9 +87,9 @@ $strBzError = 'phpMyAdmin ni uspel stisniti odloženih podatkov zaradi neuporabn
 $strBzip = '"bzipano"';
 
 $strCSVOptions = 'CSV možnosti';
+$strCalendar = 'Koledar';
 $strCannotLogin = 'Ne morem se prijaviti v MySQL strežnik';
 $strCantLoad = 'ne morem naložiti podaljška %s,<br />prosim preverite PHP konfiguracijo';
-$strCantLoadMySQL = 'ni mogoče naložiti MySQL ekstenzij,<br /> prosimo, preverite PHP konfiguracijo.';
 $strCantLoadRecodeIconv = 'Ni mogoče naložiti iconv ali recode ekstenzij, ki so potrebne za pretvorbe kodnih tabel, konfigurirajte php tako, da bo omogočal uporabo teh ekstenzij ali onemogočite pretvarjanje kodnih tabel v phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Indeksa ni mogoče preimenovati v PRIMARY!';
 $strCantUseRecodeIconv = 'Ni mogoče uporabljati iconv, libiconv ali recode_string funkcij, čeprav so ekstenzije normalno naložene. Preverite konfiguracijo php.';
@@ -113,23 +112,23 @@ $strCharsetOfFile = 'Nabor znakov datoteke:';
 $strCharsets = 'Nabori znakov';
 $strCharsetsAndCollations = 'Nabori znakov in pravila za razvrščanje znakov';
 $strCheckAll = 'Označi vse';
-$strCheckDbPriv = 'Preveri privilegije podatkovne baze';
+$strCheckOverhead = 'Preveri prekoračene';
 $strCheckPrivs = 'Preveri privilegije';
 $strCheckPrivsLong = 'Preveri privilegije za podatkovno bazo &quot;%s&quot;.';
 $strCheckTable = 'Preveri tabelo';
 $strChoosePage = 'Izberite stran za urejanje';
 $strColComFeat = 'Prikazovanje komentarjev stolpcev';
 $strCollation = 'Pravilo za razvrščanje znakov';
-$strColumn = 'Stolpec';
 $strColumnNames = 'Imena stolpcev';
 $strColumnPrivileges = 'Privilegiji tipični za stolpec';
 $strCommand = 'Ukaz';
 $strComments = 'Komentarji';
+$strCommentsForTable = 'KOMENTARJI ZA TABELO';
 $strCompleteInserts = 'Popolne \'insert\' poizvedbe';
 $strCompression = 'Stiskanje';
 $strConfigFileError = 'phpMyAdmin ni mogel prebrati konfiguracijske datoteke!<br />To se lahko zgodi, če php pri prevajanju konfiguracijske datoteke najde napako ali pa ne najde datoteke.<br />Prosimo, odprite konfiguracijsko datoteko s povezavo, ki je navedena spodaj in preberite dobljeno sporočilo o napaki. V večini primerov gre za manjkajoči narekovaj ali podpičje.<br />Če dobite prazno stran, je vse v redu.';
 $strConfigureTableCoord = 'Prosimo, konfigurirajte koordinate za tabelo %s';
-$strConfirm = 'Ali res želite to storiti?';
+$strConnectionError = 'Povezava ni mogoča: neveljavne nastavitve.';
 $strConnections = 'Povezave';
 $strConstraintsForDumped = 'Omejitve tabel za povzetek stanja';
 $strConstraintsForTable = 'Omejitve za tabelo';
@@ -145,10 +144,12 @@ $strCreateNewDatabase = 'Ustvari novo podatkovno bazo';
 $strCreateNewTable = 'Ustvari novo tabelo v podatkovni bazi %s';
 $strCreatePage = 'Ustvari novo stran';
 $strCreatePdfFeat = 'Ustvarjanje PDF datotek';
+$strCreationDates = 'Datumi za ustvarjeno/posodobljeno/preverjeno';
 $strCriteria = 'Kriteriji';
 $strCroatian = 'Hrvaško';
 $strCyrillic = 'Cirilica';
 $strCzech = 'Češko';
+$strCzechSlovak = 'Češkoslovaško';
 
 $strDBComment = 'Komentar zbirke podatkov: ';
 $strDBGContext = 'Kontekst';
@@ -160,15 +161,16 @@ $strDBGMinTimeMs = 'Najmanjši čas, ms';
 $strDBGModule = 'Modul';
 $strDBGTimePerHitMs = 'Čas/Zadetek, ms';
 $strDBGTotalTimeMs = 'Skupni čas, ms';
+$strDBRename = 'Preimenuj podatkovno bazo v';
 $strDanish = 'Dansko';
 $strData = 'Podatki';
 $strDataDict = 'Podatkovni slovar';
 $strDataOnly = 'Samo podatki';
-$strDatabase = 'Podatkovna baza ';
+$strDatabase = 'Podatkovna baza';
+$strDatabaseEmpty = 'Ime podatkovne baze je prazno!';
 $strDatabaseExportOptions = 'Možnosti za izvoz baze podatkov';
 $strDatabaseHasBeenDropped = 'Podatkovna baza %s je zavržena.';
 $strDatabaseNoTable = 'Ta baza podatkov ne vsebuje tabele!!';
-$strDatabaseWildcard = 'Podatkovna baza (nadomestni znaki dovoljeni):';
 $strDatabases = 'podatkovne baze';
 $strDatabasesDropped = '%s podatkovne baze so uspešno zavržene.';
 $strDatabasesStats = 'Statistika podatkovnih baz';
@@ -180,11 +182,10 @@ $strDbSpecific = 'glede na zbirko podatkov';
 $strDefault = 'Privzeto';
 $strDefaultValueHelp = 'Za privzete vrednosti vnesite samo vrednosti, brez poševnice nazaj ali narekovaja, npr.: a';
 $strDelOld = 'Trenutna stran vsebuje sklice na tabele, ki ne obstajajo več. Ali želite izbrisati te sklice?';
+$strDelayedInserts = 'Uporabi zakasnjeno vstavljanje';
 $strDelete = 'Izbriši';
 $strDeleteAndFlush = 'Izbriši uporabnike in potem osveži privilegije.';
 $strDeleteAndFlushDescr = 'To je najboljši način, vendar lahko osveževanje privilegijev traja nekaj časa.';
-$strDeleteFailed = 'Brisanje ni uspelo!';
-$strDeleteUserMessage = 'Izbrisali ste uporabnika %s.';
 $strDeleted = 'Vrstica je izbrisana';
 $strDeletedRows = 'Izbrisane vrstice:';
 $strDeleting = 'Brišem %s';
@@ -192,7 +193,6 @@ $strDescending = 'Padajoče';
 $strDescription = 'Opis';
 $strDictionary = 'slovar';
 $strDisabled = 'Onemogočeno';
-$strDisplay = 'Prikaži';
 $strDisplayFeat = 'Prikaži lastnosti';
 $strDisplayOrder = 'Vrstni red prikaza:';
 $strDisplayPDF = 'Prikaži PDF shemo';
@@ -200,11 +200,9 @@ $strDoAQuery = 'Izvedi "query by example" (nadomestni znak: "%")';
 $strDoYouReally = 'Ali res želite ';
 $strDocu = 'Dokumentacija';
 $strDrop = 'Zavrži';
-$strDropDB = 'Zavrži podatkovno bazo %s';
+$strDropDatabaseStrongWarning = 'S tem dejanjem boste UNIČILI celotno bazo podatkov!';
 $strDropSelectedDatabases = 'Zavrži izbrane podatkovne baze';
-$strDropTable = 'Zavrži tabelo';
 $strDropUsersDb = 'Izbriši podatkovne baze, ki imajo enako ime kot uporabniki.';
-$strDumpComments = 'Vključi komentarje stolpcev v SQL-stavke';
 $strDumpSaved = 'Dump je shranjen v datoteko %s.';
 $strDumpXRows = 'Odloži %s vrstic, začni z zapisom # %s.';
 $strDumpingData = 'Odloži podatke za tabelo';
@@ -217,6 +215,7 @@ $strEffective = 'Učinkovito';
 $strEmpty = 'Izprazni';
 $strEmptyResultSet = 'MySQL je vrnil kot rezultat prazno množico (npr. nič vrstic).';
 $strEnabled = 'Omogočeno';
+$strEncloseInTransaction = 'Vključi izvoz v transakcijo';
 $strEnd = 'Konec';
 $strEndCut = 'KONEC IZREZA';
 $strEndRaw = 'END RAW';
@@ -224,11 +223,11 @@ $strEnglish = 'Angleško';
 $strEnglishPrivileges = ' Opomba: Imena MySQL privilegijev so zapisana v angleščini ';
 $strError = 'Napaka';
 $strEstonian = 'Estonsko';
+$strExcelEdition = 'Izdaja za Excel';
 $strExcelOptions = 'Možnosti za Excel';
 $strExecuteBookmarked = 'Izvedi izbrano poizvedbo';
 $strExplain = 'Razloži SQL stavek';
 $strExport = 'Izvozi';
-$strExportToXML = 'Izvozi v XML obliko';
 $strExtendedInserts = 'Razširjene \'insert\' poizvedbe';
 $strExtra = 'Dodatno';
 
@@ -256,13 +255,13 @@ $strFunction = 'Funkcija';
 $strGenBy = 'Ustvaril';
 $strGenTime = 'Čas nastanka';
 $strGeneralRelationFeat = 'Splošne lastnosti relacij';
+$strGeorgian = 'Gruzijsko';
 $strGerman = 'Nemško';
 $strGlobal = 'globalno';
 $strGlobalPrivileges = 'Globalni privilegiji';
 $strGlobalValue = 'Skupna vrednost';
 $strGo = 'Izvedi';
 $strGrantOption = 'Dovoli';
-$strGrants = 'Dovoljenja';
 $strGreek = 'Grško';
 $strGzip = '"gzipano"';
 
@@ -272,7 +271,6 @@ $strHaveToShow = 'Za prikaz morate izbrati morate vsaj en stolpec';
 $strHebrew = 'Hebrejsko';
 $strHome = 'Domov';
 $strHomepageOfficial = 'Uradna domača stran phpMyAdmin';
-$strHomepageSourceforge = 'Sourceforge phpMyAdmin Download Page';
 $strHost = 'Gostitelj';
 $strHostEmpty = 'Ime gostitelja je prazno!';
 $strHungarian = 'Madžarsko';
@@ -281,6 +279,7 @@ $strId = 'ID';
 $strIdxFulltext = 'Polno besedilo';
 $strIfYouWish = 'Če bi radi naložili samo nekatere stolpce tabele, jih navedite v seznamu, kjer jih ločite z vejico.';
 $strIgnore = 'Prezri';
+$strIgnoreInserts = 'Uporabi možnost prezri vstavke';
 $strIgnoringFile = 'Prezrl sem datoteko %s';
 $strImportDocSQL = 'Uvozi docSQL datoteke';
 $strImportFiles = 'Uvozi datoteke';
@@ -302,7 +301,6 @@ $strInsertedRows = 'Vstavljene vrstice:';
 $strInstructions = 'Navodila';
 $strInternalNotNecessary = '* Notranja relacija je nepotrebna, če obstaja tudi v InnoDB.';
 $strInternalRelations = 'Notranje relacije';
-$strInvalidName = 'beseda "%s" je rezervirana, zato je ne morete uporabiti kot ime podatkovne baze/tabele/polja.';
 
 $strJapanese = 'Japonsko';
 $strJumpToDB = 'Preskoči na podatkovno bazo &quot;%s&quot;.';
@@ -324,11 +322,9 @@ $strLatexContinuedCaption = 'Nadaljevanje imena tabele';
 $strLatexIncludeCaption = 'Vključi ime tabele';
 $strLatexLabel = 'Označi ključ';
 $strLatexStructure = 'Struktura tabele __TABLE__';
-$strLength = 'Dolžina';
 $strLengthSet = 'Dolžina/Vrednosti*';
 $strLimitNumRows = 'Število vrstic na stran';
 $strLineFeed = 'Pomik v novo vrsto (Linefeed): \\n';
-$strLines = 'Vrstice';
 $strLinesTerminatedBy = 'Vrstice zaključene z';
 $strLinkNotFound = 'Povezave ni mogoče najti';
 $strLinksTo = 'Povezave z';
@@ -344,18 +340,18 @@ $strLogin = 'Prijava';
 $strLoginInformation = 'Podatki o prijavi';
 $strLogout = 'Odjava';
 
+$strMIMETypesForTable = 'VRSTE MIME ZA TABELO';
 $strMIME_MIMEtype = 'MIME-vrsta';
 $strMIME_available_mime = 'Razpoložljive MIME-vrste';
 $strMIME_available_transform = 'Razpoložljive pretvorbe';
 $strMIME_description = 'Opis';
-$strMIME_file = 'Datoteka';
 $strMIME_nodescription = 'Za to pretvorbo ni na voljo opisa.<br />Za funkcije %s se pozanimajte pri avtorju.';
 $strMIME_transformation = 'Pretvorba z brskalnikom';
 $strMIME_transformation_note = 'Seznam razpoložljivih možnosti pretvorbe in pretvorbe MIME-vrst boste videli, če kliknete na %sopise transformacij%s';
 $strMIME_transformation_options = 'Možnosti pretvorbe';
 $strMIME_transformation_options_note = 'Vrednosti za možnosti pretvorbe vnesite v naslednji obliki: \'a\',\'b\',\'c\'...<br />Če želite med vrednosti vnesti poševnico nazaj ("\") ali enojni narekovaj ("\'"), morate pred ta znak postaviti (še eno) poševnico nazaj (npr. \'\\\\xyz\' ali \'a\\\'b\').';
 $strMIME_without = 'MIME-vrste, ki so napisano ležeče, nimajo lastne pretvorbene funkcije';
-$strMissingBracket = 'Manjkajoč oklepaj';
+$strMaximumSize = 'Največja velikost: %s%s';
 $strModifications = 'Spremembe so shranjene';
 $strModify = 'Spremeni';
 $strModifyIndexTopic = 'Spremeni indeks';
@@ -374,6 +370,7 @@ $strMySQLShowStatus = 'Pokaži tekoče informacije o MySQL';
 $strMySQLShowVars = 'Pokaži sistemske spremenljivke MySQL';
 
 $strName = 'Ime';
+$strNeedPrimaryKey = 'Določite primarni ključ za to tabelo.';
 $strNext = 'Naslednji';
 $strNo = 'Ne';
 $strNoDatabases = 'Brez podatkovnih baz';
@@ -392,10 +389,9 @@ $strNoPhp = 'Brez kode PHP';
 $strNoPrivileges = 'Brez privilegijev';
 $strNoQuery = 'Brez SQL poizvedbe!';
 $strNoRights = 'Nimate dovolj pravic, da bi bili sedaj tukaj!';
-$strNoSpace = 'Ni dovolj prostora za shranjevanje datoteke %s.'; 
+$strNoSpace = 'Ni dovolj prostora za shranjevanje datoteke %s.';
 $strNoTablesFound = 'V podatkovni bazi ni mogoče najti tabel.';
 $strNoUsersFound = 'Ni mogoče najti uporabnika(ov).';
-$strNoUsersSelected = 'Ni izbranih uporabnikov.';
 $strNoValidateSQL = 'Preskoči preverjanje pravilnosti SQL stavka';
 $strNone = 'Brez';
 $strNotNumber = 'To ni število!';
@@ -410,10 +406,10 @@ $strNumTables = 'Ttabel';
 $strOK = 'V redu';
 $strOftenQuotation = 'Pogosti narekovaji. OPCIJSKO pomeni, da so samo polja tipa \'char\' in \'varchar\' obdana s temi znaki.';
 $strOperations = 'Operacije';
+$strOperator = 'Operator';
 $strOptimizeTable = 'Optimiraj tabelo';
 $strOptionalControls = 'Opcijsko. Narekuje način pisanja in branja posebnih znakov.';
 $strOptionally = 'OPCIJSKO';
-$strOptions = 'Možnosti';
 $strOr = 'Ali';
 $strOverhead = 'Presežek';
 $strOverwriteExisting = 'Prepiši obstoječo(e) datoteko(e)';
@@ -428,7 +424,6 @@ $strPasswordChanged = 'Geslo za %s je uspešno spremenjeno.';
 $strPasswordEmpty = 'Geslo je prazno!';
 $strPasswordNotSame = 'Gesli se ne ujemata!';
 $strPdfDbSchema = 'Shema podatkovne baze "%s" - Stran %s';
-$strPdfInvalidPageNum = 'Nedefinirna številka PDF strani!';
 $strPdfInvalidTblName = 'Tabela "%s" ne obstaja!';
 $strPdfNoTables = 'Ni tabel';
 $strPerHour = 'na uro';
@@ -442,7 +437,6 @@ $strPortrait = 'Pokončno';
 $strPos1 = 'Začetek';
 $strPrevious = 'Prejšnji';
 $strPrimary = 'Primarni';
-$strPrimaryKey = 'Primarni ključ';
 $strPrimaryKeyHasBeenDropped = 'Primarni ključ je zavržen';
 $strPrimaryKeyName = 'Ime primarnega ključa mora biti... PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime <b>samo</b> primarnega ključa!)';
@@ -481,15 +475,12 @@ $strPrivDescUsage = 'Brez privilegijev.';
 $strPrivileges = 'Privilegiji';
 $strPrivilegesReloaded = 'Uspešno sem osvežil privilegije.';
 $strProcesslist = 'Seznam procesov';
-$strProperties = 'Lastnosti';
 $strPutColNames = 'Postavi imena polj v prvo vrstico';
 
 $strQBE = 'Poizvedba';
 $strQBEDel = 'Briši';
 $strQBEIns = 'Vstavi';
 $strQueryFrame = 'Okno za iskanje';
-$strQueryFrameDebug = 'Informacije o iskanju hroščev';
-$strQueryFrameDebugBox = 'Aktivne spremenljivke za poizvedbo:\nPodat. zbirka: %s\nTabela: %s\nStrežnik: %s\n\nTrenutne spremenljivke za poizvedbo:\nPodat. zbirka: %s\nTabela: %s\nStrežnik: %s\n\nLokacija strani: %s\nLokacija okvirov: %s.';
 $strQueryOnDb = 'SQL-poizvedba na podatkovni bazi <b>%s</b>:';
 $strQuerySQLHistory = 'SQL-zgodovina';
 $strQueryStatistics = '<b>Statistika poizvedbe</b>: Od zagona je bilo strežniku poslanih %s poizvedb.';
@@ -505,11 +496,12 @@ $strRelationNotWorking = 'Dodatne funkcije za delo s povezanimi tabelami so bile
 $strRelationView = 'Pogled relacij';
 $strRelationalSchema = 'Relacijska shema';
 $strRelations = 'Relacije';
+$strRelationsForTable = 'RELACIJE ZA TABELO';
 $strReloadFailed = 'Ponovno nalaganje MySQL ni uspelo.';
 $strReloadMySQL = 'Ponovno naloži MySQL';
 $strReloadingThePrivileges = 'Osvežujem privilegije';
-$strRememberReload = 'Ne pozabite ponovno naložiti strežnika.';
 $strRemoveSelectedUsers = 'Izbriši izbrane uporabnike';
+$strRenameDatabaseOK = 'Baza podatkov %s je preimenovana v %s';
 $strRenameTable = 'Preimenuj tabelo v';
 $strRenameTableOK = 'Tabela %s je preimenovana v %s';
 $strRepairTable = 'Popravi tabelo';
@@ -521,10 +513,7 @@ $strResourceLimits = 'Omejitve virov';
 $strRevoke = 'Odvzemi';
 $strRevokeAndDelete = 'Odvzemi uporabnikom aktivne privilegije in jih potem izbriši.';
 $strRevokeAndDeleteDescr = 'Uporabniki bodo še vedno imeli USAGE privilegije, dokler ne osvežite privilegijev.';
-$strRevokeGrant = 'Odvzemi dovoljenje';
-$strRevokeGrantMessage = 'Odvzeli ste dovoljenje (Grant) za %s';
 $strRevokeMessage = 'Odvzeli ste privilegije za %s';
-$strRevokePriv = 'Odvzemi privilegije';
 $strRowLength = 'Dolžina vrstice';
 $strRowSize = ' Velikost vrstice ';
 $strRows = 'Vrstice';
@@ -540,6 +529,7 @@ $strRunning = 'teče na %s';
 $strRussian = 'Rusko';
 
 $strSQL = 'SQL';
+$strSQLExportType = 'Vrsta izvoza';
 $strSQLOptions = 'SQL možnosti';
 $strSQLParserBugMessage = 'Obstaja možnost, da ste v SQL razčlenjevalniku naleteli na hrošča. Temeljito preglejte poizvedbo in preverite, če so citati pravilni in če se ujemajo. Možno je tudi, da prenašate binarno datoteko, ki je izven področja besedila citata. Poizvedbo lahko preizkusite tudi na vmesniku ukazne vrstice MySQL. Če je strežnik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju težav. Če se bodo težave nadaljevale, ali če razčlenjevalniku ne uspe tam, kjer vmesniku ukazne vrstice uspe, potem zmanjšajte vnešeno SQL poizvedbo na tisto poizvedbo, ki povzroča težave in pošljite poročilo o napaki skupaj s podatki iz spodnjega odseka IZREZA.';
 $strSQLParserUserError = 'Izgleda, da je v SQL poizvedbi prišlo do napake. Če je strežnik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju težav.';
@@ -562,7 +552,6 @@ $strSearchOption4 = 'kot \'regular expression\'';
 $strSearchResultsFor = 'Rezultati iskanja "<i>%s</i>" %s:';
 $strSearchType = 'Najdi:';
 $strSecretRequired = 'Konfiguracijski datoteki morate sedaj določiti skrivno geslo (blowfish_secret).';
-$strSelect = 'Izberi';
 $strSelectADb = 'Prosimo, izberite podatkovno bazo';
 $strSelectAll = 'Izberi vse';
 $strSelectFields = 'Izberite polja (vsaj eno):';
@@ -570,7 +559,7 @@ $strSelectNumRows = 'in poizvedba';
 $strSelectTables = 'Izberi tabele';
 $strSend = 'Shrani kot datoteko';
 $strSent = 'Poslano';
-$strServer = 'Strežnik %s';
+$strServer = 'Strežnik';
 $strServerChoice = 'Izbira strežnika';
 $strServerStatus = 'Podatki o izvajanju';
 $strServerStatusUptime = 'MySQL strežnik deluje že %s. Zagnal se je %s.';
@@ -584,7 +573,6 @@ $strSetEnumVal = 'Če je polje vrste "enum" ali "set", navedite vrednosti v obli
 $strShow = 'Pokaži';
 $strShowAll = 'Pokaži vse';
 $strShowColor = 'Pokaži barvo';
-$strShowCols = 'Pokaži stolpce';
 $strShowDatadictAs = 'Oblika podatkovnega slovarja';
 $strShowFullQueries = 'Pokaži celotne poizvedbe';
 $strShowGrid = 'Pokaži mrežo';
@@ -607,8 +595,8 @@ $strStatement = 'Izjave';
 $strStatus = 'Stanje';
 $strStrucCSV = 'CSV podatki';
 $strStrucData = 'Struktura in podatki';
-$strStrucDrop = 'Dodaj \'drop table\' poizvedbo';
-$strStrucExcelCSV = 'CSV podatki za Ms Excel';
+$strStrucDrop = 'Dodaj DROP TABLE poizvedbo';
+$strStrucExcelCSV = 'CSV podatki za MS Excel';
 $strStrucOnly = 'Samo struktura';
 $strStructPropose = 'Predlagaj strukturo tabele';
 $strStructure = 'Struktura';
@@ -645,6 +633,7 @@ $strTotal = 'skupaj';
 $strTotalUC = 'Skupaj';
 $strTraditionalChinese = 'Tradicionalno kitajsko';
 $strTraffic = 'Promet';
+$strTransformation_application_octetstream__download = 'Prikaži povezavo za prenos binarnih podatkov polja. Prva možnost je ime binarne datoteke. Druga možnost je možno ime polja v vrstici tabele, ki vsebuje to ime datoteke. Če vnesete drugo možnost, mora biti prva možnost prazna';
 $strTransformation_image_jpeg__inline = 'Prikaže sličico, na katero lahko kliknete; možnosti: širina, višina v slikovnih pikah (obdrži prvotna razmerja)';
 $strTransformation_image_jpeg__link = 'Pokaže povezavo na grafiko (neposredni BLOB prenos, ipd.).';
 $strTransformation_image_png__inline = 'Pokaži sliko/jpeg: vključeno';
@@ -654,7 +643,6 @@ $strTransformation_text_plain__formatted = 'Ohrani izvirno oblikovanje polja, br
 $strTransformation_text_plain__imagelink = 'Prikaže sliko in povezavo, polje vsebuje ime datoteke; najprej je predpona, npr. "http://domena.com/", druga možnost je širina v slikovnih pikah, tretja pa višina.';
 $strTransformation_text_plain__link = 'Prikaže povezavo, polje vsebuje ime datoteke; prva možnost je predpona, npr. "http://domena.com/", druga pa ime povezave.';
 $strTransformation_text_plain__substr = 'Vrne le del niza. Prva možnost je odmik, ki določa, kje se bo začelo prikazano besedilo (Privzeto: 0). Druga možnost je odmik, ki pove, koliko besedila bo prikazanega. Če ni določen, bo izpisano vse preostalo besedilo. Tretja možnost pa določa, kateri znaki bodo pripeti vrnjenemu podnizu (Privzeto: ...) .';
-$strTransformation_text_plain__unformatted = 'Pokaže HTML-kodo namesto HTML elementov. HTML oblikovanje ne bo prikazano.';
 $strTruncateQueries = 'Skrči prikazane poizvedbe';
 $strTurkish = 'Turško';
 $strType = 'Vrsta';
@@ -667,7 +655,6 @@ $strUnknown = 'neznano';
 $strUnselectAll = 'Prekliči izbor vsega';
 $strUpdComTab = 'Navodila za posodobitev tabele Column_comments\' najdete v dokumentaciji';
 $strUpdatePrivMessage = 'Posodobili ste privilegije za %s.';
-$strUpdateProfile = 'Posodobi profil:';
 $strUpdateProfileMessage = 'Profil je posodobljen.';
 $strUpdateQuery = 'Osveži poizvedbo';
 $strUpgrade = '%s bi morali nadgraditi v verzijo %s ali novejšo.';
@@ -683,7 +670,6 @@ $strUserEmpty = 'Uporabniško ime je prazno!';
 $strUserName = 'Uporabniško ime';
 $strUserNotFound = 'Izbranega uporabnika v tabelah privilegijev nisem našel.';
 $strUserOverview = 'Pregled uporabnikov';
-$strUsers = 'Uporabniki';
 $strUsersDeleted = 'Uspešno sem izbrisal izbrane uporabnike.';
 $strUsersHavingAccessToDb = 'Uporabniški dostop do &quot;%s&quot;';
 
@@ -712,17 +698,104 @@ $strYes = 'Da';
 
 $strZeroRemovesTheLimit = 'Obvestilo: Če postavite vrednost na 0 (nič), boste odstranili omejitev.';
 $strZip = '"zipano"';
-// To translate
 
-$strCreationDates = 'Creation/Update/Check dates';  //to translate
-$strCheckOverhead = 'Check overheaded';  //to translate
-$strExcelEdition = 'Excel edition';  //to translate
-$strDelayedInserts = 'Use delayed inserts';  //to translate
-$strSQLExportType = 'Export type';  //to translate
-$strAddConstraints = 'Add constraints';  //to translate
-$strGeorgian = 'Georgian';  //to translate
-$strCzechSlovak = 'Czech-Slovak';  //to translate
-$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
-$strMaximumSize = 'Maximum size: %s%s';  //to translate
+$strRefresh = 'Refresh';  //to translate
+$strDefragment = 'Defragment table';  //to translate
+$strNoRowsSelected = 'No rows selected';  //to translate
 $strSpanish = 'Spanish';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
+$strServerNotResponding = 'The server is not responding';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
+$strIcelandic = 'Icelandic';  //to translate
+$strLatvian = 'Latvian';  //to translate
+$strPolish = 'Polish';  //to translate
+$strRomanian = 'Romanian';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
