@@ -1,5 +1,5 @@
 <?php
-/* $Id: ukrainian-windows-1251.inc.php,v 2.6.2.1 2004/06/07 10:09:56 rabus Exp $ */
+/* $Id: ukrainian-windows-1251.inc.php,v 2.65 2005/03/30 19:25:46 lem9 Exp $ */
 
 $charset = 'windows-1251';
 $text_dir = 'ltr';
@@ -30,8 +30,6 @@ $strAddDeleteRow = '/  ';
 $strAddDropDatabase = ' DROP DATABASE';
 $strAddIntoComments = ' ';
 $strAddNewField = '  ';
-$strAddPriv = '  ';
-$strAddPrivMessage = '   ';
 $strAddPrivilegesOnDb = '     ';
 $strAddPrivilegesOnTbl = '    ';
 $strAddSearchConditions = '   (   "where"):';
@@ -52,10 +50,7 @@ $strAnIndex = '    %s';
 $strAnalyzeTable = ' ';
 $strAnd = '';
 $strAny = '';
-$strAnyColumn = ' ';
-$strAnyDatabase = '  ';
 $strAnyHost = ' ';
-$strAnyTable = ' ';
 $strAnyUser = ' ';
 $strArabic = '';
 $strArmenian = '³';
@@ -85,7 +80,6 @@ $strBzip = '  "bzip"';
 $strCSVOptions = 'CSV ';
 $strCannotLogin = '    MySQL ';
 $strCantLoad = '   %s,<br />   PHP.';
-$strCantLoadMySQL = ' MySQL  ,<br />  PHP.';
 $strCantLoadRecodeIconv = '   iconv  recode extension    charset-,  php ,      extensions,    charset-  phpMyAdmin.';
 $strCantRenameIdxToPrimary = '    PRIMARY!';
 $strCantUseRecodeIconv = '    / iconv, / libiconv, /  recode_string    extension reports.   php .';
@@ -108,14 +102,12 @@ $strCharsetOfFile = ' :';
 $strCharsets = '';
 $strCharsetsAndCollations = '   ';
 $strCheckAll = '³ ';
-$strCheckDbPriv = '   ';
 $strCheckPrivs = ' ';
 $strCheckPrivsLong = '     &quot;%s&quot;.';
 $strCheckTable = ' ';
 $strChoosePage = '    ';
 $strColComFeat = '  ';
 $strCollation = '';
-$strColumn = '';
 $strColumnNames = ' ';
 $strColumnPrivileges = ',    ';
 $strCommand = '';
@@ -124,7 +116,6 @@ $strCompleteInserts = ' ';
 $strCompression = '';
 $strConfigFileError = 'phpMyAdmin      <br />     ,  php     (parse error)  ,      .<br />               (php error messages).         .  <br />    , -    .';
 $strConfigureTableCoord = '    %s';
-$strConfirm = '    ?';
 $strConnections = '\'';
 $strCookiesRequired = '   Cookies   .';
 $strCopyTable = '   ( <b>.</b>):';
@@ -157,11 +148,10 @@ $strDanish = '';
 $strData = '';
 $strDataDict = ' ';
 $strDataOnly = ' ';
-$strDatabase = ' ';
+$strDatabase = '';
 $strDatabaseExportOptions = '   ';
 $strDatabaseHasBeenDropped = '  %s .';
 $strDatabaseNoTable = '     !';
-$strDatabaseWildcard = '  (  ):';
 $strDatabases = ' ';
 $strDatabasesDropped = '%s (\)   .';
 $strDatabasesStats = '  ';
@@ -176,8 +166,6 @@ $strDelOld = '     ,   .    ?';
 $strDelete = '';
 $strDeleteAndFlush = '      .';
 $strDeleteAndFlushDescr = '  ,       .';
-$strDeleteFailed = '  !';
-$strDeleteUserMessage = '  %s.';
 $strDeleted = ' ';
 $strDeletedRows = '  :';
 $strDeleting = ' %s';
@@ -185,7 +173,6 @@ $strDescending = '';
 $strDescription = '';
 $strDictionary = '';
 $strDisabled = '';
-$strDisplay = '';
 $strDisplayFeat = ' ';
 $strDisplayOrder = ' :';
 $strDisplayPDF = ' PDF ';
@@ -193,11 +180,8 @@ $strDoAQuery = ' "  " ( : "%")';
 $strDoYouReally = '   ';
 $strDocu = '';
 $strDrop = '';
-$strDropDB = '  %s';
 $strDropSelectedDatabases = '   ';
-$strDropTable = ' ';
 $strDropUsersDb = '  ,        .';
-$strDumpComments = '     SQL-';
 $strDumpSaved = 'Dump    %s.';
 $strDumpXRows = 'Ǵ  %s    %s -.';
 $strDumpingData = '  ';
@@ -221,7 +205,6 @@ $strExcelOptions = ' Excel';
 $strExecuteBookmarked = '  ';
 $strExplain = ' SQL';
 $strExport = '';
-$strExportToXML = '  XML ';
 $strExtendedInserts = ' ';
 $strExtra = '';
 
@@ -255,7 +238,6 @@ $strGlobalPrivileges = ' ';
 $strGlobalValue = ' ';
 $strGo = '';
 $strGrantOption = 'Grant';
-$strGrants = '';
 $strGreek = '';
 $strGzip = '  "gzip"';
 
@@ -265,7 +247,6 @@ $strHaveToShow = '      ';
 $strHebrew = '';
 $strHome = ' ';
 $strHomepageOfficial = '  phpMyAdmin';
-$strHomepageSourceforge = ' phpMyAdmin  Sourceforge';
 $strHost = '';
 $strHostEmpty = ' \' !';
 $strHungarian = '';
@@ -293,7 +274,6 @@ $strInsertTextfiles = '    ';
 $strInsertedRowId = '  id:';
 $strInsertedRows = ' :';
 $strInstructions = '';
-$strInvalidName = '"%s" -  ,         //.';
 
 $strJapanese = '';
 $strJumpToDB = '    &quot;%s&quot;.';
@@ -308,11 +288,9 @@ $strKorean = '';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = ' LaTeX';
 $strLandscape = 'Landscape';
-$strLength = '';
 $strLengthSet = '/*';
 $strLimitNumRows = '  ';
 $strLineFeed = '  : \\n';
-$strLines = '';
 $strLinesTerminatedBy = ' ';
 $strLinkNotFound = '˳  ';
 $strLinksTo = '˳ ';
@@ -331,14 +309,12 @@ $strMIME_MIMEtype = 'MIME-type';
 $strMIME_available_mime = ' MIME-types';
 $strMIME_available_transform = ' ';
 $strMIME_description = '';
-$strMIME_file = ' ';
 $strMIME_nodescription = '    .<br />  ,   %s.';
 $strMIME_transformation = ' ̲- ';
 $strMIME_transformation_note = '       MIME-type ,  %s %s';
 $strMIME_transformation_options = ' ';
 $strMIME_transformation_options_note = '       : \'a\',\'b\',\'c\'...<br />     ("\")    ("\'")   ,       ( \'\\\\xyz\'  \'a\\\'b\').';
 $strMIME_without = 'MIME-types       ';
-$strMissingBracket = ' ';
 $strModifications = '  ';
 $strModify = '';
 $strModifyIndexTopic = ' ';
@@ -378,7 +354,6 @@ $strNoRights = '     !';
 $strNoSpace = '     %s.';
 $strNoTablesFound = '    .';
 $strNoUsersFound = '  .';
-$strNoUsersSelected = '  .';
 $strNoValidateSQL = '  SQL';
 $strNone = '';
 $strNotNumber = '  !';
@@ -396,7 +371,6 @@ $strOperations = '';
 $strOptimizeTable = ' ';
 $strOptionalControls = ' .      .';
 $strOptionally = ' ';
-$strOptions = '';
 $strOr = '';
 $strOverhead = ' ';
 $strOverwriteExisting = '  ';
@@ -411,7 +385,6 @@ $strPasswordChanged = '  %s  .';
 $strPasswordEmpty = ' !';
 $strPasswordNotSame = '  !';
 $strPdfDbSchema = '   "%s" -  %s';
-$strPdfInvalidPageNum = '   PDF !';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
 $strPerHour = ' ';
@@ -425,7 +398,6 @@ $strPortrait = 'Portrait';
 $strPos1 = '';
 $strPrevious = '';
 $strPrimary = '';
-$strPrimaryKey = ' ';
 $strPrimaryKeyHasBeenDropped = '   ';
 $strPrimaryKeyName = '\'     PRIMARY!';
 $strPrimaryKeyWarning = '("PRIMARY" <b></b>   <b></b>  !)';
@@ -463,15 +435,12 @@ $strPrivDescUsage = ' .';
 $strPrivileges = '';
 $strPrivilegesReloaded = '  .';
 $strProcesslist = ' ';
-$strProperties = '';
 $strPutColNames = '     ';
 
 $strQBE = '  ';
 $strQBEDel = '';
 $strQBEIns = '';
 $strQueryFrame = '³ ';
-$strQueryFrameDebug = '  ';
-$strQueryFrameDebugBox = '  :\nDB: %s\nTable: %s\nServer: %s\n\n  :\nDB: %s\nTable: %s\nServer: %s\n\nOpener location: %s\nFrameset location: %s.';
 $strQueryOnDb = 'SQL-   <b>%s</b>:';
 $strQuerySQLHistory = 'SQL-history';
 $strQueryStatistics = '<b> </b>:   ,     %s .';
@@ -490,7 +459,6 @@ $strRelations = '\'';
 $strReloadFailed = '   MySQL.';
 $strReloadMySQL = ' MySQL';
 $strReloadingThePrivileges = ' ';
-$strRememberReload = '   .';
 $strRemoveSelectedUsers = '  ';
 $strRenameTable = '  ';
 $strRenameTableOK = ' %s    %s';
@@ -503,10 +471,7 @@ $strResourceLimits = ' ';
 $strRevoke = '³';
 $strRevokeAndDelete = '³         .';
 $strRevokeAndDeleteDescr = '       (USAGE)   ,     .';
-$strRevokeGrant = '³  ';
-$strRevokeGrantMessage = '     %s';
 $strRevokeMessage = '    %s';
-$strRevokePriv = '³ ';
 $strRowLength = ' ';
 $strRowSize = '   ';
 $strRows = '';
@@ -544,7 +509,6 @@ $strSearchOption4 = ' ';
 $strSearchResultsFor = '  "<i>%s</i>" %s:';
 $strSearchType = ':';
 $strSecretRequired = '     ().';
-$strSelect = '';
 $strSelectADb = '  ';
 $strSelectAll = '³ ';
 $strSelectFields = '  ( ):';
@@ -552,7 +516,7 @@ $strSelectNumRows = ' ';
 $strSelectTables = ' ';
 $strSend = '³';
 $strSent = '³';
-$strServer = ' %s';
+$strServer = '';
 $strServerChoice = ' ';
 $strServerStatus = '   ';
 $strServerStatusUptime = ' MySQL   %s.  %s.';
@@ -566,7 +530,6 @@ $strSetEnumVal = '   "enum"  "set",     : \'a\',\'b\',\'c\'...<br />        ("\"
 $strShow = '';
 $strShowAll = ' ';
 $strShowColor = ' ';
-$strShowCols = ' ';
 $strShowDatadictAs = ' ';
 $strShowFullQueries = '  ';
 $strShowGrid = ' ';
@@ -635,7 +598,6 @@ $strTransformation_text_plain__formatted = '   .   .';
 $strTransformation_text_plain__imagelink = '   ,    ;   - ,   "http://domain.com/",  -   ,  - .';
 $strTransformation_text_plain__link = ' ,    ;   - ,   "http://domain.com/",   - title  .';
 $strTransformation_text_plain__substr = '   .   -            ( : 0).   -     .    -    .   -          ( : ...) .';
-$strTransformation_text_plain__unformatted = '³ HTML   HTML entities. HTML   .';
 $strTruncateQueries = '  ';
 $strTurkish = '';
 $strType = '';
@@ -648,7 +610,6 @@ $strUnknown = '';
 $strUnselectAll = '  ';
 $strUpdComTab = '      Column_comments    ';
 $strUpdatePrivMessage = '   ';
-$strUpdateProfile = ' :';
 $strUpdateProfileMessage = '  .';
 $strUpdateQuery = ' ';
 $strUsage = '';
@@ -662,7 +623,6 @@ $strUserEmpty = ' \' !';
 $strUserName = '\' ';
 $strUserNotFound = '      .';
 $strUserOverview = ' ';
-$strUsers = '';
 $strUsersDeleted = '³   .';
 $strUsersHavingAccessToDb = ',     &quot;%s&quot;';
 
@@ -716,7 +676,7 @@ $strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
 $strConstraintsForTable = 'Constraints for table';  //to translate
 $strBookmarkOptions = 'Bookmark options';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
-$strCheckOverhead = 'Check overheaded';  //to translate
+$strCheckOverhead = 'Check tables with overhead';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
 $strDelayedInserts = 'Use delayed inserts';  //to translate
 $strSQLExportType = 'Export type';  //to translate
@@ -725,5 +685,119 @@ $strGeorgian = 'Georgian';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
 $strMaximumSize = 'Maximum size: %s%s';  //to translate
+$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
+$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
+$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
+$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
+$strIgnoreInserts = 'Use ignore inserts';  //to translate
+$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
+$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
+$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
+$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
+$strAfterInsertSame = 'Go back to this page';  //to translate
+$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
+$strDatabaseEmpty = 'The database name is empty!';  //to translate
+$strDBRename = 'Rename database to';  //to translate
+$strOperator = 'Operator';  //to translate
+$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
+$strCalendar = 'Calendar';  //to translate
+$strRefresh = 'Refresh';  //to translate
+$strDefragment = 'Defragment table';  //to translate
+$strNoRowsSelected = 'No rows selected';  //to translate
 $strSpanish = 'Spanish';  //to translate
+$strStrucNativeExcel = 'Native MS Excel data';  //to translate
+$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
+$strServerNotResponding = 'The server is not responding';  //to translate
+$strTheme = 'Theme / Style';  //to translate
+$strTakeIt = 'take it';  //to translate
+$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
+$strIcelandic = 'Icelandic';  //to translate
+$strLatvian = 'Latvian';  //to translate
+$strPolish = 'Polish';  //to translate
+$strRomanian = 'Romanian';  //to translate
+$strSlovenian = 'Slovenian';  //to translate
+$strTraditionalSpanish = 'Traditional Spanish';  //to translate
+$strSlovak = 'Slovak';  //to translate
+$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
+$strPersian = 'Persian';  //to translate
+$strAddFields = 'Add %s field(s)';  //to translate
+$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
+$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
+$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
+$strBinLogName = 'Log name';  //to translate
+$strBinLogPosition = 'Position';  //to translate
+$strBinLogEventType = 'Event type';  //to translate
+$strBinLogServerId = 'Server ID';  //to translate
+$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBinLogInfo = 'Information';  //to translate
+$strBinaryLog = 'Binary log';  //to translate
+$strSelectBinaryLog = 'Select binary log to view';  //to translate
+$strDBCopy = 'Copy database to';  //to translate
+$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
+$strSwitchToDatabase = 'Switch to copied database';  //to translate
+$strPasswordHashing = 'Password Hashing';  //to translate
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
+$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
+$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
+$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
+$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
+$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
+$strAfterInsertNext = 'Edit next row';  //to translate
+$strView = 'View';  //to translate
+$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
+$strEngines = 'Engines';  //to translate
+$strStorageEngines = 'Storage Engines';  //to translate
+$strStorageEngine = 'Storage Engine';  //to translate
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
+$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
+$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
+$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
+$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
+$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
+$strMyISAMRepairThreads = 'Repair threads';  //to translate
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
+$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
+$strVersionInformation = 'Version information';  //to translate
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
