@@ -1,8 +1,7 @@
 <?php
-/* $Id: pdf_schema.php,v 2.2 2003/11/26 22:52:24 rabus Exp $ */
+/* $Id: pdf_schema.php,v 2.13 2005/03/05 23:19:59 lem9 Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
-
 /**
  * Contributed by Maxime Delorme and merged by lem9
  */
@@ -40,10 +39,20 @@ if (!$cfgRelation['pdfwork']) {
 
 
 /**
- * Gets the "fpdf" libraries and defines the pdf font path
+ * Gets the "fpdf" libraries and defines the pdf font path, use unicode version for unicode.
  */
-require_once('./libraries/fpdf/fpdf.php');
-$FPDF_font_path = './libraries/fpdf/font/';
+define('FPDF_FONTPATH','./libraries/fpdf/font/');
+if ($charset == 'utf-8') {
+    define('PMA_PDF_FONT', 'FreeSans');
+    require_once('./libraries/fpdf/ufpdf.php');
+    class PMA_FPDF extends UFPDF {
+    };
+} else {
+    define('PMA_PDF_FONT', 'Arial');
+    require_once('./libraries/fpdf/fpdf.php');
+    class PMA_FPDF extends FPDF {
+    };
+}
 
 
 /**
@@ -53,7 +62,7 @@ $FPDF_font_path = './libraries/fpdf/font/';
  *
  * @see     FPDF
  */
-class PMA_PDF extends FPDF
+class PMA_PDF extends PMA_FPDF
 {
     /**
      * Defines private properties
@@ -96,12 +105,12 @@ class PMA_PDF extends FPDF
     }
     function _putpages()
     {
-        if(count($this->Alias) > 0)
+        if (count($this->Alias) > 0)
         {
             $nb=$this->page;
-            foreach($this->Alias AS $alias => $value) {
-                for($n=1;$n<=$nb;$n++)
-                $this->pages[$n]=str_replace($alias,$value,$this->pages[$n]);
+            foreach ($this->Alias AS $alias => $value) {
+                for ($n=1;$n<=$nb;$n++)
+                $this->pages[$n]=$this->_strreplace($alias,$value,$this->pages[$n]);
             }
         }
         parent::_putpages();
@@ -282,7 +291,7 @@ class PMA_PDF extends FPDF
         echo "\n";
 
         require_once('./footer.inc.php');
-    } // end of the "PMA_PDF_die()" function
+    } // end of the "PMA_PDF_die()" function 
 
 
     /**
@@ -312,7 +321,7 @@ class PMA_PDF extends FPDF
                     . ' WHERE db_name = \'' . PMA_sqlAddslashes($db) . '\''
                     . ' AND page_nr = \'' . $pdf_page_number . '\'';
         $test_rs    = PMA_query_as_cu($test_query);
-        $pages = @PMA_mysql_fetch_array($test_rs);
+        $pages = @PMA_DBI_fetch_assoc($test_rs);
         $this->SetFont('', 'B', 14);
         $this->Cell(0,6, ucfirst($pages['page_descr']),'B',1,'C');
         $this->SetFont('', '');
@@ -336,14 +345,14 @@ class PMA_PDF extends FPDF
    $this->Outlines[0][]=$level;
    $this->Outlines[1][]=$txt;
    $this->Outlines[2][]=$this->page;
-   if($y==-1)
+   if ($y==-1)
       $y=$this->GetY();
    $this->Outlines[3][]=round($this->hPt-$y*$this->k,2);
 }
 
 function _putbookmarks()
 {
-   if(count($this->Outlines)>0)
+   if (count($this->Outlines)>0)
    {
       //Save object number
       $memo_n = $this->n;
@@ -352,29 +361,29 @@ function _putbookmarks()
       $first_level=array();
       $parent=array();
       $parent[0]=1;
-      for( $i=0; $i<$nb_outlines; $i++)
+      for ($i=0; $i<$nb_outlines; $i++)
       {
          $level=$this->Outlines[0][$i];
          $kids=0;
          $last=-1;
          $prev=-1;
          $next=-1;
-         if( $i>0 )
+         if ($i>0 )
          {
             $cursor=$i-1;
             //Take the previous outline in the same level
-            while( $this->Outlines[0][$cursor] > $level && $cursor > 0)
+            while ($this->Outlines[0][$cursor] > $level && $cursor > 0)
                $cursor--;
-            if( $this->Outlines[0][$cursor] == $level)
+            if ($this->Outlines[0][$cursor] == $level)
                $prev=$cursor;
          }
-         if( $i<$nb_outlines-1)
+         if ($i<$nb_outlines-1)
          {
             $cursor=$i+1;
-            while( isset($this->Outlines[0][$cursor]) && $this->Outlines[0][$cursor] > $level)
+            while (isset($this->Outlines[0][$cursor]) && $this->Outlines[0][$cursor] > $level)
             {
                //Take the immediate kid in level + 1
-               if( $this->Outlines[0][$cursor] == $level+1)
+               if ($this->Outlines[0][$cursor] == $level+1)
                {
                   $kids++;
                   $last=$cursor;
@@ -383,24 +392,24 @@ function _putbookmarks()
             }
             $cursor=$i+1;
             //Take the next outline in the same level
-            while( $this->Outlines[0][$cursor] > $level && ($cursor+1 < sizeof($this->Outlines[0])))
+            while ($this->Outlines[0][$cursor] > $level && ($cursor+1 < sizeof($this->Outlines[0])))
                $cursor++;
-            if( $this->Outlines[0][$cursor] == $level)
+            if ($this->Outlines[0][$cursor] == $level)
                $next=$cursor;
          }
          $this->_newobj();
          $parent[$level+1]=$this->n;
-         if( $level == 0)
+         if ($level == 0)
             $first_level[]=$this->n;
          $this->_out('<<');
          $this->_out('/Title ('.$this->Outlines[1][$i].')');
          $this->_out('/Parent '.$parent[$level].' 0 R');
-         if( $prev != -1)
+         if ($prev != -1)
             $this->_out('/Prev '.($memo_n+$prev+1).' 0 R');
-         if( $next != -1)
+         if ($next != -1)
             $this->_out('/Next '.($this->n+$next-$i).' 0 R');
          $this->_out('/Dest ['.(1+(2*$this->Outlines[2][$i])).' 0 R /XYZ null '.$this->Outlines[3][$i].' null]');
-         if( $kids > 0)
+         if ($kids > 0)
          {
             $this->_out('/First '.($this->n+1).' 0 R');
             $this->_out('/Last '.($this->n+$last-$i).' 0 R');
@@ -432,7 +441,7 @@ function _putresources()
 function _putcatalog()
 {
    parent::_putcatalog();
-   if(count($this->Outlines)>0)
+   if (count($this->Outlines)>0)
    {
       $this->_out('/Outlines '.$this->def_outlines.' 0 R');
       $this->_out('/PageMode /UseOutlines');
@@ -449,7 +458,7 @@ function Row($data,$links)
    // line height
    $nb=0;
    $data_cnt = count($data);
-   for($i=0;$i<$data_cnt;$i++)
+   for ($i=0;$i<$data_cnt;$i++)
       $nb=max($nb,$this->NbLines($this->widths[$i],$data[$i]));
    $il = $this->FontSize;
    $h=($il+1)*$nb;
@@ -457,7 +466,7 @@ function Row($data,$links)
    $this->CheckPageBreak($h);
    // draw the cells
    $data_cnt = count($data);
-   for($i=0;$i<$data_cnt;$i++)
+   for ($i=0;$i<$data_cnt;$i++)
    {
       $w=$this->widths[$i];
       // save current position
@@ -479,7 +488,7 @@ function Row($data,$links)
 function CheckPageBreak($h)
 {
    // if height h overflows, manual page break
-   if($this->GetY()+$h>$this->PageBreakTrigger)
+   if ($this->GetY()+$h>$this->PageBreakTrigger)
       $this->AddPage($this->CurOrientation);
 }
 
@@ -487,22 +496,22 @@ function NbLines($w,$txt)
 {
    // compute number of lines used by a multicell of width w
    $cw=&$this->CurrentFont['cw'];
-   if($w==0)
+   if ($w==0)
       $w=$this->w-$this->rMargin-$this->x;
    $wmax=($w-2*$this->cMargin)*1000/$this->FontSize;
    $s=str_replace("\r",'',$txt);
    $nb=strlen($s);
-   if($nb>0 and $s[$nb-1]=="\n")
+   if ($nb>0 and $s[$nb-1]=="\n")
       $nb--;
    $sep=-1;
    $i=0;
    $j=0;
    $l=0;
    $nl=1;
-   while($i<$nb)
+   while ($i<$nb)
    {
       $c=$s[$i];
-      if($c=="\n")
+      if ($c=="\n")
       {
          $i++;
          $sep=-1;
@@ -511,14 +520,14 @@ function NbLines($w,$txt)
          $nl++;
          continue;
       }
-      if($c==' ')
+      if ($c==' ')
          $sep=$i;
-      $l+=$cw[$c];
-      if($l>$wmax)
+      $l+=isset($cw[ord($c)])?$cw[ord($c)]:0 ;
+      if ($l>$wmax)
       {
-         if($sep==-1)
+         if ($sep==-1)
          {
-            if($i==$j)
+            if ($i==$j)
                $i++;
          }
          else
@@ -576,7 +585,7 @@ class PMA_RT_Table
         //  there are fields that require wider cells than the name of the table?
         global $pdf;
 
-        foreach($this->fields AS $field) {
+        foreach ($this->fields AS $field) {
             $this->width = max($this->width, $pdf->GetStringWidth($field));
         }
         $this->width += $pdf->GetStringWidth('  ');
@@ -633,7 +642,7 @@ class PMA_RT_Table
         $pdf->SetTextColor(0);
         $pdf->SetFillColor(255);
 
-        foreach($this->fields AS $field) {
+        foreach ($this->fields AS $field) {
             // loic1 : PHP3 fix
             // if (in_array($field, $this->primary)) {
             if ($setcolor) {
@@ -683,12 +692,12 @@ class PMA_RT_Table
 
         $this->table_name = $table_name;
         $sql              = 'DESCRIBE ' .  PMA_backquote($table_name);
-        $result           = PMA_mysql_query($sql);
-        if (!$result || !mysql_num_rows($result)) {
+        $result           = PMA_DBI_try_query($sql, NULL, PMA_DBI_QUERY_STORE);
+        if (!$result || !PMA_DBI_num_rows($result)) {
             $pdf->PMA_PDF_die(sprintf($GLOBALS['strPdfInvalidTblName'], $table_name));
         }
         // load fields
-        while ($row = PMA_mysql_fetch_array($result)) {
+        while ($row = PMA_DBI_fetch_row($result)) {
             $this->fields[] = $row[0];
         }
 
@@ -705,22 +714,21 @@ class PMA_RT_Table
                 .   ' WHERE db_name = \'' . PMA_sqlAddslashes($db) . '\''
                 .   ' AND   table_name = \'' . PMA_sqlAddslashes($table_name) . '\''
                 .   ' AND   pdf_page_number = ' . $pdf_page_number;
-        $result = PMA_query_as_cu($sql);
+        $result = PMA_query_as_cu($sql, FALSE, PMA_DBI_QUERY_STORE);
 
-        if (!$result || !mysql_num_rows($result)) {
+        if (!$result || !PMA_DBI_num_rows($result)) {
             $pdf->PMA_PDF_die(sprintf($GLOBALS['strConfigureTableCoord'], $table_name));
         }
-        list($this->x, $this->y) = PMA_mysql_fetch_array($result);
+        list($this->x, $this->y) = PMA_DBI_fetch_row($result);
         $this->x = (double) $this->x;
         $this->y = (double) $this->y;
         // displayfield
         $this->displayfield = PMA_getDisplayField($db, $table_name);
 
         // index
-        $sql    = 'SHOW index FROM ' . PMA_backquote($table_name);
-        $result = PMA_mysql_query($sql);
-        if ($result && mysql_num_rows($result) > 0) {
-            while ($row = PMA_mysql_fetch_array($result)) {
+        $result = PMA_DBI_query('SHOW INDEX FROM ' . PMA_backquote($table_name) . ';', NULL, PMA_DBI_QUERY_STORE);
+        if (PMA_DBI_num_rows($result) > 0) {
+            while ($row = PMA_DBI_fetch_assoc($result)) {
                 if ($row['Key_name'] == 'PRIMARY') {
                     $this->primary[] = $row['Column_name'];
                 }
@@ -891,7 +899,7 @@ class PMA_RT
      */
     var $tables    = array();
     var $relations = array();
-    var $ff        = 'Arial';
+    var $ff        = PMA_PDF_FONT;
     var $x_max     = 0;
     var $y_max     = 0;
     var $scale;
@@ -995,7 +1003,7 @@ class PMA_RT
     function PMA_RT_drawRelations($change_color)
     {
         $i = 0;
-        foreach($this->relations AS $relation) {
+        foreach ($this->relations AS $relation) {
             $relation->PMA_RT_Relation_draw($change_color, $i);
             $i++;
         } // end while
@@ -1013,7 +1021,7 @@ class PMA_RT
      */
     function PMA_RT_drawTables($show_info,$draw_color=0)
     {
-        foreach($this->tables AS $table) {
+        foreach ($this->tables AS $table) {
             $table->PMA_RT_Table_draw($show_info, $this->ff,$draw_color);
         }
     } // end of the "PMA_RT_drawTables()" method
@@ -1043,15 +1051,15 @@ class PMA_RT
                   .   ' WHERE page_nr = ' . $pdf_page_number;
         $_name_rs   = PMA_query_as_cu($_name_sql);
         if ($_name_rs) {
-            $_name_row = PMA_mysql_fetch_row($_name_rs);
+            $_name_row = PMA_DBI_fetch_row($_name_rs);
             $filename = $_name_row[0] . '.pdf';
         }
         // i don't know if there is a chance for this to happen, but rather be on the safe side:
         if (empty($filename)) {
             $filename = $pdf_page_number . '.pdf';
         }
-        $pdf->Output($db . '_' . $filename, TRUE);
-        //$pdf->Output('', TRUE);
+        //$pdf->Output($db . '_' . $filename, TRUE);
+        $pdf->Output($db . '_' . $filename, 'I'); // destination: Inline
     } // end of the "PMA_RT_showRt()" method
 
 
@@ -1082,6 +1090,7 @@ class PMA_RT
 
         // Font face depends on the current language
         $this->ff        = str_replace('"', '', substr($GLOBALS['right_font_family'], 0, strpos($GLOBALS['right_font_family'], ',')));
+
         $this->same_wide = $all_tab_same_wide;
 
         // Initializes a new document
@@ -1093,13 +1102,20 @@ class PMA_RT
         $pdf->SetAuthor('phpMyAdmin ' . PMA_VERSION);
         $pdf->AliasNbPages();
 
-         // fonts added to phpMyAdmin and considered non-standard by fpdf
-         // (Note: those tahoma fonts are iso-8859-2 based)
-         if ($this->ff == 'tahoma') {
-             $pdf->AddFont('tahoma','','tahoma.php');
-             $pdf->AddFont('tahoma','B','tahomab.php');
-         }
-
+        if ($GLOBALS['charset'] == 'utf-8') {
+            // Force FreeSans for utf-8
+            $this->ff = 'FreeSans';
+            $pdf->AddFont('FreeSans','','FreeSans.php');
+            $pdf->AddFont('FreeSans','B','FreeSansBold.php');
+            $pdf->SetFont('FreeSans', '', 14);
+        } else { 
+            // fonts added to phpMyAdmin and considered non-standard by fpdf
+            // (Note: those tahoma fonts are iso-8859-2 based)
+            if ($this->ff == 'tahoma') {
+                $pdf->AddFont('tahoma','','tahoma.php');
+                $pdf->AddFont('tahoma','B','tahomab.php');
+            }
+        }
         $pdf->SetFont($this->ff, '', 14);
         $pdf->SetAutoPageBreak('auto');
 
@@ -1107,12 +1123,12 @@ class PMA_RT
         $tab_sql  = 'SELECT table_name FROM ' . PMA_backquote($cfgRelation['table_coords'])
                   .   ' WHERE db_name = \'' . PMA_sqlAddslashes($db) . '\''
                   .   ' AND pdf_page_number = ' . $which_rel;
-        $tab_rs   = PMA_query_as_cu($tab_sql);
-        if (!$tab_rs || !mysql_num_rows($tab_rs) > 0) {
+        $tab_rs   = PMA_query_as_cu($tab_sql, NULL, PMA_DBI_QUERY_STORE);
+        if (!$tab_rs || !PMA_DBI_num_rows($tab_rs) > 0) {
             $pdf->PMA_PDF_die($GLOBALS['strPdfNoTables']);
 //            die('No tables');
         }
-        while ($curr_table = @PMA_mysql_fetch_array($tab_rs)) {
+        while ($curr_table = @PMA_DBI_fetch_assoc($tab_rs)) {
             $alltables[] = PMA_sqlAddslashes($curr_table['table_name']);
             //$intable     = '\'' . implode('\', \'', $alltables) . '\'';
         }
@@ -1139,12 +1155,12 @@ class PMA_RT
 
                                 /* snip */
 
-        foreach($alltables AS $table) {
+        foreach ($alltables AS $table) {
             if (!isset($this->tables[$table])) {
                 $this->tables[$table] = new PMA_RT_Table($table, $this->ff, $this->tablewidth);
             }
 
-            if($this->same_wide){
+            if ($this->same_wide){
                 $this->tables[$table]->width = $this->tablewidth;
             }
             $this->PMA_RT_setMinMax($this->tables[$table]);
@@ -1177,12 +1193,12 @@ class PMA_RT
 // and finding its foreigns is OK (then we can support innodb)
 
         $seen_a_relation = FALSE;
-        foreach($alltables AS $one_table) {
+        foreach ($alltables AS $one_table) {
 
             $exist_rel = PMA_getForeigners($db, $one_table, '', 'both');
             if ($exist_rel) {
                 $seen_a_relation = TRUE;
-                foreach($exist_rel AS $master_field => $rel) {
+                foreach ($exist_rel AS $master_field => $rel) {
                     // put the foreign table on the schema only if selected
                     // by the user
                     // (do not use array_search() because we would have to
@@ -1198,9 +1214,9 @@ class PMA_RT
 
         // loic1: also show tables without relations
 //        $norelations     = TRUE;
-//        if ($result && mysql_num_rows($result) > 0) {
+//        if ($result && PMA_DBI_num_rows($result) > 0) {
 //            $norelations = FALSE;
-//            while ($row = PMA_mysql_fetch_array($result)) {
+//            while ($row = PMA_DBI_fetch_assoc($result)) {
 //                $this->PMA_RT_addRelation($row['master_table'] , $row['master_field'], $row['foreign_table'], $row['foreign_field']);
 //            }
 //        }
@@ -1218,13 +1234,13 @@ class PMA_RT
 } // end of the "PMA_RT" class
 
 function PMA_RT_DOC($alltables ){
-    global  $db, $pdf, $orientation;
+    global  $db, $pdf, $orientation, $paper;
     //TOC
-    $pdf->addpage("P");
+    $pdf->addpage($GLOBALS['orientation']);
     $pdf->Cell(0,9, $GLOBALS['strTableOfContents'],1,0,'C');
     $pdf->Ln(15);
     $i = 1;
-    foreach($alltables AS $table) {
+    foreach ($alltables AS $table) {
         $pdf->PMA_links['doc'][$table]['-'] = $pdf->AddLink();
         $pdf->SetX(10);
         //$pdf->Ln(1);
@@ -1233,9 +1249,8 @@ function PMA_RT_DOC($alltables ){
         $pdf->Cell(0,6,$i.' '. $table,0,1,'L',0,$pdf->PMA_links['doc'][$table]['-']);
 
         //$pdf->Ln(1);
-        $local_query = 'SHOW FIELDS FROM ' . PMA_backquote($table);
-        $result      = PMA_mysql_query($local_query) or PMA_mysqlDie('', $local_query, '', $err_url);
-        while ($row = PMA_mysql_fetch_array($result)) {
+        $result     = PMA_DBI_query('SHOW FIELDS FROM ' . PMA_backquote($table) . ';');
+        while ($row = PMA_DBI_fetch_assoc($result)) {
             $pdf->SetX(20);
             $field_name = $row['Field'];
             $pdf->PMA_links['doc'][$table][$field_name] =$pdf->AddLink();
@@ -1250,7 +1265,7 @@ function PMA_RT_DOC($alltables ){
     $pdf->SetX(10);
     $pdf->Cell(0,6,$i.' '. $GLOBALS['strRelationalSchema'],0,1,'L',0,$pdf->PMA_links['RT']['-']);
     $z = 0;
-    foreach($alltables AS $table) {
+    foreach ($alltables AS $table) {
         $z++;
         $pdf->addpage($GLOBALS['orientation']);
         $pdf->Bookmark($table);
@@ -1263,35 +1278,33 @@ function PMA_RT_DOC($alltables ){
         $pdf->ln();
 
         $cfgRelation  = PMA_getRelationsParam();
-        if ($cfgRelation['commwork']) {
+        if ($cfgRelation['commwork'] || PMA_MYSQL_INT_VERSION >= 40100) {
             $comments = PMA_getComments($db, $table);
         }
         if ($cfgRelation['mimework']) {
             $mime_map = PMA_getMIME($db, $table, true);
         }
 
+
         /**
          * Gets table informations
          */
-        $local_query  = "SHOW TABLE STATUS LIKE '" . PMA_sqlAddslashes($table, TRUE) . "'";
-        $result       = PMA_mysql_query($local_query) or PMA_mysqlDie('', $local_query, '', $err_url);
-        $showtable    = PMA_mysql_fetch_array($result);
+        $result       = PMA_DBI_query('SHOW TABLE STATUS LIKE \'' . PMA_sqlAddslashes($table, TRUE) . '\';', NULL, PMA_DBI_QUERY_STORE);
+        $showtable    = PMA_DBI_fetch_assoc($result);
         $num_rows     = (isset($showtable['Rows']) ? $showtable['Rows'] : 0);
         $show_comment = (isset($showtable['Comment']) ? $showtable['Comment'] : '');
         $create_time  = (isset($showtable['Create_time']) ? PMA_localisedDate(strtotime($showtable['Create_time'])) : '');
         $update_time  = (isset($showtable['Update_time']) ? PMA_localisedDate(strtotime($showtable['Update_time'])) : '');
         $check_time   = (isset($showtable['Check_time']) ? PMA_localisedDate(strtotime($showtable['Check_time'])) : '');
 
-        if ($result) {
-             mysql_free_result($result);
-        }
+        PMA_DBI_free_result($result);
+        unset($result);
 
 
         /**
          * Gets table keys and retains them
          */
-        $local_query  = 'SHOW KEYS FROM ' . PMA_backquote($table);
-        $result       = PMA_mysql_query($local_query) or PMA_mysqlDie('', $local_query, '', $err_url);
+        $result       = PMA_DBI_query('SHOW KEYS FROM ' . PMA_backquote($table) . ';');
         $primary      = '';
         $indexes      = array();
         $lastIndex    = '';
@@ -1299,7 +1312,7 @@ function PMA_RT_DOC($alltables ){
         $indexes_data = array();
         $pk_array     = array(); // will be use to emphasis prim. keys in the table
                                  // view
-        while ($row = PMA_mysql_fetch_array($result)) {
+        while ($row = PMA_DBI_fetch_assoc($result)) {
             // Backups the list of primary keys
             if ($row['Key_name'] == 'PRIMARY') {
                 $primary   .= $row['Column_name'] . ', ';
@@ -1326,16 +1339,15 @@ function PMA_RT_DOC($alltables ){
 
         } // end while
         if ($result) {
-            mysql_free_result($result);
+            PMA_DBI_free_result($result);
         }
 
 
         /**
          * Gets fields properties
          */
-        $local_query = 'SHOW FIELDS FROM ' . PMA_backquote($table);
-        $result      = PMA_mysql_query($local_query) or PMA_mysqlDie('', $local_query, '', $err_url);
-        $fields_cnt  = mysql_num_rows($result);
+        $result      = PMA_DBI_query('SHOW FIELDS FROM ' . PMA_backquote($table) . ';', NULL, PMA_DBI_QUERY_STORE);
+        $fields_cnt  = PMA_DBI_num_rows($result);
 
 
         // Check if we can use Relations (Mike Beck)
@@ -1395,9 +1407,17 @@ function PMA_RT_DOC($alltables ){
             $pdf->Cell(20,8,ucfirst($GLOBALS['strDefault']),1,0,'C');
             $pdf->Cell(25,8,ucfirst($GLOBALS['strExtra']),1,0,'C');
             $pdf->Cell(45,8,ucfirst($GLOBALS['strLinksTo']),1,0,'C');
-            $pdf->Cell(67,8,ucfirst($GLOBALS['strComments']),1,0,'C');
+
+            if ($paper == 'A4') {
+                $comments_width = 67;
+            } else {
+                // this is really intended for 'letter'
+                // TODO: find optimal width for all formats
+                $comments_width = 50;
+            }
+            $pdf->Cell($comments_width,8,ucfirst($GLOBALS['strComments']),1,0,'C');
             $pdf->Cell(45,8,'MIME',1,1,'C');
-            $pdf->SetWidths(array(25,20,20,10,20,25,45,67,45));
+            $pdf->SetWidths(array(25,20,20,10,20,25,45,$comments_width,45));
         } else {
             $pdf->Cell(20,8,ucfirst($GLOBALS['strField']),1,0,'C');
             $pdf->Cell(20,8,ucfirst($GLOBALS['strType']),1,0,'C');
@@ -1412,7 +1432,7 @@ function PMA_RT_DOC($alltables ){
         }
         $pdf->SetFont('', '');
 
-        while ($row = PMA_mysql_fetch_array($result)) {
+        while ($row = PMA_DBI_fetch_assoc($result)) {
             $bgcolor = ($i % 2) ?$GLOBALS['cfg']['BgcolorOne'] : $GLOBALS['cfg']['BgcolorTwo'];
             $i++;
 
@@ -1498,7 +1518,7 @@ function PMA_RT_DOC($alltables ){
             } */
         } // end while
         $pdf->SetFont('', '',14);
-        mysql_free_result($result);
+        PMA_DBI_free_result($result);
     }//end each
 
 
@@ -1518,7 +1538,7 @@ $all_tab_same_wide    = (isset($all_tab_same_wide) && $all_tab_same_wide == 'on'
 $with_doc             = (isset($with_doc) && $with_doc == 'on') ? 1 : 0;
 $orientation          = (isset($orientation) && $orientation == 'P') ? 'P' : 'L';
 $paper                = isset($paper) ? $paper : 'A4';
-PMA_mysql_select_db($db);
+PMA_DBI_select_db($db);
 
 $rt = new PMA_RT($pdf_page_number, $show_table_dimension, $show_color, $show_grid, $all_tab_same_wide, $orientation, $paper);
 ?>
